@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -39,8 +39,8 @@ except ImportError as error:
 
 
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Interpolation import Interpolation
 
 
 class CellMat(FrozenClass):
@@ -90,18 +90,17 @@ class CellMat(FrozenClass):
         )
     else:
         is_exist = is_exist
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
         self,
-        connectivity=[],
+        connectivity=None,
         nb_cell=0,
         nb_node_per_cell=0,
-        indice=[],
+        indice=None,
         interpolation=-1,
         init_dict=None,
         init_str=None,
@@ -194,7 +193,7 @@ class CellMat(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -205,9 +204,29 @@ class CellMat(FrozenClass):
         if not array_equal(other.connectivity, self.connectivity):
             diff_list.append(name + ".connectivity")
         if other._nb_cell != self._nb_cell:
-            diff_list.append(name + ".nb_cell")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._nb_cell)
+                    + ", other="
+                    + str(other._nb_cell)
+                    + ")"
+                )
+                diff_list.append(name + ".nb_cell" + val_str)
+            else:
+                diff_list.append(name + ".nb_cell")
         if other._nb_node_per_cell != self._nb_node_per_cell:
-            diff_list.append(name + ".nb_node_per_cell")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._nb_node_per_cell)
+                    + ", other="
+                    + str(other._nb_node_per_cell)
+                    + ")"
+                )
+                diff_list.append(name + ".nb_node_per_cell" + val_str)
+            else:
+                diff_list.append(name + ".nb_node_per_cell")
         if not array_equal(other.indice, self.indice):
             diff_list.append(name + ".indice")
         if (other.interpolation is None and self.interpolation is not None) or (
@@ -217,7 +236,10 @@ class CellMat(FrozenClass):
         elif self.interpolation is not None:
             diff_list.extend(
                 self.interpolation.compare(
-                    other.interpolation, name=name + ".interpolation"
+                    other.interpolation,
+                    name=name + ".interpolation",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
                 )
             )
         # Filter ignore differences
@@ -287,6 +309,34 @@ class CellMat(FrozenClass):
         CellMat_dict["__class__"] = "CellMat"
         return CellMat_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.connectivity is None:
+            connectivity_val = None
+        else:
+            connectivity_val = self.connectivity.copy()
+        nb_cell_val = self.nb_cell
+        nb_node_per_cell_val = self.nb_node_per_cell
+        if self.indice is None:
+            indice_val = None
+        else:
+            indice_val = self.indice.copy()
+        if self.interpolation is None:
+            interpolation_val = None
+        else:
+            interpolation_val = self.interpolation.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            connectivity=connectivity_val,
+            nb_cell=nb_cell_val,
+            nb_node_per_cell=nb_node_per_cell_val,
+            indice=indice_val,
+            interpolation=interpolation_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -390,13 +440,22 @@ class CellMat(FrozenClass):
     def _set_interpolation(self, value):
         """setter of interpolation"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "interpolation"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Interpolation = import_class(
+                "pyleecan.Classes", "Interpolation", "interpolation"
+            )
             value = Interpolation()
         check_var("interpolation", value, "Interpolation")
         self._interpolation = value
