@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .GaussPoint import GaussPoint
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     get_gauss_points = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -43,9 +44,8 @@ class FPGNTri(GaussPoint):
         )
     else:
         get_gauss_points = get_gauss_points
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -96,7 +96,7 @@ class FPGNTri(GaussPoint):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -106,9 +106,23 @@ class FPGNTri(GaussPoint):
         diff_list = list()
 
         # Check the properties inherited from GaussPoint
-        diff_list.extend(super(FPGNTri, self).compare(other, name=name))
+        diff_list.extend(
+            super(FPGNTri, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._nb_gauss_point != self._nb_gauss_point:
-            diff_list.append(name + ".nb_gauss_point")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._nb_gauss_point)
+                    + ", other="
+                    + str(other._nb_gauss_point)
+                    + ")"
+                )
+                diff_list.append(name + ".nb_gauss_point" + val_str)
+            else:
+                diff_list.append(name + ".nb_gauss_point")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -146,6 +160,15 @@ class FPGNTri(GaussPoint):
         FPGNTri_dict["__class__"] = "FPGNTri"
         return FPGNTri_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        nb_gauss_point_val = self.nb_gauss_point
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(nb_gauss_point=nb_gauss_point_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
