@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Force import Force
 
 # Import all class method
@@ -40,6 +40,7 @@ except ImportError as error:
     element_loop = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -95,9 +96,8 @@ class ForceTensor(Force):
         )
     else:
         element_loop = element_loop
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -185,7 +185,7 @@ class ForceTensor(Force):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -195,11 +195,31 @@ class ForceTensor(Force):
         diff_list = list()
 
         # Check the properties inherited from Force
-        diff_list.extend(super(ForceTensor, self).compare(other, name=name))
+        diff_list.extend(
+            super(ForceTensor, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._group != self._group:
-            diff_list.append(name + ".group")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._group) + ", other=" + str(other._group) + ")"
+                )
+                diff_list.append(name + ".group" + val_str)
+            else:
+                diff_list.append(name + ".group")
         if other._tensor != self._tensor:
-            diff_list.append(name + ".tensor")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._tensor)
+                    + ", other="
+                    + str(other._tensor)
+                    + ")"
+                )
+                diff_list.append(name + ".tensor" + val_str)
+            else:
+                diff_list.append(name + ".tensor")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -243,6 +263,34 @@ class ForceTensor(Force):
         ForceTensor_dict["__class__"] = "ForceTensor"
         return ForceTensor_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        group_val = self.group
+        if self.tensor is None:
+            tensor_val = None
+        else:
+            tensor_val = self.tensor.copy()
+        is_periodicity_t_val = self.is_periodicity_t
+        is_periodicity_a_val = self.is_periodicity_a
+        is_agsf_transfer_val = self.is_agsf_transfer
+        max_wavenumber_transfer_val = self.max_wavenumber_transfer
+        Rsbo_enforced_transfer_val = self.Rsbo_enforced_transfer
+        logger_name_val = self.logger_name
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            group=group_val,
+            tensor=tensor_val,
+            is_periodicity_t=is_periodicity_t_val,
+            is_periodicity_a=is_periodicity_a_val,
+            is_agsf_transfer=is_agsf_transfer_val,
+            max_wavenumber_transfer=max_wavenumber_transfer_val,
+            Rsbo_enforced_transfer=Rsbo_enforced_transfer_val,
+            logger_name=logger_name_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
