@@ -10,22 +10,21 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Unit import Unit
 
 
 class GUIOption(FrozenClass):
 
     VERSION = 1
 
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -78,7 +77,7 @@ class GUIOption(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -91,7 +90,14 @@ class GUIOption(FrozenClass):
         ):
             diff_list.append(name + ".unit None mismatch")
         elif self.unit is not None:
-            diff_list.extend(self.unit.compare(other.unit, name=name + ".unit"))
+            diff_list.extend(
+                self.unit.compare(
+                    other.unit,
+                    name=name + ".unit",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -127,6 +133,18 @@ class GUIOption(FrozenClass):
         GUIOption_dict["__class__"] = "GUIOption"
         return GUIOption_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.unit is None:
+            unit_val = None
+        else:
+            unit_val = self.unit.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(unit=unit_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -140,11 +158,18 @@ class GUIOption(FrozenClass):
     def _set_unit(self, value):
         """setter of unit"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "unit")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Unit = import_class("pyleecan.Classes", "Unit", "unit")
             value = Unit()
         check_var("unit", value, "Unit")
         self._unit = value
