@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -41,9 +41,8 @@ except ImportError as error:
 from ..Classes.ImportMatrixVal import ImportMatrixVal
 from numpy import ndarray
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ImportMatrix import ImportMatrix
-from .OP import OP
 
 
 class Input(FrozenClass):
@@ -94,9 +93,8 @@ class Input(FrozenClass):
         )
     else:
         comp_axis_phase = comp_axis_phase
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -108,6 +106,7 @@ class Input(FrozenClass):
         Nrev=None,
         Na_tot=2048,
         OP=None,
+        t_final=None,
         init_dict=None,
         init_str=None,
     ):
@@ -138,6 +137,8 @@ class Input(FrozenClass):
                 Na_tot = init_dict["Na_tot"]
             if "OP" in list(init_dict.keys()):
                 OP = init_dict["OP"]
+            if "t_final" in list(init_dict.keys()):
+                t_final = init_dict["t_final"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.time = time
@@ -146,6 +147,7 @@ class Input(FrozenClass):
         self.Nrev = Nrev
         self.Na_tot = Na_tot
         self.OP = OP
+        self.t_final = t_final
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -176,6 +178,7 @@ class Input(FrozenClass):
             Input_str += "OP = " + tmp
         else:
             Input_str += "OP = None" + linesep + linesep
+        Input_str += "t_final = " + str(self.t_final) + linesep
         return Input_str
 
     def __eq__(self, other):
@@ -195,9 +198,11 @@ class Input(FrozenClass):
             return False
         if other.OP != self.OP:
             return False
+        if other.t_final != self.t_final:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -210,25 +215,98 @@ class Input(FrozenClass):
         ):
             diff_list.append(name + ".time None mismatch")
         elif self.time is not None:
-            diff_list.extend(self.time.compare(other.time, name=name + ".time"))
+            diff_list.extend(
+                self.time.compare(
+                    other.time,
+                    name=name + ".time",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if (other.angle is None and self.angle is not None) or (
             other.angle is not None and self.angle is None
         ):
             diff_list.append(name + ".angle None mismatch")
         elif self.angle is not None:
-            diff_list.extend(self.angle.compare(other.angle, name=name + ".angle"))
+            diff_list.extend(
+                self.angle.compare(
+                    other.angle,
+                    name=name + ".angle",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if other._Nt_tot != self._Nt_tot:
-            diff_list.append(name + ".Nt_tot")
-        if other._Nrev != self._Nrev:
-            diff_list.append(name + ".Nrev")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Nt_tot)
+                    + ", other="
+                    + str(other._Nt_tot)
+                    + ")"
+                )
+                diff_list.append(name + ".Nt_tot" + val_str)
+            else:
+                diff_list.append(name + ".Nt_tot")
+        if (
+            other._Nrev is not None
+            and self._Nrev is not None
+            and isnan(other._Nrev)
+            and isnan(self._Nrev)
+        ):
+            pass
+        elif other._Nrev != self._Nrev:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Nrev) + ", other=" + str(other._Nrev) + ")"
+                )
+                diff_list.append(name + ".Nrev" + val_str)
+            else:
+                diff_list.append(name + ".Nrev")
         if other._Na_tot != self._Na_tot:
-            diff_list.append(name + ".Na_tot")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Na_tot)
+                    + ", other="
+                    + str(other._Na_tot)
+                    + ")"
+                )
+                diff_list.append(name + ".Na_tot" + val_str)
+            else:
+                diff_list.append(name + ".Na_tot")
         if (other.OP is None and self.OP is not None) or (
             other.OP is not None and self.OP is None
         ):
             diff_list.append(name + ".OP None mismatch")
         elif self.OP is not None:
-            diff_list.extend(self.OP.compare(other.OP, name=name + ".OP"))
+            diff_list.extend(
+                self.OP.compare(
+                    other.OP,
+                    name=name + ".OP",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
+        if (
+            other._t_final is not None
+            and self._t_final is not None
+            and isnan(other._t_final)
+            and isnan(self._t_final)
+        ):
+            pass
+        elif other._t_final != self._t_final:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._t_final)
+                    + ", other="
+                    + str(other._t_final)
+                    + ")"
+                )
+                diff_list.append(name + ".t_final" + val_str)
+            else:
+                diff_list.append(name + ".t_final")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -243,6 +321,7 @@ class Input(FrozenClass):
         S += getsizeof(self.Nrev)
         S += getsizeof(self.Na_tot)
         S += getsizeof(self.OP)
+        S += getsizeof(self.t_final)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -284,10 +363,43 @@ class Input(FrozenClass):
                 keep_function=keep_function,
                 **kwargs
             )
+        Input_dict["t_final"] = self.t_final
         # The class name is added to the dict for deserialisation purpose
         Input_dict["__class__"] = "Input"
         return Input_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.time is None:
+            time_val = None
+        else:
+            time_val = self.time.copy()
+        if self.angle is None:
+            angle_val = None
+        else:
+            angle_val = self.angle.copy()
+        Nt_tot_val = self.Nt_tot
+        Nrev_val = self.Nrev
+        Na_tot_val = self.Na_tot
+        if self.OP is None:
+            OP_val = None
+        else:
+            OP_val = self.OP.copy()
+        t_final_val = self.t_final
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            time=time_val,
+            angle=angle_val,
+            Nt_tot=Nt_tot_val,
+            Nrev=Nrev_val,
+            Na_tot=Na_tot_val,
+            OP=OP_val,
+            t_final=t_final_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -300,6 +412,7 @@ class Input(FrozenClass):
         self.Na_tot = None
         if self.OP is not None:
             self.OP._set_None()
+        self.t_final = None
 
     def _get_time(self):
         """getter of time"""
@@ -307,6 +420,8 @@ class Input(FrozenClass):
 
     def _set_time(self, value):
         """setter of time"""
+        ImportMatrix = import_class("pyleecan.Classes", "ImportMatrix", "time")
+        ImportMatrixVal = import_class("pyleecan.Classes", "ImportMatrixVal", "time")
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, ndarray):
@@ -339,6 +454,8 @@ class Input(FrozenClass):
 
     def _set_angle(self, value):
         """setter of angle"""
+        ImportMatrix = import_class("pyleecan.Classes", "ImportMatrix", "angle")
+        ImportMatrixVal = import_class("pyleecan.Classes", "ImportMatrixVal", "angle")
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, ndarray):
@@ -431,11 +548,18 @@ class Input(FrozenClass):
     def _set_OP(self, value):
         """setter of OP"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "OP")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            OP = import_class("pyleecan.Classes", "OP", "OP")
             value = OP()
         check_var("OP", value, "OP")
         self._OP = value
@@ -451,3 +575,21 @@ class Input(FrozenClass):
         :Type: OP
         """,
     )
+
+    def _get_t_final(self):
+        """getter of t_final"""
+        return self._t_final
+
+    def _set_t_final(self, value):
+        """setter of t_final"""
+        check_var("t_final", value, "float")
+        self._t_final = value
+
+    t_final = property(
+        fget=_get_t_final,
+        fset=_set_t_final,
+        doc=u"""To enforce final time
+
+        :Type: float
+        """,
+    )
