@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -59,11 +59,6 @@ try:
 except ImportError as error:
     comp_volumes = error
 
-try:
-    from ..Methods.Machine.Lamination.get_bore_line import get_bore_line
-except ImportError as error:
-    get_bore_line = error
-
 try:
     from ..Methods.Machine.Lamination.get_Rbo import get_Rbo
 except ImportError as error:
@@ -104,11 +99,6 @@ try:
 except ImportError as error:
     comp_height_yoke = error
 
-try:
-    from ..Methods.Machine.Lamination.get_notch_list import get_notch_list
-except ImportError as error:
-    get_notch_list = error
-
 try:
     from ..Methods.Machine.Lamination.comp_angle_q_axis import comp_angle_q_axis
 except ImportError as error:
@@ -119,16 +109,6 @@ try:
 except ImportError as error:
     comp_radius_mid_yoke = error
 
-try:
-    from ..Methods.Machine.Lamination.get_yoke_desc import get_yoke_desc
-except ImportError as error:
-    get_yoke_desc = error
-
-try:
-    from ..Methods.Machine.Lamination.get_bore_desc import get_bore_desc
-except ImportError as error:
-    get_bore_desc = error
-
 try:
     from ..Methods.Machine.Lamination.comp_point_ref import comp_point_ref
 except ImportError as error:
@@ -147,9 +127,9 @@ except ImportError as error:
     get_label = error
 
 try:
-    from ..Methods.Machine.Lamination.get_yoke_side_line import get_yoke_side_line
+    from ..Methods.Machine.Lamination.build_yoke_side_line import build_yoke_side_line
 except ImportError as error:
-    get_yoke_side_line = error
+    build_yoke_side_line = error
 
 try:
     from ..Methods.Machine.Lamination.get_notches_surf import get_notches_surf
@@ -163,13 +143,44 @@ try:
 except ImportError as error:
     comp_periodicity_duct_spatial = error
 
+try:
+    from ..Methods.Machine.Lamination.get_surfaces_closing import get_surfaces_closing
+except ImportError as error:
+    get_surfaces_closing = error
 
+try:
+    from ..Methods.Machine.Lamination.comp_periodicity_geo import comp_periodicity_geo
+except ImportError as error:
+    comp_periodicity_geo = error
+
+try:
+    from ..Methods.Machine.Lamination.has_notch import has_notch
+except ImportError as error:
+    has_notch = error
+
+try:
+    from ..Methods.Machine.Lamination.build_radius_lines import build_radius_lines
+except ImportError as error:
+    build_radius_lines = error
+
+try:
+    from ..Methods.Machine.Lamination.build_radius_desc import build_radius_desc
+except ImportError as error:
+    build_radius_desc = error
+
+try:
+    from ..Methods.Machine.Lamination.has_slot import has_slot
+except ImportError as error:
+    has_slot = error
+
+try:
+    from ..Methods.Machine.Lamination.plot_preview_notch import plot_preview_notch
+except ImportError as error:
+    plot_preview_notch = error
+
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Material import Material
-from .Hole import Hole
-from .Notch import Notch
-from .Skew import Skew
-from .Bore import Bore
 
 
 class Lamination(FrozenClass):
@@ -266,17 +277,6 @@ class Lamination(FrozenClass):
         )
     else:
         comp_volumes = comp_volumes
-    # cf Methods.Machine.Lamination.get_bore_line
-    if isinstance(get_bore_line, ImportError):
-        get_bore_line = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Lamination method get_bore_line: " + str(get_bore_line)
-                )
-            )
-        )
-    else:
-        get_bore_line = get_bore_line
     # cf Methods.Machine.Lamination.get_Rbo
     if isinstance(get_Rbo, ImportError):
         get_Rbo = property(
@@ -361,17 +361,6 @@ class Lamination(FrozenClass):
         )
     else:
         comp_height_yoke = comp_height_yoke
-    # cf Methods.Machine.Lamination.get_notch_list
-    if isinstance(get_notch_list, ImportError):
-        get_notch_list = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Lamination method get_notch_list: " + str(get_notch_list)
-                )
-            )
-        )
-    else:
-        get_notch_list = get_notch_list
     # cf Methods.Machine.Lamination.comp_angle_q_axis
     if isinstance(comp_angle_q_axis, ImportError):
         comp_angle_q_axis = property(
@@ -396,28 +385,6 @@ class Lamination(FrozenClass):
         )
     else:
         comp_radius_mid_yoke = comp_radius_mid_yoke
-    # cf Methods.Machine.Lamination.get_yoke_desc
-    if isinstance(get_yoke_desc, ImportError):
-        get_yoke_desc = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Lamination method get_yoke_desc: " + str(get_yoke_desc)
-                )
-            )
-        )
-    else:
-        get_yoke_desc = get_yoke_desc
-    # cf Methods.Machine.Lamination.get_bore_desc
-    if isinstance(get_bore_desc, ImportError):
-        get_bore_desc = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Lamination method get_bore_desc: " + str(get_bore_desc)
-                )
-            )
-        )
-    else:
-        get_bore_desc = get_bore_desc
     # cf Methods.Machine.Lamination.comp_point_ref
     if isinstance(comp_point_ref, ImportError):
         comp_point_ref = property(
@@ -450,18 +417,18 @@ class Lamination(FrozenClass):
         )
     else:
         get_label = get_label
-    # cf Methods.Machine.Lamination.get_yoke_side_line
-    if isinstance(get_yoke_side_line, ImportError):
-        get_yoke_side_line = property(
+    # cf Methods.Machine.Lamination.build_yoke_side_line
+    if isinstance(build_yoke_side_line, ImportError):
+        build_yoke_side_line = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use Lamination method get_yoke_side_line: "
-                    + str(get_yoke_side_line)
+                    "Can't use Lamination method build_yoke_side_line: "
+                    + str(build_yoke_side_line)
                 )
             )
         )
     else:
-        get_yoke_side_line = get_yoke_side_line
+        build_yoke_side_line = build_yoke_side_line
     # cf Methods.Machine.Lamination.get_notches_surf
     if isinstance(get_notches_surf, ImportError):
         get_notches_surf = property(
@@ -486,9 +453,86 @@ class Lamination(FrozenClass):
         )
     else:
         comp_periodicity_duct_spatial = comp_periodicity_duct_spatial
-    # save and copy methods are available in all object
+    # cf Methods.Machine.Lamination.get_surfaces_closing
+    if isinstance(get_surfaces_closing, ImportError):
+        get_surfaces_closing = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method get_surfaces_closing: "
+                    + str(get_surfaces_closing)
+                )
+            )
+        )
+    else:
+        get_surfaces_closing = get_surfaces_closing
+    # cf Methods.Machine.Lamination.comp_periodicity_geo
+    if isinstance(comp_periodicity_geo, ImportError):
+        comp_periodicity_geo = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method comp_periodicity_geo: "
+                    + str(comp_periodicity_geo)
+                )
+            )
+        )
+    else:
+        comp_periodicity_geo = comp_periodicity_geo
+    # cf Methods.Machine.Lamination.has_notch
+    if isinstance(has_notch, ImportError):
+        has_notch = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Lamination method has_notch: " + str(has_notch))
+            )
+        )
+    else:
+        has_notch = has_notch
+    # cf Methods.Machine.Lamination.build_radius_lines
+    if isinstance(build_radius_lines, ImportError):
+        build_radius_lines = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method build_radius_lines: "
+                    + str(build_radius_lines)
+                )
+            )
+        )
+    else:
+        build_radius_lines = build_radius_lines
+    # cf Methods.Machine.Lamination.build_radius_desc
+    if isinstance(build_radius_desc, ImportError):
+        build_radius_desc = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method build_radius_desc: "
+                    + str(build_radius_desc)
+                )
+            )
+        )
+    else:
+        build_radius_desc = build_radius_desc
+    # cf Methods.Machine.Lamination.has_slot
+    if isinstance(has_slot, ImportError):
+        has_slot = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Lamination method has_slot: " + str(has_slot))
+            )
+        )
+    else:
+        has_slot = has_slot
+    # cf Methods.Machine.Lamination.plot_preview_notch
+    if isinstance(plot_preview_notch, ImportError):
+        plot_preview_notch = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method plot_preview_notch: "
+                    + str(plot_preview_notch)
+                )
+            )
+        )
+    else:
+        plot_preview_notch = plot_preview_notch
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -506,8 +550,8 @@ class Lamination(FrozenClass):
         axial_vent=-1,
         notch=-1,
         skew=None,
-        yoke_notch=-1,
         bore=None,
+        yoke=None,
         init_dict=None,
         init_str=None,
     ):
@@ -550,10 +594,10 @@ class Lamination(FrozenClass):
                 notch = init_dict["notch"]
             if "skew" in list(init_dict.keys()):
                 skew = init_dict["skew"]
-            if "yoke_notch" in list(init_dict.keys()):
-                yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
                 bore = init_dict["bore"]
+            if "yoke" in list(init_dict.keys()):
+                yoke = init_dict["yoke"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.L1 = L1
@@ -568,8 +612,8 @@ class Lamination(FrozenClass):
         self.axial_vent = axial_vent
         self.notch = notch
         self.skew = skew
-        self.yoke_notch = yoke_notch
         self.bore = bore
+        self.yoke = yoke
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -612,18 +656,16 @@ class Lamination(FrozenClass):
             Lamination_str += "skew = " + tmp
         else:
             Lamination_str += "skew = None" + linesep + linesep
-        if len(self.yoke_notch) == 0:
-            Lamination_str += "yoke_notch = []" + linesep
-        for ii in range(len(self.yoke_notch)):
-            tmp = (
-                self.yoke_notch[ii].__str__().replace(linesep, linesep + "\t") + linesep
-            )
-            Lamination_str += "yoke_notch[" + str(ii) + "] =" + tmp + linesep + linesep
         if self.bore is not None:
             tmp = self.bore.__str__().replace(linesep, linesep + "\t").rstrip("\t")
             Lamination_str += "bore = " + tmp
         else:
             Lamination_str += "bore = None" + linesep + linesep
+        if self.yoke is not None:
+            tmp = self.yoke.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            Lamination_str += "yoke = " + tmp
+        else:
+            Lamination_str += "yoke = None" + linesep + linesep
         return Lamination_str
 
     def __eq__(self, other):
@@ -655,13 +697,13 @@ class Lamination(FrozenClass):
             return False
         if other.skew != self.skew:
             return False
-        if other.yoke_notch != self.yoke_notch:
-            return False
         if other.bore != self.bore:
             return False
+        if other.yoke != self.yoke:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -669,30 +711,124 @@ class Lamination(FrozenClass):
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
-        if other._L1 != self._L1:
-            diff_list.append(name + ".L1")
+        if (
+            other._L1 is not None
+            and self._L1 is not None
+            and isnan(other._L1)
+            and isnan(self._L1)
+        ):
+            pass
+        elif other._L1 != self._L1:
+            if is_add_value:
+                val_str = " (self=" + str(self._L1) + ", other=" + str(other._L1) + ")"
+                diff_list.append(name + ".L1" + val_str)
+            else:
+                diff_list.append(name + ".L1")
         if (other.mat_type is None and self.mat_type is not None) or (
             other.mat_type is not None and self.mat_type is None
         ):
             diff_list.append(name + ".mat_type None mismatch")
         elif self.mat_type is not None:
             diff_list.extend(
-                self.mat_type.compare(other.mat_type, name=name + ".mat_type")
+                self.mat_type.compare(
+                    other.mat_type,
+                    name=name + ".mat_type",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if other._Nrvd != self._Nrvd:
-            diff_list.append(name + ".Nrvd")
-        if other._Wrvd != self._Wrvd:
-            diff_list.append(name + ".Wrvd")
-        if other._Kf1 != self._Kf1:
-            diff_list.append(name + ".Kf1")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Nrvd) + ", other=" + str(other._Nrvd) + ")"
+                )
+                diff_list.append(name + ".Nrvd" + val_str)
+            else:
+                diff_list.append(name + ".Nrvd")
+        if (
+            other._Wrvd is not None
+            and self._Wrvd is not None
+            and isnan(other._Wrvd)
+            and isnan(self._Wrvd)
+        ):
+            pass
+        elif other._Wrvd != self._Wrvd:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Wrvd) + ", other=" + str(other._Wrvd) + ")"
+                )
+                diff_list.append(name + ".Wrvd" + val_str)
+            else:
+                diff_list.append(name + ".Wrvd")
+        if (
+            other._Kf1 is not None
+            and self._Kf1 is not None
+            and isnan(other._Kf1)
+            and isnan(self._Kf1)
+        ):
+            pass
+        elif other._Kf1 != self._Kf1:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Kf1) + ", other=" + str(other._Kf1) + ")"
+                )
+                diff_list.append(name + ".Kf1" + val_str)
+            else:
+                diff_list.append(name + ".Kf1")
         if other._is_internal != self._is_internal:
-            diff_list.append(name + ".is_internal")
-        if other._Rint != self._Rint:
-            diff_list.append(name + ".Rint")
-        if other._Rext != self._Rext:
-            diff_list.append(name + ".Rext")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_internal)
+                    + ", other="
+                    + str(other._is_internal)
+                    + ")"
+                )
+                diff_list.append(name + ".is_internal" + val_str)
+            else:
+                diff_list.append(name + ".is_internal")
+        if (
+            other._Rint is not None
+            and self._Rint is not None
+            and isnan(other._Rint)
+            and isnan(self._Rint)
+        ):
+            pass
+        elif other._Rint != self._Rint:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Rint) + ", other=" + str(other._Rint) + ")"
+                )
+                diff_list.append(name + ".Rint" + val_str)
+            else:
+                diff_list.append(name + ".Rint")
+        if (
+            other._Rext is not None
+            and self._Rext is not None
+            and isnan(other._Rext)
+            and isnan(self._Rext)
+        ):
+            pass
+        elif other._Rext != self._Rext:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Rext) + ", other=" + str(other._Rext) + ")"
+                )
+                diff_list.append(name + ".Rext" + val_str)
+            else:
+                diff_list.append(name + ".Rext")
         if other._is_stator != self._is_stator:
-            diff_list.append(name + ".is_stator")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_stator)
+                    + ", other="
+                    + str(other._is_stator)
+                    + ")"
+                )
+                diff_list.append(name + ".is_stator" + val_str)
+            else:
+                diff_list.append(name + ".is_stator")
         if (other.axial_vent is None and self.axial_vent is not None) or (
             other.axial_vent is not None and self.axial_vent is None
         ):
@@ -705,7 +841,10 @@ class Lamination(FrozenClass):
             for ii in range(len(other.axial_vent)):
                 diff_list.extend(
                     self.axial_vent[ii].compare(
-                        other.axial_vent[ii], name=name + ".axial_vent[" + str(ii) + "]"
+                        other.axial_vent[ii],
+                        name=name + ".axial_vent[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (other.notch is None and self.notch is not None) or (
@@ -720,7 +859,10 @@ class Lamination(FrozenClass):
             for ii in range(len(other.notch)):
                 diff_list.extend(
                     self.notch[ii].compare(
-                        other.notch[ii], name=name + ".notch[" + str(ii) + "]"
+                        other.notch[ii],
+                        name=name + ".notch[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (other.skew is None and self.skew is not None) or (
@@ -728,28 +870,40 @@ class Lamination(FrozenClass):
         ):
             diff_list.append(name + ".skew None mismatch")
         elif self.skew is not None:
-            diff_list.extend(self.skew.compare(other.skew, name=name + ".skew"))
-        if (other.yoke_notch is None and self.yoke_notch is not None) or (
-            other.yoke_notch is not None and self.yoke_notch is None
-        ):
-            diff_list.append(name + ".yoke_notch None mismatch")
-        elif self.yoke_notch is None:
-            pass
-        elif len(other.yoke_notch) != len(self.yoke_notch):
-            diff_list.append("len(" + name + ".yoke_notch)")
-        else:
-            for ii in range(len(other.yoke_notch)):
-                diff_list.extend(
-                    self.yoke_notch[ii].compare(
-                        other.yoke_notch[ii], name=name + ".yoke_notch[" + str(ii) + "]"
-                    )
+            diff_list.extend(
+                self.skew.compare(
+                    other.skew,
+                    name=name + ".skew",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
                 )
+            )
         if (other.bore is None and self.bore is not None) or (
             other.bore is not None and self.bore is None
         ):
             diff_list.append(name + ".bore None mismatch")
         elif self.bore is not None:
-            diff_list.extend(self.bore.compare(other.bore, name=name + ".bore"))
+            diff_list.extend(
+                self.bore.compare(
+                    other.bore,
+                    name=name + ".bore",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
+        if (other.yoke is None and self.yoke is not None) or (
+            other.yoke is not None and self.yoke is None
+        ):
+            diff_list.append(name + ".yoke None mismatch")
+        elif self.yoke is not None:
+            diff_list.extend(
+                self.yoke.compare(
+                    other.yoke,
+                    name=name + ".yoke",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -774,10 +928,8 @@ class Lamination(FrozenClass):
             for value in self.notch:
                 S += getsizeof(value)
         S += getsizeof(self.skew)
-        if self.yoke_notch is not None:
-            for value in self.yoke_notch:
-                S += getsizeof(value)
         S += getsizeof(self.bore)
+        S += getsizeof(self.yoke)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -846,21 +998,6 @@ class Lamination(FrozenClass):
                 keep_function=keep_function,
                 **kwargs
             )
-        if self.yoke_notch is None:
-            Lamination_dict["yoke_notch"] = None
-        else:
-            Lamination_dict["yoke_notch"] = list()
-            for obj in self.yoke_notch:
-                if obj is not None:
-                    Lamination_dict["yoke_notch"].append(
-                        obj.as_dict(
-                            type_handle_ndarray=type_handle_ndarray,
-                            keep_function=keep_function,
-                            **kwargs
-                        )
-                    )
-                else:
-                    Lamination_dict["yoke_notch"].append(None)
         if self.bore is None:
             Lamination_dict["bore"] = None
         else:
@@ -869,10 +1006,77 @@ class Lamination(FrozenClass):
                 keep_function=keep_function,
                 **kwargs
             )
+        if self.yoke is None:
+            Lamination_dict["yoke"] = None
+        else:
+            Lamination_dict["yoke"] = self.yoke.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         Lamination_dict["__class__"] = "Lamination"
         return Lamination_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        L1_val = self.L1
+        if self.mat_type is None:
+            mat_type_val = None
+        else:
+            mat_type_val = self.mat_type.copy()
+        Nrvd_val = self.Nrvd
+        Wrvd_val = self.Wrvd
+        Kf1_val = self.Kf1
+        is_internal_val = self.is_internal
+        Rint_val = self.Rint
+        Rext_val = self.Rext
+        is_stator_val = self.is_stator
+        if self.axial_vent is None:
+            axial_vent_val = None
+        else:
+            axial_vent_val = list()
+            for obj in self.axial_vent:
+                axial_vent_val.append(obj.copy())
+        if self.notch is None:
+            notch_val = None
+        else:
+            notch_val = list()
+            for obj in self.notch:
+                notch_val.append(obj.copy())
+        if self.skew is None:
+            skew_val = None
+        else:
+            skew_val = self.skew.copy()
+        if self.bore is None:
+            bore_val = None
+        else:
+            bore_val = self.bore.copy()
+        if self.yoke is None:
+            yoke_val = None
+        else:
+            yoke_val = self.yoke.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            L1=L1_val,
+            mat_type=mat_type_val,
+            Nrvd=Nrvd_val,
+            Wrvd=Wrvd_val,
+            Kf1=Kf1_val,
+            is_internal=is_internal_val,
+            Rint=Rint_val,
+            Rext=Rext_val,
+            is_stator=is_stator_val,
+            axial_vent=axial_vent_val,
+            notch=notch_val,
+            skew=skew_val,
+            bore=bore_val,
+            yoke=yoke_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -890,9 +1094,10 @@ class Lamination(FrozenClass):
         self.notch = None
         if self.skew is not None:
             self.skew._set_None()
-        self.yoke_notch = None
         if self.bore is not None:
             self.bore._set_None()
+        if self.yoke is not None:
+            self.yoke._set_None()
 
     def _get_L1(self):
         """getter of L1"""
@@ -906,7 +1111,7 @@ class Lamination(FrozenClass):
     L1 = property(
         fget=_get_L1,
         fset=_set_L1,
-        doc=u"""Lamination stack active length [m] without radial ventilation airducts but including insulation layers between lamination sheets
+        doc=u"""Lamination stack active length without radial ventilation airducts but including insulation layers between lamination sheets
 
         :Type: float
         :min: 0
@@ -920,13 +1125,20 @@ class Lamination(FrozenClass):
     def _set_mat_type(self, value):
         """setter of mat_type"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "mat_type"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Material = import_class("pyleecan.Classes", "Material", "mat_type")
             value = Material()
         check_var("mat_type", value, "Material")
         self._mat_type = value
@@ -1087,6 +1299,15 @@ class Lamination(FrozenClass):
         """setter of axial_vent"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "axial_vent"
@@ -1120,6 +1341,15 @@ class Lamination(FrozenClass):
         """setter of notch"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "notch"
@@ -1148,11 +1378,18 @@ class Lamination(FrozenClass):
     def _set_skew(self, value):
         """setter of skew"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "skew")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Skew = import_class("pyleecan.Classes", "Skew", "skew")
             value = Skew()
         check_var("skew", value, "Skew")
         self._skew = value
@@ -1169,39 +1406,6 @@ class Lamination(FrozenClass):
         """,
     )
 
-    def _get_yoke_notch(self):
-        """getter of yoke_notch"""
-        if self._yoke_notch is not None:
-            for obj in self._yoke_notch:
-                if obj is not None:
-                    obj.parent = self
-        return self._yoke_notch
-
-    def _set_yoke_notch(self, value):
-        """setter of yoke_notch"""
-        if type(value) is list:
-            for ii, obj in enumerate(value):
-                if type(obj) is dict:
-                    class_obj = import_class(
-                        "pyleecan.Classes", obj.get("__class__"), "yoke_notch"
-                    )
-                    value[ii] = class_obj(init_dict=obj)
-                if value[ii] is not None:
-                    value[ii].parent = self
-        if value == -1:
-            value = list()
-        check_var("yoke_notch", value, "[Notch]")
-        self._yoke_notch = value
-
-    yoke_notch = property(
-        fget=_get_yoke_notch,
-        fset=_set_yoke_notch,
-        doc=u"""Lamination yoke notches
-
-        :Type: [Notch]
-        """,
-    )
-
     def _get_bore(self):
         """getter of bore"""
         return self._bore
@@ -1209,11 +1413,18 @@ class Lamination(FrozenClass):
     def _set_bore(self, value):
         """setter of bore"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "bore")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Bore = import_class("pyleecan.Classes", "Bore", "bore")
             value = Bore()
         check_var("bore", value, "Bore")
         self._bore = value
@@ -1229,3 +1440,38 @@ class Lamination(FrozenClass):
         :Type: Bore
         """,
     )
+
+    def _get_yoke(self):
+        """getter of yoke"""
+        return self._yoke
+
+    def _set_yoke(self, value):
+        """setter of yoke"""
+        if isinstance(value, str):  # Load from file
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "yoke")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            Bore = import_class("pyleecan.Classes", "Bore", "yoke")
+            value = Bore()
+        check_var("yoke", value, "Bore")
+        self._yoke = value
+
+        if self._yoke is not None:
+            self._yoke.parent = self
+
+    yoke = property(
+        fget=_get_yoke,
+        fset=_set_yoke,
+        doc=u"""Yoke Shape
+
+        :Type: Bore
+        """,
+    )
