@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .LossModel import LossModel
 
 # Import all class method
@@ -37,6 +37,7 @@ except ImportError as error:
     comp_loss_density = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -83,9 +84,8 @@ class LossModelBertotti(LossModel):
         )
     else:
         comp_loss_density = comp_loss_density
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -101,6 +101,7 @@ class LossModelBertotti(LossModel):
         get_meshsolution=False,
         N0=-1,
         name="",
+        is_show_fig=False,
         init_dict=None,
         init_str=None,
     ):
@@ -139,6 +140,8 @@ class LossModelBertotti(LossModel):
                 N0 = init_dict["N0"]
             if "name" in list(init_dict.keys()):
                 name = init_dict["name"]
+            if "is_show_fig" in list(init_dict.keys()):
+                is_show_fig = init_dict["is_show_fig"]
         # Set the properties (value check and convertion are done in setter)
         self.k_hy = k_hy
         self.k_ed = k_ed
@@ -150,7 +153,7 @@ class LossModelBertotti(LossModel):
         self.get_meshsolution = get_meshsolution
         self.N0 = N0
         # Call LossModel init
-        super(LossModelBertotti, self).__init__(name=name)
+        super(LossModelBertotti, self).__init__(name=name, is_show_fig=is_show_fig)
         # The class is frozen (in LossModel init), for now it's impossible to
         # add new properties
 
@@ -204,7 +207,7 @@ class LossModelBertotti(LossModel):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -214,25 +217,139 @@ class LossModelBertotti(LossModel):
         diff_list = list()
 
         # Check the properties inherited from LossModel
-        diff_list.extend(super(LossModelBertotti, self).compare(other, name=name))
-        if other._k_hy != self._k_hy:
-            diff_list.append(name + ".k_hy")
-        if other._k_ed != self._k_ed:
-            diff_list.append(name + ".k_ed")
-        if other._k_ex != self._k_ex:
-            diff_list.append(name + ".k_ex")
-        if other._alpha_hy != self._alpha_hy:
-            diff_list.append(name + ".alpha_hy")
-        if other._alpha_ed != self._alpha_ed:
-            diff_list.append(name + ".alpha_ed")
-        if other._alpha_ex != self._alpha_ex:
-            diff_list.append(name + ".alpha_ex")
+        diff_list.extend(
+            super(LossModelBertotti, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._k_hy is not None
+            and self._k_hy is not None
+            and isnan(other._k_hy)
+            and isnan(self._k_hy)
+        ):
+            pass
+        elif other._k_hy != self._k_hy:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._k_hy) + ", other=" + str(other._k_hy) + ")"
+                )
+                diff_list.append(name + ".k_hy" + val_str)
+            else:
+                diff_list.append(name + ".k_hy")
+        if (
+            other._k_ed is not None
+            and self._k_ed is not None
+            and isnan(other._k_ed)
+            and isnan(self._k_ed)
+        ):
+            pass
+        elif other._k_ed != self._k_ed:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._k_ed) + ", other=" + str(other._k_ed) + ")"
+                )
+                diff_list.append(name + ".k_ed" + val_str)
+            else:
+                diff_list.append(name + ".k_ed")
+        if (
+            other._k_ex is not None
+            and self._k_ex is not None
+            and isnan(other._k_ex)
+            and isnan(self._k_ex)
+        ):
+            pass
+        elif other._k_ex != self._k_ex:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._k_ex) + ", other=" + str(other._k_ex) + ")"
+                )
+                diff_list.append(name + ".k_ex" + val_str)
+            else:
+                diff_list.append(name + ".k_ex")
+        if (
+            other._alpha_hy is not None
+            and self._alpha_hy is not None
+            and isnan(other._alpha_hy)
+            and isnan(self._alpha_hy)
+        ):
+            pass
+        elif other._alpha_hy != self._alpha_hy:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._alpha_hy)
+                    + ", other="
+                    + str(other._alpha_hy)
+                    + ")"
+                )
+                diff_list.append(name + ".alpha_hy" + val_str)
+            else:
+                diff_list.append(name + ".alpha_hy")
+        if (
+            other._alpha_ed is not None
+            and self._alpha_ed is not None
+            and isnan(other._alpha_ed)
+            and isnan(self._alpha_ed)
+        ):
+            pass
+        elif other._alpha_ed != self._alpha_ed:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._alpha_ed)
+                    + ", other="
+                    + str(other._alpha_ed)
+                    + ")"
+                )
+                diff_list.append(name + ".alpha_ed" + val_str)
+            else:
+                diff_list.append(name + ".alpha_ed")
+        if (
+            other._alpha_ex is not None
+            and self._alpha_ex is not None
+            and isnan(other._alpha_ex)
+            and isnan(self._alpha_ex)
+        ):
+            pass
+        elif other._alpha_ex != self._alpha_ex:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._alpha_ex)
+                    + ", other="
+                    + str(other._alpha_ex)
+                    + ")"
+                )
+                diff_list.append(name + ".alpha_ex" + val_str)
+            else:
+                diff_list.append(name + ".alpha_ex")
         if other._group != self._group:
-            diff_list.append(name + ".group")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._group) + ", other=" + str(other._group) + ")"
+                )
+                diff_list.append(name + ".group" + val_str)
+            else:
+                diff_list.append(name + ".group")
         if other._get_meshsolution != self._get_meshsolution:
-            diff_list.append(name + ".get_meshsolution")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._get_meshsolution)
+                    + ", other="
+                    + str(other._get_meshsolution)
+                    + ")"
+                )
+                diff_list.append(name + ".get_meshsolution" + val_str)
+            else:
+                diff_list.append(name + ".get_meshsolution")
         if other._N0 != self._N0:
-            diff_list.append(name + ".N0")
+            if is_add_value:
+                val_str = " (self=" + str(self._N0) + ", other=" + str(other._N0) + ")"
+                diff_list.append(name + ".N0" + val_str)
+            else:
+                diff_list.append(name + ".N0")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -288,6 +405,40 @@ class LossModelBertotti(LossModel):
         LossModelBertotti_dict["__class__"] = "LossModelBertotti"
         return LossModelBertotti_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        k_hy_val = self.k_hy
+        k_ed_val = self.k_ed
+        k_ex_val = self.k_ex
+        alpha_hy_val = self.alpha_hy
+        alpha_ed_val = self.alpha_ed
+        alpha_ex_val = self.alpha_ex
+        group_val = self.group
+        get_meshsolution_val = self.get_meshsolution
+        if self.N0 is None:
+            N0_val = None
+        else:
+            N0_val = self.N0.copy()
+        name_val = self.name
+        is_show_fig_val = self.is_show_fig
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            k_hy=k_hy_val,
+            k_ed=k_ed_val,
+            k_ex=k_ex_val,
+            alpha_hy=alpha_hy_val,
+            alpha_ed=alpha_ed_val,
+            alpha_ex=alpha_ex_val,
+            group=group_val,
+            get_meshsolution=get_meshsolution_val,
+            N0=N0_val,
+            name=name_val,
+            is_show_fig=is_show_fig_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
