@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Machine import Machine
 
 # Import all class method
@@ -22,10 +22,16 @@ try:
 except ImportError as error:
     is_synchronous = error
 
+try:
+    from ..Methods.Machine.MachineSync.comp_angle_rotor_initial import (
+        comp_angle_rotor_initial,
+    )
+except ImportError as error:
+    comp_angle_rotor_initial = error
 
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Frame import Frame
-from .Shaft import Shaft
 
 
 class MachineSync(Machine):
@@ -33,6 +39,7 @@ class MachineSync(Machine):
 
     VERSION = 1
 
+    # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.Machine.MachineSync.is_synchronous
     if isinstance(is_synchronous, ImportError):
         is_synchronous = property(
@@ -45,9 +52,20 @@ class MachineSync(Machine):
         )
     else:
         is_synchronous = is_synchronous
-    # save and copy methods are available in all object
+    # cf Methods.Machine.MachineSync.comp_angle_rotor_initial
+    if isinstance(comp_angle_rotor_initial, ImportError):
+        comp_angle_rotor_initial = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use MachineSync method comp_angle_rotor_initial: "
+                    + str(comp_angle_rotor_initial)
+                )
+            )
+        )
+    else:
+        comp_angle_rotor_initial = comp_angle_rotor_initial
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -121,7 +139,7 @@ class MachineSync(Machine):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -131,7 +149,11 @@ class MachineSync(Machine):
         diff_list = list()
 
         # Check the properties inherited from Machine
-        diff_list.extend(super(MachineSync, self).compare(other, name=name))
+        diff_list.extend(
+            super(MachineSync, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -167,6 +189,33 @@ class MachineSync(Machine):
         MachineSync_dict["__class__"] = "MachineSync"
         return MachineSync_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.frame is None:
+            frame_val = None
+        else:
+            frame_val = self.frame.copy()
+        if self.shaft is None:
+            shaft_val = None
+        else:
+            shaft_val = self.shaft.copy()
+        name_val = self.name
+        desc_val = self.desc
+        type_machine_val = self.type_machine
+        logger_name_val = self.logger_name
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            frame=frame_val,
+            shaft=shaft_val,
+            name=name_val,
+            desc=desc_val,
+            type_machine=type_machine_val,
+            logger_name=logger_name_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
