@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -38,8 +38,8 @@ except ImportError as error:
     comp_I_mag = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .SliceModel import SliceModel
 
 
 class Magnetics(FrozenClass):
@@ -87,9 +87,8 @@ class Magnetics(FrozenClass):
         )
     else:
         comp_I_mag = comp_I_mag
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -112,6 +111,8 @@ class Magnetics(FrozenClass):
         Nslices_enforced=None,
         type_distribution_enforced=None,
         is_current_harm=True,
+        T_mag=20,
+        is_periodicity_rotor=False,
         init_dict=None,
         init_str=None,
     ):
@@ -164,6 +165,10 @@ class Magnetics(FrozenClass):
                 type_distribution_enforced = init_dict["type_distribution_enforced"]
             if "is_current_harm" in list(init_dict.keys()):
                 is_current_harm = init_dict["is_current_harm"]
+            if "T_mag" in list(init_dict.keys()):
+                T_mag = init_dict["T_mag"]
+            if "is_periodicity_rotor" in list(init_dict.keys()):
+                is_periodicity_rotor = init_dict["is_periodicity_rotor"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.is_remove_slotS = is_remove_slotS
@@ -183,6 +188,8 @@ class Magnetics(FrozenClass):
         self.Nslices_enforced = Nslices_enforced
         self.type_distribution_enforced = type_distribution_enforced
         self.is_current_harm = is_current_harm
+        self.T_mag = T_mag
+        self.is_periodicity_rotor = is_periodicity_rotor
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -227,6 +234,10 @@ class Magnetics(FrozenClass):
             + linesep
         )
         Magnetics_str += "is_current_harm = " + str(self.is_current_harm) + linesep
+        Magnetics_str += "T_mag = " + str(self.T_mag) + linesep
+        Magnetics_str += (
+            "is_periodicity_rotor = " + str(self.is_periodicity_rotor) + linesep
+        )
         return Magnetics_str
 
     def __eq__(self, other):
@@ -268,9 +279,13 @@ class Magnetics(FrozenClass):
             return False
         if other.is_current_harm != self.is_current_harm:
             return False
+        if other.T_mag != self.T_mag:
+            return False
+        if other.is_periodicity_rotor != self.is_periodicity_rotor:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -279,31 +294,175 @@ class Magnetics(FrozenClass):
             return ["type(" + name + ")"]
         diff_list = list()
         if other._is_remove_slotS != self._is_remove_slotS:
-            diff_list.append(name + ".is_remove_slotS")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_remove_slotS)
+                    + ", other="
+                    + str(other._is_remove_slotS)
+                    + ")"
+                )
+                diff_list.append(name + ".is_remove_slotS" + val_str)
+            else:
+                diff_list.append(name + ".is_remove_slotS")
         if other._is_remove_slotR != self._is_remove_slotR:
-            diff_list.append(name + ".is_remove_slotR")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_remove_slotR)
+                    + ", other="
+                    + str(other._is_remove_slotR)
+                    + ")"
+                )
+                diff_list.append(name + ".is_remove_slotR" + val_str)
+            else:
+                diff_list.append(name + ".is_remove_slotR")
         if other._is_remove_ventS != self._is_remove_ventS:
-            diff_list.append(name + ".is_remove_ventS")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_remove_ventS)
+                    + ", other="
+                    + str(other._is_remove_ventS)
+                    + ")"
+                )
+                diff_list.append(name + ".is_remove_ventS" + val_str)
+            else:
+                diff_list.append(name + ".is_remove_ventS")
         if other._is_remove_ventR != self._is_remove_ventR:
-            diff_list.append(name + ".is_remove_ventR")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_remove_ventR)
+                    + ", other="
+                    + str(other._is_remove_ventR)
+                    + ")"
+                )
+                diff_list.append(name + ".is_remove_ventR" + val_str)
+            else:
+                diff_list.append(name + ".is_remove_ventR")
         if other._is_mmfs != self._is_mmfs:
-            diff_list.append(name + ".is_mmfs")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_mmfs)
+                    + ", other="
+                    + str(other._is_mmfs)
+                    + ")"
+                )
+                diff_list.append(name + ".is_mmfs" + val_str)
+            else:
+                diff_list.append(name + ".is_mmfs")
         if other._is_mmfr != self._is_mmfr:
-            diff_list.append(name + ".is_mmfr")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_mmfr)
+                    + ", other="
+                    + str(other._is_mmfr)
+                    + ")"
+                )
+                diff_list.append(name + ".is_mmfr" + val_str)
+            else:
+                diff_list.append(name + ".is_mmfr")
         if other._type_BH_stator != self._type_BH_stator:
-            diff_list.append(name + ".type_BH_stator")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_BH_stator)
+                    + ", other="
+                    + str(other._type_BH_stator)
+                    + ")"
+                )
+                diff_list.append(name + ".type_BH_stator" + val_str)
+            else:
+                diff_list.append(name + ".type_BH_stator")
         if other._type_BH_rotor != self._type_BH_rotor:
-            diff_list.append(name + ".type_BH_rotor")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_BH_rotor)
+                    + ", other="
+                    + str(other._type_BH_rotor)
+                    + ")"
+                )
+                diff_list.append(name + ".type_BH_rotor" + val_str)
+            else:
+                diff_list.append(name + ".type_BH_rotor")
         if other._is_periodicity_t != self._is_periodicity_t:
-            diff_list.append(name + ".is_periodicity_t")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_periodicity_t)
+                    + ", other="
+                    + str(other._is_periodicity_t)
+                    + ")"
+                )
+                diff_list.append(name + ".is_periodicity_t" + val_str)
+            else:
+                diff_list.append(name + ".is_periodicity_t")
         if other._is_periodicity_a != self._is_periodicity_a:
-            diff_list.append(name + ".is_periodicity_a")
-        if other._angle_stator_shift != self._angle_stator_shift:
-            diff_list.append(name + ".angle_stator_shift")
-        if other._angle_rotor_shift != self._angle_rotor_shift:
-            diff_list.append(name + ".angle_rotor_shift")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_periodicity_a)
+                    + ", other="
+                    + str(other._is_periodicity_a)
+                    + ")"
+                )
+                diff_list.append(name + ".is_periodicity_a" + val_str)
+            else:
+                diff_list.append(name + ".is_periodicity_a")
+        if (
+            other._angle_stator_shift is not None
+            and self._angle_stator_shift is not None
+            and isnan(other._angle_stator_shift)
+            and isnan(self._angle_stator_shift)
+        ):
+            pass
+        elif other._angle_stator_shift != self._angle_stator_shift:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._angle_stator_shift)
+                    + ", other="
+                    + str(other._angle_stator_shift)
+                    + ")"
+                )
+                diff_list.append(name + ".angle_stator_shift" + val_str)
+            else:
+                diff_list.append(name + ".angle_stator_shift")
+        if (
+            other._angle_rotor_shift is not None
+            and self._angle_rotor_shift is not None
+            and isnan(other._angle_rotor_shift)
+            and isnan(self._angle_rotor_shift)
+        ):
+            pass
+        elif other._angle_rotor_shift != self._angle_rotor_shift:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._angle_rotor_shift)
+                    + ", other="
+                    + str(other._angle_rotor_shift)
+                    + ")"
+                )
+                diff_list.append(name + ".angle_rotor_shift" + val_str)
+            else:
+                diff_list.append(name + ".angle_rotor_shift")
         if other._logger_name != self._logger_name:
-            diff_list.append(name + ".logger_name")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._logger_name)
+                    + ", other="
+                    + str(other._logger_name)
+                    + ")"
+                )
+                diff_list.append(name + ".logger_name" + val_str)
+            else:
+                diff_list.append(name + ".logger_name")
         if (other.Slice_enforced is None and self.Slice_enforced is not None) or (
             other.Slice_enforced is not None and self.Slice_enforced is None
         ):
@@ -311,15 +470,75 @@ class Magnetics(FrozenClass):
         elif self.Slice_enforced is not None:
             diff_list.extend(
                 self.Slice_enforced.compare(
-                    other.Slice_enforced, name=name + ".Slice_enforced"
+                    other.Slice_enforced,
+                    name=name + ".Slice_enforced",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
                 )
             )
         if other._Nslices_enforced != self._Nslices_enforced:
-            diff_list.append(name + ".Nslices_enforced")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Nslices_enforced)
+                    + ", other="
+                    + str(other._Nslices_enforced)
+                    + ")"
+                )
+                diff_list.append(name + ".Nslices_enforced" + val_str)
+            else:
+                diff_list.append(name + ".Nslices_enforced")
         if other._type_distribution_enforced != self._type_distribution_enforced:
-            diff_list.append(name + ".type_distribution_enforced")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_distribution_enforced)
+                    + ", other="
+                    + str(other._type_distribution_enforced)
+                    + ")"
+                )
+                diff_list.append(name + ".type_distribution_enforced" + val_str)
+            else:
+                diff_list.append(name + ".type_distribution_enforced")
         if other._is_current_harm != self._is_current_harm:
-            diff_list.append(name + ".is_current_harm")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_current_harm)
+                    + ", other="
+                    + str(other._is_current_harm)
+                    + ")"
+                )
+                diff_list.append(name + ".is_current_harm" + val_str)
+            else:
+                diff_list.append(name + ".is_current_harm")
+        if (
+            other._T_mag is not None
+            and self._T_mag is not None
+            and isnan(other._T_mag)
+            and isnan(self._T_mag)
+        ):
+            pass
+        elif other._T_mag != self._T_mag:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._T_mag) + ", other=" + str(other._T_mag) + ")"
+                )
+                diff_list.append(name + ".T_mag" + val_str)
+            else:
+                diff_list.append(name + ".T_mag")
+        if other._is_periodicity_rotor != self._is_periodicity_rotor:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_periodicity_rotor)
+                    + ", other="
+                    + str(other._is_periodicity_rotor)
+                    + ")"
+                )
+                diff_list.append(name + ".is_periodicity_rotor" + val_str)
+            else:
+                diff_list.append(name + ".is_periodicity_rotor")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -345,6 +564,8 @@ class Magnetics(FrozenClass):
         S += getsizeof(self.Nslices_enforced)
         S += getsizeof(self.type_distribution_enforced)
         S += getsizeof(self.is_current_harm)
+        S += getsizeof(self.T_mag)
+        S += getsizeof(self.is_periodicity_rotor)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -383,10 +604,62 @@ class Magnetics(FrozenClass):
         Magnetics_dict["Nslices_enforced"] = self.Nslices_enforced
         Magnetics_dict["type_distribution_enforced"] = self.type_distribution_enforced
         Magnetics_dict["is_current_harm"] = self.is_current_harm
+        Magnetics_dict["T_mag"] = self.T_mag
+        Magnetics_dict["is_periodicity_rotor"] = self.is_periodicity_rotor
         # The class name is added to the dict for deserialisation purpose
         Magnetics_dict["__class__"] = "Magnetics"
         return Magnetics_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        is_remove_slotS_val = self.is_remove_slotS
+        is_remove_slotR_val = self.is_remove_slotR
+        is_remove_ventS_val = self.is_remove_ventS
+        is_remove_ventR_val = self.is_remove_ventR
+        is_mmfs_val = self.is_mmfs
+        is_mmfr_val = self.is_mmfr
+        type_BH_stator_val = self.type_BH_stator
+        type_BH_rotor_val = self.type_BH_rotor
+        is_periodicity_t_val = self.is_periodicity_t
+        is_periodicity_a_val = self.is_periodicity_a
+        angle_stator_shift_val = self.angle_stator_shift
+        angle_rotor_shift_val = self.angle_rotor_shift
+        logger_name_val = self.logger_name
+        if self.Slice_enforced is None:
+            Slice_enforced_val = None
+        else:
+            Slice_enforced_val = self.Slice_enforced.copy()
+        Nslices_enforced_val = self.Nslices_enforced
+        type_distribution_enforced_val = self.type_distribution_enforced
+        is_current_harm_val = self.is_current_harm
+        T_mag_val = self.T_mag
+        is_periodicity_rotor_val = self.is_periodicity_rotor
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            is_remove_slotS=is_remove_slotS_val,
+            is_remove_slotR=is_remove_slotR_val,
+            is_remove_ventS=is_remove_ventS_val,
+            is_remove_ventR=is_remove_ventR_val,
+            is_mmfs=is_mmfs_val,
+            is_mmfr=is_mmfr_val,
+            type_BH_stator=type_BH_stator_val,
+            type_BH_rotor=type_BH_rotor_val,
+            is_periodicity_t=is_periodicity_t_val,
+            is_periodicity_a=is_periodicity_a_val,
+            angle_stator_shift=angle_stator_shift_val,
+            angle_rotor_shift=angle_rotor_shift_val,
+            logger_name=logger_name_val,
+            Slice_enforced=Slice_enforced_val,
+            Nslices_enforced=Nslices_enforced_val,
+            type_distribution_enforced=type_distribution_enforced_val,
+            is_current_harm=is_current_harm_val,
+            T_mag=T_mag_val,
+            is_periodicity_rotor=is_periodicity_rotor_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -408,6 +681,8 @@ class Magnetics(FrozenClass):
         self.Nslices_enforced = None
         self.type_distribution_enforced = None
         self.is_current_harm = None
+        self.T_mag = None
+        self.is_periodicity_rotor = None
 
     def _get_is_remove_slotS(self):
         """getter of is_remove_slotS"""
@@ -654,13 +929,22 @@ class Magnetics(FrozenClass):
     def _set_Slice_enforced(self, value):
         """setter of Slice_enforced"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "Slice_enforced"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            SliceModel = import_class(
+                "pyleecan.Classes", "SliceModel", "Slice_enforced"
+            )
             value = SliceModel()
         check_var("Slice_enforced", value, "SliceModel")
         self._Slice_enforced = value
@@ -730,3 +1014,39 @@ class Magnetics(FrozenClass):
         :Type: bool
         """,
     )
+
+    def _get_T_mag(self):
+        """getter of T_mag"""
+        return self._T_mag
+
+    def _set_T_mag(self, value):
+        """setter of T_mag"""
+        check_var("T_mag", value, "float")
+        self._T_mag = value
+
+    T_mag = property(
+        fget=_get_T_mag,
+        fset=_set_T_mag,
+        doc=u"""Permanent magnet temperature to adapt magnet remanent flux density
+
+        :Type: float
+        """,
+    )
+
+    def _get_is_periodicity_rotor(self):
+        """getter of is_periodicity_rotor"""
+        return self._is_periodicity_rotor
+
+    def _set_is_periodicity_rotor(self, value):
+        """setter of is_periodicity_rotor"""
+        check_var("is_periodicity_rotor", value, "bool")
+        self._is_periodicity_rotor = value
+
+    is_periodicity_rotor = property(
+        fget=_get_is_periodicity_rotor,
+        fset=_set_is_periodicity_rotor,
+        doc=u"""True to consider rotor periodicity over time instead of stator
+
+        :Type: bool
+        """,
+    )
