@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -27,13 +27,22 @@ try:
 except ImportError as error:
     plot_BH = error
 
+try:
+    from ..Methods.Material.MatMagnetics.get_Hc import get_Hc
+except ImportError as error:
+    get_Hc = error
+
+try:
+    from ..Methods.Material.MatMagnetics.get_Brm import get_Brm
+except ImportError as error:
+    get_Brm = error
+
 
 from ..Classes.ImportMatrixVal import ImportMatrixVal
 from numpy import ndarray
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ImportMatrix import ImportMatrix
-from .ModelBH import ModelBH
 
 
 class MatMagnetics(FrozenClass):
@@ -60,16 +69,32 @@ class MatMagnetics(FrozenClass):
         )
     else:
         plot_BH = plot_BH
-    # save and copy methods are available in all object
+    # cf Methods.Material.MatMagnetics.get_Hc
+    if isinstance(get_Hc, ImportError):
+        get_Hc = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MatMagnetics method get_Hc: " + str(get_Hc))
+            )
+        )
+    else:
+        get_Hc = get_Hc
+    # cf Methods.Material.MatMagnetics.get_Brm
+    if isinstance(get_Brm, ImportError):
+        get_Brm = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MatMagnetics method get_Brm: " + str(get_Brm))
+            )
+        )
+    else:
+        get_Brm = get_Brm
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
         self,
         mur_lin=1,
-        Hc=0,
         Brm20=0,
         alpha_Br=0,
         Wlam=0,
@@ -97,8 +122,6 @@ class MatMagnetics(FrozenClass):
             # Overwrite default value with init_dict content
             if "mur_lin" in list(init_dict.keys()):
                 mur_lin = init_dict["mur_lin"]
-            if "Hc" in list(init_dict.keys()):
-                Hc = init_dict["Hc"]
             if "Brm20" in list(init_dict.keys()):
                 Brm20 = init_dict["Brm20"]
             if "alpha_Br" in list(init_dict.keys()):
@@ -116,7 +139,6 @@ class MatMagnetics(FrozenClass):
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.mur_lin = mur_lin
-        self.Hc = Hc
         self.Brm20 = Brm20
         self.alpha_Br = alpha_Br
         self.Wlam = Wlam
@@ -139,7 +161,6 @@ class MatMagnetics(FrozenClass):
                 "parent = " + str(type(self.parent)) + " object" + linesep
             )
         MatMagnetics_str += "mur_lin = " + str(self.mur_lin) + linesep
-        MatMagnetics_str += "Hc = " + str(self.Hc) + linesep
         MatMagnetics_str += "Brm20 = " + str(self.Brm20) + linesep
         MatMagnetics_str += "alpha_Br = " + str(self.alpha_Br) + linesep
         MatMagnetics_str += "Wlam = " + str(self.Wlam) + linesep
@@ -170,8 +191,6 @@ class MatMagnetics(FrozenClass):
             return False
         if other.mur_lin != self.mur_lin:
             return False
-        if other.Hc != self.Hc:
-            return False
         if other.Brm20 != self.Brm20:
             return False
         if other.alpha_Br != self.alpha_Br:
@@ -188,7 +207,7 @@ class MatMagnetics(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -196,23 +215,86 @@ class MatMagnetics(FrozenClass):
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
-        if other._mur_lin != self._mur_lin:
-            diff_list.append(name + ".mur_lin")
-        if other._Hc != self._Hc:
-            diff_list.append(name + ".Hc")
-        if other._Brm20 != self._Brm20:
-            diff_list.append(name + ".Brm20")
-        if other._alpha_Br != self._alpha_Br:
-            diff_list.append(name + ".alpha_Br")
-        if other._Wlam != self._Wlam:
-            diff_list.append(name + ".Wlam")
+        if (
+            other._mur_lin is not None
+            and self._mur_lin is not None
+            and isnan(other._mur_lin)
+            and isnan(self._mur_lin)
+        ):
+            pass
+        elif other._mur_lin != self._mur_lin:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._mur_lin)
+                    + ", other="
+                    + str(other._mur_lin)
+                    + ")"
+                )
+                diff_list.append(name + ".mur_lin" + val_str)
+            else:
+                diff_list.append(name + ".mur_lin")
+        if (
+            other._Brm20 is not None
+            and self._Brm20 is not None
+            and isnan(other._Brm20)
+            and isnan(self._Brm20)
+        ):
+            pass
+        elif other._Brm20 != self._Brm20:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Brm20) + ", other=" + str(other._Brm20) + ")"
+                )
+                diff_list.append(name + ".Brm20" + val_str)
+            else:
+                diff_list.append(name + ".Brm20")
+        if (
+            other._alpha_Br is not None
+            and self._alpha_Br is not None
+            and isnan(other._alpha_Br)
+            and isnan(self._alpha_Br)
+        ):
+            pass
+        elif other._alpha_Br != self._alpha_Br:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._alpha_Br)
+                    + ", other="
+                    + str(other._alpha_Br)
+                    + ")"
+                )
+                diff_list.append(name + ".alpha_Br" + val_str)
+            else:
+                diff_list.append(name + ".alpha_Br")
+        if (
+            other._Wlam is not None
+            and self._Wlam is not None
+            and isnan(other._Wlam)
+            and isnan(self._Wlam)
+        ):
+            pass
+        elif other._Wlam != self._Wlam:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Wlam) + ", other=" + str(other._Wlam) + ")"
+                )
+                diff_list.append(name + ".Wlam" + val_str)
+            else:
+                diff_list.append(name + ".Wlam")
         if (other.BH_curve is None and self.BH_curve is not None) or (
             other.BH_curve is not None and self.BH_curve is None
         ):
             diff_list.append(name + ".BH_curve None mismatch")
         elif self.BH_curve is not None:
             diff_list.extend(
-                self.BH_curve.compare(other.BH_curve, name=name + ".BH_curve")
+                self.BH_curve.compare(
+                    other.BH_curve,
+                    name=name + ".BH_curve",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if (other.LossData is None and self.LossData is not None) or (
             other.LossData is not None and self.LossData is None
@@ -220,7 +302,12 @@ class MatMagnetics(FrozenClass):
             diff_list.append(name + ".LossData None mismatch")
         elif self.LossData is not None:
             diff_list.extend(
-                self.LossData.compare(other.LossData, name=name + ".LossData")
+                self.LossData.compare(
+                    other.LossData,
+                    name=name + ".LossData",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if (other.ModelBH is None and self.ModelBH is not None) or (
             other.ModelBH is not None and self.ModelBH is None
@@ -228,10 +315,25 @@ class MatMagnetics(FrozenClass):
             diff_list.append(name + ".ModelBH None mismatch")
         elif self.ModelBH is not None:
             diff_list.extend(
-                self.ModelBH.compare(other.ModelBH, name=name + ".ModelBH")
+                self.ModelBH.compare(
+                    other.ModelBH,
+                    name=name + ".ModelBH",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if other._is_BH_extrapolate != self._is_BH_extrapolate:
-            diff_list.append(name + ".is_BH_extrapolate")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_BH_extrapolate)
+                    + ", other="
+                    + str(other._is_BH_extrapolate)
+                    + ")"
+                )
+                diff_list.append(name + ".is_BH_extrapolate" + val_str)
+            else:
+                diff_list.append(name + ".is_BH_extrapolate")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -241,7 +343,6 @@ class MatMagnetics(FrozenClass):
 
         S = 0  # Full size of the object
         S += getsizeof(self.mur_lin)
-        S += getsizeof(self.Hc)
         S += getsizeof(self.Brm20)
         S += getsizeof(self.alpha_Br)
         S += getsizeof(self.Wlam)
@@ -264,7 +365,6 @@ class MatMagnetics(FrozenClass):
 
         MatMagnetics_dict = dict()
         MatMagnetics_dict["mur_lin"] = self.mur_lin
-        MatMagnetics_dict["Hc"] = self.Hc
         MatMagnetics_dict["Brm20"] = self.Brm20
         MatMagnetics_dict["alpha_Br"] = self.alpha_Br
         MatMagnetics_dict["Wlam"] = self.Wlam
@@ -297,11 +397,44 @@ class MatMagnetics(FrozenClass):
         MatMagnetics_dict["__class__"] = "MatMagnetics"
         return MatMagnetics_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        mur_lin_val = self.mur_lin
+        Brm20_val = self.Brm20
+        alpha_Br_val = self.alpha_Br
+        Wlam_val = self.Wlam
+        if self.BH_curve is None:
+            BH_curve_val = None
+        else:
+            BH_curve_val = self.BH_curve.copy()
+        if self.LossData is None:
+            LossData_val = None
+        else:
+            LossData_val = self.LossData.copy()
+        if self.ModelBH is None:
+            ModelBH_val = None
+        else:
+            ModelBH_val = self.ModelBH.copy()
+        is_BH_extrapolate_val = self.is_BH_extrapolate
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            mur_lin=mur_lin_val,
+            Brm20=Brm20_val,
+            alpha_Br=alpha_Br_val,
+            Wlam=Wlam_val,
+            BH_curve=BH_curve_val,
+            LossData=LossData_val,
+            ModelBH=ModelBH_val,
+            is_BH_extrapolate=is_BH_extrapolate_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
         self.mur_lin = None
-        self.Hc = None
         self.Brm20 = None
         self.alpha_Br = None
         self.Wlam = None
@@ -332,25 +465,6 @@ class MatMagnetics(FrozenClass):
         """,
     )
 
-    def _get_Hc(self):
-        """getter of Hc"""
-        return self._Hc
-
-    def _set_Hc(self, value):
-        """setter of Hc"""
-        check_var("Hc", value, "float", Vmin=0)
-        self._Hc = value
-
-    Hc = property(
-        fget=_get_Hc,
-        fset=_set_Hc,
-        doc=u"""Coercitivity field
-
-        :Type: float
-        :min: 0
-        """,
-    )
-
     def _get_Brm20(self):
         """getter of Brm20"""
         return self._Brm20
@@ -363,7 +477,7 @@ class MatMagnetics(FrozenClass):
     Brm20 = property(
         fget=_get_Brm20,
         fset=_set_Brm20,
-        doc=u"""magnet remanence induction at 20degC
+        doc=u"""magnet remanence induction at 20degC (calculated from mur_lin and Hc if not provided)
 
         :Type: float
         """,
@@ -412,6 +526,10 @@ class MatMagnetics(FrozenClass):
 
     def _set_BH_curve(self, value):
         """setter of BH_curve"""
+        ImportMatrix = import_class("pyleecan.Classes", "ImportMatrix", "BH_curve")
+        ImportMatrixVal = import_class(
+            "pyleecan.Classes", "ImportMatrixVal", "BH_curve"
+        )
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, ndarray):
@@ -446,6 +564,10 @@ class MatMagnetics(FrozenClass):
 
     def _set_LossData(self, value):
         """setter of LossData"""
+        ImportMatrix = import_class("pyleecan.Classes", "ImportMatrix", "LossData")
+        ImportMatrixVal = import_class(
+            "pyleecan.Classes", "ImportMatrixVal", "LossData"
+        )
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, ndarray):
@@ -481,13 +603,20 @@ class MatMagnetics(FrozenClass):
     def _set_ModelBH(self, value):
         """setter of ModelBH"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "ModelBH"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            ModelBH = import_class("pyleecan.Classes", "ModelBH", "ModelBH")
             value = ModelBH()
         check_var("ModelBH", value, "ModelBH")
         self._ModelBH = value
