@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .OptiSolver import OptiSolver
 
 from ntpath import basename
@@ -20,9 +20,8 @@ from os.path import isfile
 from ._check import CheckTypeError
 import numpy as np
 import random
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .OptiProblem import OptiProblem
-from .XOutput import XOutput
 
 
 class OptiGenAlg(OptiSolver):
@@ -30,9 +29,8 @@ class OptiGenAlg(OptiSolver):
 
     VERSION = 1
 
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -162,7 +160,7 @@ class OptiGenAlg(OptiSolver):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -172,21 +170,79 @@ class OptiGenAlg(OptiSolver):
         diff_list = list()
 
         # Check the properties inherited from OptiSolver
-        diff_list.extend(super(OptiGenAlg, self).compare(other, name=name))
+        diff_list.extend(
+            super(OptiGenAlg, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._selector_str != self._selector_str:
             diff_list.append(name + ".selector")
         if other._crossover_str != self._crossover_str:
             diff_list.append(name + ".crossover")
         if other._mutator_str != self._mutator_str:
             diff_list.append(name + ".mutator")
-        if other._p_cross != self._p_cross:
-            diff_list.append(name + ".p_cross")
-        if other._p_mutate != self._p_mutate:
-            diff_list.append(name + ".p_mutate")
+        if (
+            other._p_cross is not None
+            and self._p_cross is not None
+            and isnan(other._p_cross)
+            and isnan(self._p_cross)
+        ):
+            pass
+        elif other._p_cross != self._p_cross:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._p_cross)
+                    + ", other="
+                    + str(other._p_cross)
+                    + ")"
+                )
+                diff_list.append(name + ".p_cross" + val_str)
+            else:
+                diff_list.append(name + ".p_cross")
+        if (
+            other._p_mutate is not None
+            and self._p_mutate is not None
+            and isnan(other._p_mutate)
+            and isnan(self._p_mutate)
+        ):
+            pass
+        elif other._p_mutate != self._p_mutate:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._p_mutate)
+                    + ", other="
+                    + str(other._p_mutate)
+                    + ")"
+                )
+                diff_list.append(name + ".p_mutate" + val_str)
+            else:
+                diff_list.append(name + ".p_mutate")
         if other._size_pop != self._size_pop:
-            diff_list.append(name + ".size_pop")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._size_pop)
+                    + ", other="
+                    + str(other._size_pop)
+                    + ")"
+                )
+                diff_list.append(name + ".size_pop" + val_str)
+            else:
+                diff_list.append(name + ".size_pop")
         if other._nb_gen != self._nb_gen:
-            diff_list.append(name + ".nb_gen")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._nb_gen)
+                    + ", other="
+                    + str(other._nb_gen)
+                    + ")"
+                )
+                diff_list.append(name + ".nb_gen" + val_str)
+            else:
+                diff_list.append(name + ".nb_gen")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -226,7 +282,7 @@ class OptiGenAlg(OptiSolver):
         )
         if self._selector_str is not None:
             OptiGenAlg_dict["selector"] = self._selector_str
-        elif "keep_function" in kwargs and kwargs["keep_function"]:
+        elif keep_function:
             OptiGenAlg_dict["selector"] = self.selector
         else:
             OptiGenAlg_dict["selector"] = None
@@ -238,7 +294,7 @@ class OptiGenAlg(OptiSolver):
                 )
         if self._crossover_str is not None:
             OptiGenAlg_dict["crossover"] = self._crossover_str
-        elif "keep_function" in kwargs and kwargs["keep_function"]:
+        elif keep_function:
             OptiGenAlg_dict["crossover"] = self.crossover
         else:
             OptiGenAlg_dict["crossover"] = None
@@ -250,7 +306,7 @@ class OptiGenAlg(OptiSolver):
                 )
         if self._mutator_str is not None:
             OptiGenAlg_dict["mutator"] = self._mutator_str
-        elif "keep_function" in kwargs and kwargs["keep_function"]:
+        elif keep_function:
             OptiGenAlg_dict["mutator"] = self.mutator
         else:
             OptiGenAlg_dict["mutator"] = None
@@ -269,6 +325,52 @@ class OptiGenAlg(OptiSolver):
         OptiGenAlg_dict["__class__"] = "OptiGenAlg"
         return OptiGenAlg_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self._selector_str is not None:
+            selector_val = self._selector_str
+        else:
+            selector_val = self._selector_func
+        if self._crossover_str is not None:
+            crossover_val = self._crossover_str
+        else:
+            crossover_val = self._crossover_func
+        if self._mutator_str is not None:
+            mutator_val = self._mutator_str
+        else:
+            mutator_val = self._mutator_func
+        p_cross_val = self.p_cross
+        p_mutate_val = self.p_mutate
+        size_pop_val = self.size_pop
+        nb_gen_val = self.nb_gen
+        if self.problem is None:
+            problem_val = None
+        else:
+            problem_val = self.problem.copy()
+        if self.xoutput is None:
+            xoutput_val = None
+        else:
+            xoutput_val = self.xoutput.copy()
+        logger_name_val = self.logger_name
+        is_keep_all_output_val = self.is_keep_all_output
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            selector=selector_val,
+            crossover=crossover_val,
+            mutator=mutator_val,
+            p_cross=p_cross_val,
+            p_mutate=p_mutate_val,
+            size_pop=size_pop_val,
+            nb_gen=nb_gen_val,
+            problem=problem_val,
+            xoutput=xoutput_val,
+            logger_name=logger_name_val,
+            is_keep_all_output=is_keep_all_output_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
