@@ -10,13 +10,13 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .OutGeoLam import OutGeoLam
 
 
 class OutGeo(FrozenClass):
@@ -24,9 +24,8 @@ class OutGeo(FrozenClass):
 
     VERSION = 1
 
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -193,7 +192,7 @@ class OutGeo(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -206,35 +205,186 @@ class OutGeo(FrozenClass):
         ):
             diff_list.append(name + ".stator None mismatch")
         elif self.stator is not None:
-            diff_list.extend(self.stator.compare(other.stator, name=name + ".stator"))
+            diff_list.extend(
+                self.stator.compare(
+                    other.stator,
+                    name=name + ".stator",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if (other.rotor is None and self.rotor is not None) or (
             other.rotor is not None and self.rotor is None
         ):
             diff_list.append(name + ".rotor None mismatch")
         elif self.rotor is not None:
-            diff_list.extend(self.rotor.compare(other.rotor, name=name + ".rotor"))
-        if other._Wgap_mec != self._Wgap_mec:
-            diff_list.append(name + ".Wgap_mec")
-        if other._Wgap_mag != self._Wgap_mag:
-            diff_list.append(name + ".Wgap_mag")
-        if other._Rgap_mec != self._Rgap_mec:
-            diff_list.append(name + ".Rgap_mec")
-        if other._Lgap != self._Lgap:
-            diff_list.append(name + ".Lgap")
+            diff_list.extend(
+                self.rotor.compare(
+                    other.rotor,
+                    name=name + ".rotor",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
+        if (
+            other._Wgap_mec is not None
+            and self._Wgap_mec is not None
+            and isnan(other._Wgap_mec)
+            and isnan(self._Wgap_mec)
+        ):
+            pass
+        elif other._Wgap_mec != self._Wgap_mec:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Wgap_mec)
+                    + ", other="
+                    + str(other._Wgap_mec)
+                    + ")"
+                )
+                diff_list.append(name + ".Wgap_mec" + val_str)
+            else:
+                diff_list.append(name + ".Wgap_mec")
+        if (
+            other._Wgap_mag is not None
+            and self._Wgap_mag is not None
+            and isnan(other._Wgap_mag)
+            and isnan(self._Wgap_mag)
+        ):
+            pass
+        elif other._Wgap_mag != self._Wgap_mag:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Wgap_mag)
+                    + ", other="
+                    + str(other._Wgap_mag)
+                    + ")"
+                )
+                diff_list.append(name + ".Wgap_mag" + val_str)
+            else:
+                diff_list.append(name + ".Wgap_mag")
+        if (
+            other._Rgap_mec is not None
+            and self._Rgap_mec is not None
+            and isnan(other._Rgap_mec)
+            and isnan(self._Rgap_mec)
+        ):
+            pass
+        elif other._Rgap_mec != self._Rgap_mec:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Rgap_mec)
+                    + ", other="
+                    + str(other._Rgap_mec)
+                    + ")"
+                )
+                diff_list.append(name + ".Rgap_mec" + val_str)
+            else:
+                diff_list.append(name + ".Rgap_mec")
+        if (
+            other._Lgap is not None
+            and self._Lgap is not None
+            and isnan(other._Lgap)
+            and isnan(self._Lgap)
+        ):
+            pass
+        elif other._Lgap != self._Lgap:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Lgap) + ", other=" + str(other._Lgap) + ")"
+                )
+                diff_list.append(name + ".Lgap" + val_str)
+            else:
+                diff_list.append(name + ".Lgap")
         if other._logger_name != self._logger_name:
-            diff_list.append(name + ".logger_name")
-        if other._angle_rotor_initial != self._angle_rotor_initial:
-            diff_list.append(name + ".angle_rotor_initial")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._logger_name)
+                    + ", other="
+                    + str(other._logger_name)
+                    + ")"
+                )
+                diff_list.append(name + ".logger_name" + val_str)
+            else:
+                diff_list.append(name + ".logger_name")
+        if (
+            other._angle_rotor_initial is not None
+            and self._angle_rotor_initial is not None
+            and isnan(other._angle_rotor_initial)
+            and isnan(self._angle_rotor_initial)
+        ):
+            pass
+        elif other._angle_rotor_initial != self._angle_rotor_initial:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._angle_rotor_initial)
+                    + ", other="
+                    + str(other._angle_rotor_initial)
+                    + ")"
+                )
+                diff_list.append(name + ".angle_rotor_initial" + val_str)
+            else:
+                diff_list.append(name + ".angle_rotor_initial")
         if other._rot_dir != self._rot_dir:
-            diff_list.append(name + ".rot_dir")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._rot_dir)
+                    + ", other="
+                    + str(other._rot_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".rot_dir" + val_str)
+            else:
+                diff_list.append(name + ".rot_dir")
         if other._per_a != self._per_a:
-            diff_list.append(name + ".per_a")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._per_a) + ", other=" + str(other._per_a) + ")"
+                )
+                diff_list.append(name + ".per_a" + val_str)
+            else:
+                diff_list.append(name + ".per_a")
         if other._is_antiper_a != self._is_antiper_a:
-            diff_list.append(name + ".is_antiper_a")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_antiper_a)
+                    + ", other="
+                    + str(other._is_antiper_a)
+                    + ")"
+                )
+                diff_list.append(name + ".is_antiper_a" + val_str)
+            else:
+                diff_list.append(name + ".is_antiper_a")
         if other._per_t_S != self._per_t_S:
-            diff_list.append(name + ".per_t_S")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._per_t_S)
+                    + ", other="
+                    + str(other._per_t_S)
+                    + ")"
+                )
+                diff_list.append(name + ".per_t_S" + val_str)
+            else:
+                diff_list.append(name + ".per_t_S")
         if other._is_antiper_t_S != self._is_antiper_t_S:
-            diff_list.append(name + ".is_antiper_t_S")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_antiper_t_S)
+                    + ", other="
+                    + str(other._is_antiper_t_S)
+                    + ")"
+                )
+                diff_list.append(name + ".is_antiper_t_S" + val_str)
+            else:
+                diff_list.append(name + ".is_antiper_t_S")
         if (other.axes_dict is None and self.axes_dict is not None) or (
             other.axes_dict is not None and self.axes_dict is None
         ):
@@ -247,13 +397,36 @@ class OutGeo(FrozenClass):
             for key in self.axes_dict:
                 diff_list.extend(
                     self.axes_dict[key].compare(
-                        other.axes_dict[key], name=name + ".axes_dict"
+                        other.axes_dict[key],
+                        name=name + ".axes_dict[" + str(key) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._per_t_R != self._per_t_R:
-            diff_list.append(name + ".per_t_R")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._per_t_R)
+                    + ", other="
+                    + str(other._per_t_R)
+                    + ")"
+                )
+                diff_list.append(name + ".per_t_R" + val_str)
+            else:
+                diff_list.append(name + ".per_t_R")
         if other._is_antiper_t_R != self._is_antiper_t_R:
-            diff_list.append(name + ".is_antiper_t_R")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_antiper_t_R)
+                    + ", other="
+                    + str(other._is_antiper_t_R)
+                    + ")"
+                )
+                diff_list.append(name + ".is_antiper_t_R" + val_str)
+            else:
+                diff_list.append(name + ".is_antiper_t_R")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -340,6 +513,58 @@ class OutGeo(FrozenClass):
         OutGeo_dict["__class__"] = "OutGeo"
         return OutGeo_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.stator is None:
+            stator_val = None
+        else:
+            stator_val = self.stator.copy()
+        if self.rotor is None:
+            rotor_val = None
+        else:
+            rotor_val = self.rotor.copy()
+        Wgap_mec_val = self.Wgap_mec
+        Wgap_mag_val = self.Wgap_mag
+        Rgap_mec_val = self.Rgap_mec
+        Lgap_val = self.Lgap
+        logger_name_val = self.logger_name
+        angle_rotor_initial_val = self.angle_rotor_initial
+        rot_dir_val = self.rot_dir
+        per_a_val = self.per_a
+        is_antiper_a_val = self.is_antiper_a
+        per_t_S_val = self.per_t_S
+        is_antiper_t_S_val = self.is_antiper_t_S
+        if self.axes_dict is None:
+            axes_dict_val = None
+        else:
+            axes_dict_val = dict()
+            for key, obj in self.axes_dict.items():
+                axes_dict_val[key] = obj.copy()
+        per_t_R_val = self.per_t_R
+        is_antiper_t_R_val = self.is_antiper_t_R
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            stator=stator_val,
+            rotor=rotor_val,
+            Wgap_mec=Wgap_mec_val,
+            Wgap_mag=Wgap_mag_val,
+            Rgap_mec=Rgap_mec_val,
+            Lgap=Lgap_val,
+            logger_name=logger_name_val,
+            angle_rotor_initial=angle_rotor_initial_val,
+            rot_dir=rot_dir_val,
+            per_a=per_a_val,
+            is_antiper_a=is_antiper_a_val,
+            per_t_S=per_t_S_val,
+            is_antiper_t_S=is_antiper_t_S_val,
+            axes_dict=axes_dict_val,
+            per_t_R=per_t_R_val,
+            is_antiper_t_R=is_antiper_t_R_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -369,13 +594,20 @@ class OutGeo(FrozenClass):
     def _set_stator(self, value):
         """setter of stator"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "stator"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            OutGeoLam = import_class("pyleecan.Classes", "OutGeoLam", "stator")
             value = OutGeoLam()
         check_var("stator", value, "OutGeoLam")
         self._stator = value
@@ -399,13 +631,20 @@ class OutGeo(FrozenClass):
     def _set_rotor(self, value):
         """setter of rotor"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "rotor"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            OutGeoLam = import_class("pyleecan.Classes", "OutGeoLam", "rotor")
             value = OutGeoLam()
         check_var("rotor", value, "OutGeoLam")
         self._rotor = value
@@ -634,6 +873,15 @@ class OutGeo(FrozenClass):
         """setter of axes_dict"""
         if type(value) is dict:
             for key, obj in value.items():
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[key] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "SciDataTool.Classes", obj.get("__class__"), "axes_dict"
