@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .OutInternal import OutInternal
 
 # Import all class method
@@ -23,8 +23,8 @@ except ImportError as error:
     clean = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from ._FEMMHandler import _FEMMHandler
 
 
 class OutMagFEMM(OutInternal):
@@ -41,9 +41,8 @@ class OutMagFEMM(OutInternal):
         )
     else:
         clean = clean
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -109,7 +108,7 @@ class OutMagFEMM(OutInternal):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -119,9 +118,23 @@ class OutMagFEMM(OutInternal):
         diff_list = list()
 
         # Check the properties inherited from OutInternal
-        diff_list.extend(super(OutMagFEMM, self).compare(other, name=name))
+        diff_list.extend(
+            super(OutMagFEMM, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._FEMM_dict != self._FEMM_dict:
-            diff_list.append(name + ".FEMM_dict")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._FEMM_dict)
+                    + ", other="
+                    + str(other._FEMM_dict)
+                    + ")"
+                )
+                diff_list.append(name + ".FEMM_dict" + val_str)
+            else:
+                diff_list.append(name + ".FEMM_dict")
         if (other.handler_list is None and self.handler_list is not None) or (
             other.handler_list is not None and self.handler_list is None
         ):
@@ -136,6 +149,8 @@ class OutMagFEMM(OutInternal):
                     self.handler_list[ii].compare(
                         other.handler_list[ii],
                         name=name + ".handler_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         # Filter ignore differences
@@ -197,6 +212,24 @@ class OutMagFEMM(OutInternal):
         OutMagFEMM_dict["__class__"] = "OutMagFEMM"
         return OutMagFEMM_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.FEMM_dict is None:
+            FEMM_dict_val = None
+        else:
+            FEMM_dict_val = self.FEMM_dict.copy()
+        if self.handler_list is None:
+            handler_list_val = None
+        else:
+            handler_list_val = list()
+            for obj in self.handler_list:
+                handler_list_val.append(obj.copy())
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(FEMM_dict=FEMM_dict_val, handler_list=handler_list_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -237,6 +270,15 @@ class OutMagFEMM(OutInternal):
         """setter of handler_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "handler_list"
