@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .RefCell import RefCell
 
 # Import all class method
@@ -48,6 +48,7 @@ except ImportError as error:
     is_inside = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -124,9 +125,8 @@ class RefTriangle6(RefCell):
         )
     else:
         is_inside = is_inside
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -173,7 +173,7 @@ class RefTriangle6(RefCell):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -183,7 +183,11 @@ class RefTriangle6(RefCell):
         diff_list = list()
 
         # Check the properties inherited from RefCell
-        diff_list.extend(super(RefTriangle6, self).compare(other, name=name))
+        diff_list.extend(
+            super(RefTriangle6, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -219,6 +223,15 @@ class RefTriangle6(RefCell):
         RefTriangle6_dict["__class__"] = "RefTriangle6"
         return RefTriangle6_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        epsilon_val = self.epsilon
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(epsilon=epsilon_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
