@@ -10,23 +10,33 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Slot import Slot
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.SlotCirc._comp_line_dict import _comp_line_dict
+except ImportError as error:
+    _comp_line_dict = error
+
+try:
+    from ..Methods.Slot.SlotCirc._comp_point_coordinate import _comp_point_coordinate
+except ImportError as error:
+    _comp_point_coordinate = error
+
+try:
+    from ..Methods.Slot.SlotCirc._comp_R0 import _comp_R0
+except ImportError as error:
+    _comp_R0 = error
+
 try:
     from ..Methods.Slot.SlotCirc.build_geometry import build_geometry
 except ImportError as error:
     build_geometry = error
 
-try:
-    from ..Methods.Slot.SlotCirc.get_surface_active import get_surface_active
-except ImportError as error:
-    get_surface_active = error
-
 try:
     from ..Methods.Slot.SlotCirc.check import check
 except ImportError as error:
@@ -57,7 +67,28 @@ try:
 except ImportError as error:
     comp_surface_active = error
 
+try:
+    from ..Methods.Slot.SlotCirc.comp_surface_opening import comp_surface_opening
+except ImportError as error:
+    comp_surface_opening = error
 
+try:
+    from ..Methods.Slot.SlotCirc.get_surface_active import get_surface_active
+except ImportError as error:
+    get_surface_active = error
+
+try:
+    from ..Methods.Slot.SlotCirc.get_surface_opening import get_surface_opening
+except ImportError as error:
+    get_surface_opening = error
+
+try:
+    from ..Methods.Slot.SlotCirc.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -68,6 +99,38 @@ class SlotCirc(Slot):
     IS_SYMMETRICAL = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.SlotCirc._comp_line_dict
+    if isinstance(_comp_line_dict, ImportError):
+        _comp_line_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method _comp_line_dict: " + str(_comp_line_dict)
+                )
+            )
+        )
+    else:
+        _comp_line_dict = _comp_line_dict
+    # cf Methods.Slot.SlotCirc._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
+    # cf Methods.Slot.SlotCirc._comp_R0
+    if isinstance(_comp_R0, ImportError):
+        _comp_R0 = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use SlotCirc method _comp_R0: " + str(_comp_R0))
+            )
+        )
+    else:
+        _comp_R0 = _comp_R0
     # cf Methods.Slot.SlotCirc.build_geometry
     if isinstance(build_geometry, ImportError):
         build_geometry = property(
@@ -79,18 +142,6 @@ class SlotCirc(Slot):
         )
     else:
         build_geometry = build_geometry
-    # cf Methods.Slot.SlotCirc.get_surface_active
-    if isinstance(get_surface_active, ImportError):
-        get_surface_active = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use SlotCirc method get_surface_active: "
-                    + str(get_surface_active)
-                )
-            )
-        )
-    else:
-        get_surface_active = get_surface_active
     # cf Methods.Slot.SlotCirc.check
     if isinstance(check, ImportError):
         check = property(
@@ -158,13 +209,68 @@ class SlotCirc(Slot):
         )
     else:
         comp_surface_active = comp_surface_active
-    # save and copy methods are available in all object
+    # cf Methods.Slot.SlotCirc.comp_surface_opening
+    if isinstance(comp_surface_opening, ImportError):
+        comp_surface_opening = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method comp_surface_opening: "
+                    + str(comp_surface_opening)
+                )
+            )
+        )
+    else:
+        comp_surface_opening = comp_surface_opening
+    # cf Methods.Slot.SlotCirc.get_surface_active
+    if isinstance(get_surface_active, ImportError):
+        get_surface_active = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method get_surface_active: "
+                    + str(get_surface_active)
+                )
+            )
+        )
+    else:
+        get_surface_active = get_surface_active
+    # cf Methods.Slot.SlotCirc.get_surface_opening
+    if isinstance(get_surface_opening, ImportError):
+        get_surface_opening = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method get_surface_opening: "
+                    + str(get_surface_opening)
+                )
+            )
+        )
+    else:
+        get_surface_opening = get_surface_opening
+    # cf Methods.Slot.SlotCirc.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotCirc method plot_schematics: " + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(self, W0=0.01, H0=0.03, Zs=36, init_dict=None, init_str=None):
+    def __init__(
+        self,
+        W0=0.01,
+        H0=0.03,
+        Zs=36,
+        wedge_mat=None,
+        is_bore=True,
+        init_dict=None,
+        init_str=None,
+    ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
@@ -186,11 +292,15 @@ class SlotCirc(Slot):
                 H0 = init_dict["H0"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
+            if "wedge_mat" in list(init_dict.keys()):
+                wedge_mat = init_dict["wedge_mat"]
+            if "is_bore" in list(init_dict.keys()):
+                is_bore = init_dict["is_bore"]
         # Set the properties (value check and convertion are done in setter)
         self.W0 = W0
         self.H0 = H0
         # Call Slot init
-        super(SlotCirc, self).__init__(Zs=Zs)
+        super(SlotCirc, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
@@ -219,7 +329,7 @@ class SlotCirc(Slot):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -229,11 +339,37 @@ class SlotCirc(Slot):
         diff_list = list()
 
         # Check the properties inherited from Slot
-        diff_list.extend(super(SlotCirc, self).compare(other, name=name))
-        if other._W0 != self._W0:
-            diff_list.append(name + ".W0")
-        if other._H0 != self._H0:
-            diff_list.append(name + ".H0")
+        diff_list.extend(
+            super(SlotCirc, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._W0 is not None
+            and self._W0 is not None
+            and isnan(other._W0)
+            and isnan(self._W0)
+        ):
+            pass
+        elif other._W0 != self._W0:
+            if is_add_value:
+                val_str = " (self=" + str(self._W0) + ", other=" + str(other._W0) + ")"
+                diff_list.append(name + ".W0" + val_str)
+            else:
+                diff_list.append(name + ".W0")
+        if (
+            other._H0 is not None
+            and self._H0 is not None
+            and isnan(other._H0)
+            and isnan(self._H0)
+        ):
+            pass
+        elif other._H0 != self._H0:
+            if is_add_value:
+                val_str = " (self=" + str(self._H0) + ", other=" + str(other._H0) + ")"
+                diff_list.append(name + ".H0" + val_str)
+            else:
+                diff_list.append(name + ".H0")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -273,6 +409,28 @@ class SlotCirc(Slot):
         SlotCirc_dict["__class__"] = "SlotCirc"
         return SlotCirc_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        W0_val = self.W0
+        H0_val = self.H0
+        Zs_val = self.Zs
+        if self.wedge_mat is None:
+            wedge_mat_val = None
+        else:
+            wedge_mat_val = self.wedge_mat.copy()
+        is_bore_val = self.is_bore
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            W0=W0_val,
+            H0=H0_val,
+            Zs=Zs_val,
+            wedge_mat=wedge_mat_val,
+            is_bore=is_bore_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
