@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Slot import Slot
 
 # Import all class method
@@ -63,6 +63,7 @@ except ImportError as error:
     comp_surface_active = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -173,9 +174,8 @@ class SlotDC(Slot):
         )
     else:
         comp_surface_active = comp_surface_active
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -190,6 +190,8 @@ class SlotDC(Slot):
         H3=0.001,
         R3=0.001,
         Zs=36,
+        wedge_mat=None,
+        is_bore=True,
         init_dict=None,
         init_str=None,
     ):
@@ -226,6 +228,10 @@ class SlotDC(Slot):
                 R3 = init_dict["R3"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
+            if "wedge_mat" in list(init_dict.keys()):
+                wedge_mat = init_dict["wedge_mat"]
+            if "is_bore" in list(init_dict.keys()):
+                is_bore = init_dict["is_bore"]
         # Set the properties (value check and convertion are done in setter)
         self.W1 = W1
         self.H1 = H1
@@ -236,7 +242,7 @@ class SlotDC(Slot):
         self.H3 = H3
         self.R3 = R3
         # Call Slot init
-        super(SlotDC, self).__init__(Zs=Zs)
+        super(SlotDC, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
@@ -283,7 +289,7 @@ class SlotDC(Slot):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -293,23 +299,115 @@ class SlotDC(Slot):
         diff_list = list()
 
         # Check the properties inherited from Slot
-        diff_list.extend(super(SlotDC, self).compare(other, name=name))
-        if other._W1 != self._W1:
-            diff_list.append(name + ".W1")
-        if other._H1 != self._H1:
-            diff_list.append(name + ".H1")
-        if other._D1 != self._D1:
-            diff_list.append(name + ".D1")
-        if other._W2 != self._W2:
-            diff_list.append(name + ".W2")
-        if other._H2 != self._H2:
-            diff_list.append(name + ".H2")
-        if other._D2 != self._D2:
-            diff_list.append(name + ".D2")
-        if other._H3 != self._H3:
-            diff_list.append(name + ".H3")
-        if other._R3 != self._R3:
-            diff_list.append(name + ".R3")
+        diff_list.extend(
+            super(SlotDC, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._W1 is not None
+            and self._W1 is not None
+            and isnan(other._W1)
+            and isnan(self._W1)
+        ):
+            pass
+        elif other._W1 != self._W1:
+            if is_add_value:
+                val_str = " (self=" + str(self._W1) + ", other=" + str(other._W1) + ")"
+                diff_list.append(name + ".W1" + val_str)
+            else:
+                diff_list.append(name + ".W1")
+        if (
+            other._H1 is not None
+            and self._H1 is not None
+            and isnan(other._H1)
+            and isnan(self._H1)
+        ):
+            pass
+        elif other._H1 != self._H1:
+            if is_add_value:
+                val_str = " (self=" + str(self._H1) + ", other=" + str(other._H1) + ")"
+                diff_list.append(name + ".H1" + val_str)
+            else:
+                diff_list.append(name + ".H1")
+        if (
+            other._D1 is not None
+            and self._D1 is not None
+            and isnan(other._D1)
+            and isnan(self._D1)
+        ):
+            pass
+        elif other._D1 != self._D1:
+            if is_add_value:
+                val_str = " (self=" + str(self._D1) + ", other=" + str(other._D1) + ")"
+                diff_list.append(name + ".D1" + val_str)
+            else:
+                diff_list.append(name + ".D1")
+        if (
+            other._W2 is not None
+            and self._W2 is not None
+            and isnan(other._W2)
+            and isnan(self._W2)
+        ):
+            pass
+        elif other._W2 != self._W2:
+            if is_add_value:
+                val_str = " (self=" + str(self._W2) + ", other=" + str(other._W2) + ")"
+                diff_list.append(name + ".W2" + val_str)
+            else:
+                diff_list.append(name + ".W2")
+        if (
+            other._H2 is not None
+            and self._H2 is not None
+            and isnan(other._H2)
+            and isnan(self._H2)
+        ):
+            pass
+        elif other._H2 != self._H2:
+            if is_add_value:
+                val_str = " (self=" + str(self._H2) + ", other=" + str(other._H2) + ")"
+                diff_list.append(name + ".H2" + val_str)
+            else:
+                diff_list.append(name + ".H2")
+        if (
+            other._D2 is not None
+            and self._D2 is not None
+            and isnan(other._D2)
+            and isnan(self._D2)
+        ):
+            pass
+        elif other._D2 != self._D2:
+            if is_add_value:
+                val_str = " (self=" + str(self._D2) + ", other=" + str(other._D2) + ")"
+                diff_list.append(name + ".D2" + val_str)
+            else:
+                diff_list.append(name + ".D2")
+        if (
+            other._H3 is not None
+            and self._H3 is not None
+            and isnan(other._H3)
+            and isnan(self._H3)
+        ):
+            pass
+        elif other._H3 != self._H3:
+            if is_add_value:
+                val_str = " (self=" + str(self._H3) + ", other=" + str(other._H3) + ")"
+                diff_list.append(name + ".H3" + val_str)
+            else:
+                diff_list.append(name + ".H3")
+        if (
+            other._R3 is not None
+            and self._R3 is not None
+            and isnan(other._R3)
+            and isnan(self._R3)
+        ):
+            pass
+        elif other._R3 != self._R3:
+            if is_add_value:
+                val_str = " (self=" + str(self._R3) + ", other=" + str(other._R3) + ")"
+                diff_list.append(name + ".R3" + val_str)
+            else:
+                diff_list.append(name + ".R3")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -361,6 +459,40 @@ class SlotDC(Slot):
         SlotDC_dict["__class__"] = "SlotDC"
         return SlotDC_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        W1_val = self.W1
+        H1_val = self.H1
+        D1_val = self.D1
+        W2_val = self.W2
+        H2_val = self.H2
+        D2_val = self.D2
+        H3_val = self.H3
+        R3_val = self.R3
+        Zs_val = self.Zs
+        if self.wedge_mat is None:
+            wedge_mat_val = None
+        else:
+            wedge_mat_val = self.wedge_mat.copy()
+        is_bore_val = self.is_bore
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            W1=W1_val,
+            H1=H1_val,
+            D1=D1_val,
+            W2=W2_val,
+            H2=H2_val,
+            D2=D2_val,
+            H3=H3_val,
+            R3=R3_val,
+            Zs=Zs_val,
+            wedge_mat=wedge_mat_val,
+            is_bore=is_bore_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
