@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Slot import Slot
 
 # Import all class method
@@ -68,6 +68,7 @@ except ImportError as error:
     plot_schematics = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -189,9 +190,8 @@ class SlotM14(Slot):
         )
     else:
         plot_schematics = plot_schematics
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -203,6 +203,8 @@ class SlotM14(Slot):
         Hmag=0.001,
         Rtopm=0.001,
         Zs=36,
+        wedge_mat=None,
+        is_bore=True,
         init_dict=None,
         init_str=None,
     ):
@@ -233,6 +235,10 @@ class SlotM14(Slot):
                 Rtopm = init_dict["Rtopm"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
+            if "wedge_mat" in list(init_dict.keys()):
+                wedge_mat = init_dict["wedge_mat"]
+            if "is_bore" in list(init_dict.keys()):
+                is_bore = init_dict["is_bore"]
         # Set the properties (value check and convertion are done in setter)
         self.W0 = W0
         self.H0 = H0
@@ -240,7 +246,7 @@ class SlotM14(Slot):
         self.Hmag = Hmag
         self.Rtopm = Rtopm
         # Call Slot init
-        super(SlotM14, self).__init__(Zs=Zs)
+        super(SlotM14, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
@@ -278,7 +284,7 @@ class SlotM14(Slot):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -288,17 +294,82 @@ class SlotM14(Slot):
         diff_list = list()
 
         # Check the properties inherited from Slot
-        diff_list.extend(super(SlotM14, self).compare(other, name=name))
-        if other._W0 != self._W0:
-            diff_list.append(name + ".W0")
-        if other._H0 != self._H0:
-            diff_list.append(name + ".H0")
-        if other._Wmag != self._Wmag:
-            diff_list.append(name + ".Wmag")
-        if other._Hmag != self._Hmag:
-            diff_list.append(name + ".Hmag")
-        if other._Rtopm != self._Rtopm:
-            diff_list.append(name + ".Rtopm")
+        diff_list.extend(
+            super(SlotM14, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._W0 is not None
+            and self._W0 is not None
+            and isnan(other._W0)
+            and isnan(self._W0)
+        ):
+            pass
+        elif other._W0 != self._W0:
+            if is_add_value:
+                val_str = " (self=" + str(self._W0) + ", other=" + str(other._W0) + ")"
+                diff_list.append(name + ".W0" + val_str)
+            else:
+                diff_list.append(name + ".W0")
+        if (
+            other._H0 is not None
+            and self._H0 is not None
+            and isnan(other._H0)
+            and isnan(self._H0)
+        ):
+            pass
+        elif other._H0 != self._H0:
+            if is_add_value:
+                val_str = " (self=" + str(self._H0) + ", other=" + str(other._H0) + ")"
+                diff_list.append(name + ".H0" + val_str)
+            else:
+                diff_list.append(name + ".H0")
+        if (
+            other._Wmag is not None
+            and self._Wmag is not None
+            and isnan(other._Wmag)
+            and isnan(self._Wmag)
+        ):
+            pass
+        elif other._Wmag != self._Wmag:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Wmag) + ", other=" + str(other._Wmag) + ")"
+                )
+                diff_list.append(name + ".Wmag" + val_str)
+            else:
+                diff_list.append(name + ".Wmag")
+        if (
+            other._Hmag is not None
+            and self._Hmag is not None
+            and isnan(other._Hmag)
+            and isnan(self._Hmag)
+        ):
+            pass
+        elif other._Hmag != self._Hmag:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Hmag) + ", other=" + str(other._Hmag) + ")"
+                )
+                diff_list.append(name + ".Hmag" + val_str)
+            else:
+                diff_list.append(name + ".Hmag")
+        if (
+            other._Rtopm is not None
+            and self._Rtopm is not None
+            and isnan(other._Rtopm)
+            and isnan(self._Rtopm)
+        ):
+            pass
+        elif other._Rtopm != self._Rtopm:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Rtopm) + ", other=" + str(other._Rtopm) + ")"
+                )
+                diff_list.append(name + ".Rtopm" + val_str)
+            else:
+                diff_list.append(name + ".Rtopm")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -344,6 +415,34 @@ class SlotM14(Slot):
         SlotM14_dict["__class__"] = "SlotM14"
         return SlotM14_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        W0_val = self.W0
+        H0_val = self.H0
+        Wmag_val = self.Wmag
+        Hmag_val = self.Hmag
+        Rtopm_val = self.Rtopm
+        Zs_val = self.Zs
+        if self.wedge_mat is None:
+            wedge_mat_val = None
+        else:
+            wedge_mat_val = self.wedge_mat.copy()
+        is_bore_val = self.is_bore
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            W0=W0_val,
+            H0=H0_val,
+            Wmag=Wmag_val,
+            Hmag=Hmag_val,
+            Rtopm=Rtopm_val,
+            Zs=Zs_val,
+            wedge_mat=wedge_mat_val,
+            is_bore=is_bore_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
