@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Solution import Solution
 
 # Import all class method
@@ -33,6 +33,7 @@ except ImportError as error:
     get_solution = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -75,9 +76,8 @@ class SolutionData(Solution):
         )
     else:
         get_solution = get_solution
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -147,7 +147,7 @@ class SolutionData(Solution):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -157,13 +157,24 @@ class SolutionData(Solution):
         diff_list = list()
 
         # Check the properties inherited from Solution
-        diff_list.extend(super(SolutionData, self).compare(other, name=name))
+        diff_list.extend(
+            super(SolutionData, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.field is None and self.field is not None) or (
             other.field is not None and self.field is None
         ):
             diff_list.append(name + ".field None mismatch")
         elif self.field is not None:
-            diff_list.extend(self.field.compare(other.field, name=name + ".field"))
+            diff_list.extend(
+                self.field.compare(
+                    other.field,
+                    name=name + ".field",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -208,6 +219,28 @@ class SolutionData(Solution):
         SolutionData_dict["__class__"] = "SolutionData"
         return SolutionData_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.field is None:
+            field_val = None
+        else:
+            field_val = self.field.copy()
+        type_cell_val = self.type_cell
+        label_val = self.label
+        dimension_val = self.dimension
+        unit_val = self.unit
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            field=field_val,
+            type_cell=type_cell_val,
+            label=label_val,
+            dimension=dimension_val,
+            unit=unit_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -222,7 +255,13 @@ class SolutionData(Solution):
     def _set_field(self, value):
         """setter of field"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "SciDataTool.Classes", value.get("__class__"), "field"
