@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .VarSimu import VarSimu
 
 # Import all class method
@@ -35,11 +35,8 @@ except ImportError as error:
     get_simu_number = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ParamExplorer import ParamExplorer
-from .DataKeeper import DataKeeper
-from .VarSimu import VarSimu
-from .Post import Post
 
 
 class VarParam(VarSimu):
@@ -83,9 +80,8 @@ class VarParam(VarSimu):
         )
     else:
         get_simu_number = get_simu_number
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -103,6 +99,7 @@ class VarParam(VarSimu):
         postproc_list=-1,
         pre_keeper_postproc_list=None,
         post_keeper_postproc_list=None,
+        is_reuse_LUT=True,
         init_dict=None,
         init_str=None,
     ):
@@ -145,6 +142,8 @@ class VarParam(VarSimu):
                 pre_keeper_postproc_list = init_dict["pre_keeper_postproc_list"]
             if "post_keeper_postproc_list" in list(init_dict.keys()):
                 post_keeper_postproc_list = init_dict["post_keeper_postproc_list"]
+            if "is_reuse_LUT" in list(init_dict.keys()):
+                is_reuse_LUT = init_dict["is_reuse_LUT"]
         # Set the properties (value check and convertion are done in setter)
         self.paramexplorer_list = paramexplorer_list
         # Call VarSimu init
@@ -160,6 +159,7 @@ class VarParam(VarSimu):
             postproc_list=postproc_list,
             pre_keeper_postproc_list=pre_keeper_postproc_list,
             post_keeper_postproc_list=post_keeper_postproc_list,
+            is_reuse_LUT=is_reuse_LUT,
         )
         # The class is frozen (in VarSimu init), for now it's impossible to
         # add new properties
@@ -195,7 +195,7 @@ class VarParam(VarSimu):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -205,7 +205,11 @@ class VarParam(VarSimu):
         diff_list = list()
 
         # Check the properties inherited from VarSimu
-        diff_list.extend(super(VarParam, self).compare(other, name=name))
+        diff_list.extend(
+            super(VarParam, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (
             other.paramexplorer_list is None and self.paramexplorer_list is not None
         ) or (other.paramexplorer_list is not None and self.paramexplorer_list is None):
@@ -220,6 +224,8 @@ class VarParam(VarSimu):
                     self.paramexplorer_list[ii].compare(
                         other.paramexplorer_list[ii],
                         name=name + ".paramexplorer_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         # Filter ignore differences
@@ -275,6 +281,69 @@ class VarParam(VarSimu):
         VarParam_dict["__class__"] = "VarParam"
         return VarParam_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.paramexplorer_list is None:
+            paramexplorer_list_val = None
+        else:
+            paramexplorer_list_val = list()
+            for obj in self.paramexplorer_list:
+                paramexplorer_list_val.append(obj.copy())
+        name_val = self.name
+        desc_val = self.desc
+        if self.datakeeper_list is None:
+            datakeeper_list_val = None
+        else:
+            datakeeper_list_val = list()
+            for obj in self.datakeeper_list:
+                datakeeper_list_val.append(obj.copy())
+        is_keep_all_output_val = self.is_keep_all_output
+        stop_if_error_val = self.stop_if_error
+        if self.var_simu is None:
+            var_simu_val = None
+        else:
+            var_simu_val = self.var_simu.copy()
+        nb_simu_val = self.nb_simu
+        is_reuse_femm_file_val = self.is_reuse_femm_file
+        if self.postproc_list is None:
+            postproc_list_val = None
+        else:
+            postproc_list_val = list()
+            for obj in self.postproc_list:
+                postproc_list_val.append(obj.copy())
+        if self.pre_keeper_postproc_list is None:
+            pre_keeper_postproc_list_val = None
+        else:
+            pre_keeper_postproc_list_val = list()
+            for obj in self.pre_keeper_postproc_list:
+                pre_keeper_postproc_list_val.append(obj.copy())
+        if self.post_keeper_postproc_list is None:
+            post_keeper_postproc_list_val = None
+        else:
+            post_keeper_postproc_list_val = list()
+            for obj in self.post_keeper_postproc_list:
+                post_keeper_postproc_list_val.append(obj.copy())
+        is_reuse_LUT_val = self.is_reuse_LUT
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            paramexplorer_list=paramexplorer_list_val,
+            name=name_val,
+            desc=desc_val,
+            datakeeper_list=datakeeper_list_val,
+            is_keep_all_output=is_keep_all_output_val,
+            stop_if_error=stop_if_error_val,
+            var_simu=var_simu_val,
+            nb_simu=nb_simu_val,
+            is_reuse_femm_file=is_reuse_femm_file_val,
+            postproc_list=postproc_list_val,
+            pre_keeper_postproc_list=pre_keeper_postproc_list_val,
+            post_keeper_postproc_list=post_keeper_postproc_list_val,
+            is_reuse_LUT=is_reuse_LUT_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -294,6 +363,15 @@ class VarParam(VarSimu):
         """setter of paramexplorer_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "paramexplorer_list"
