@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -65,9 +65,8 @@ except ImportError as error:
     get_ref_simu_index = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .DataKeeper import DataKeeper
-from .Post import Post
 
 
 class VarSimu(FrozenClass):
@@ -177,9 +176,8 @@ class VarSimu(FrozenClass):
         )
     else:
         get_ref_simu_index = get_ref_simu_index
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -196,6 +194,7 @@ class VarSimu(FrozenClass):
         postproc_list=-1,
         pre_keeper_postproc_list=None,
         post_keeper_postproc_list=None,
+        is_reuse_LUT=True,
         init_dict=None,
         init_str=None,
     ):
@@ -236,6 +235,8 @@ class VarSimu(FrozenClass):
                 pre_keeper_postproc_list = init_dict["pre_keeper_postproc_list"]
             if "post_keeper_postproc_list" in list(init_dict.keys()):
                 post_keeper_postproc_list = init_dict["post_keeper_postproc_list"]
+            if "is_reuse_LUT" in list(init_dict.keys()):
+                is_reuse_LUT = init_dict["is_reuse_LUT"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
@@ -249,6 +250,7 @@ class VarSimu(FrozenClass):
         self.postproc_list = postproc_list
         self.pre_keeper_postproc_list = pre_keeper_postproc_list
         self.post_keeper_postproc_list = post_keeper_postproc_list
+        self.is_reuse_LUT = is_reuse_LUT
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -314,6 +316,7 @@ class VarSimu(FrozenClass):
             VarSimu_str += (
                 "post_keeper_postproc_list[" + str(ii) + "] =" + tmp + linesep + linesep
             )
+        VarSimu_str += "is_reuse_LUT = " + str(self.is_reuse_LUT) + linesep
         return VarSimu_str
 
     def __eq__(self, other):
@@ -343,9 +346,11 @@ class VarSimu(FrozenClass):
             return False
         if other.post_keeper_postproc_list != self.post_keeper_postproc_list:
             return False
+        if other.is_reuse_LUT != self.is_reuse_LUT:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -354,9 +359,21 @@ class VarSimu(FrozenClass):
             return ["type(" + name + ")"]
         diff_list = list()
         if other._name != self._name:
-            diff_list.append(name + ".name")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._name) + ", other=" + str(other._name) + ")"
+                )
+                diff_list.append(name + ".name" + val_str)
+            else:
+                diff_list.append(name + ".name")
         if other._desc != self._desc:
-            diff_list.append(name + ".desc")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._desc) + ", other=" + str(other._desc) + ")"
+                )
+                diff_list.append(name + ".desc" + val_str)
+            else:
+                diff_list.append(name + ".desc")
         if (other.datakeeper_list is None and self.datakeeper_list is not None) or (
             other.datakeeper_list is not None and self.datakeeper_list is None
         ):
@@ -371,24 +388,71 @@ class VarSimu(FrozenClass):
                     self.datakeeper_list[ii].compare(
                         other.datakeeper_list[ii],
                         name=name + ".datakeeper_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._is_keep_all_output != self._is_keep_all_output:
-            diff_list.append(name + ".is_keep_all_output")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_keep_all_output)
+                    + ", other="
+                    + str(other._is_keep_all_output)
+                    + ")"
+                )
+                diff_list.append(name + ".is_keep_all_output" + val_str)
+            else:
+                diff_list.append(name + ".is_keep_all_output")
         if other._stop_if_error != self._stop_if_error:
-            diff_list.append(name + ".stop_if_error")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._stop_if_error)
+                    + ", other="
+                    + str(other._stop_if_error)
+                    + ")"
+                )
+                diff_list.append(name + ".stop_if_error" + val_str)
+            else:
+                diff_list.append(name + ".stop_if_error")
         if (other.var_simu is None and self.var_simu is not None) or (
             other.var_simu is not None and self.var_simu is None
         ):
             diff_list.append(name + ".var_simu None mismatch")
         elif self.var_simu is not None:
             diff_list.extend(
-                self.var_simu.compare(other.var_simu, name=name + ".var_simu")
+                self.var_simu.compare(
+                    other.var_simu,
+                    name=name + ".var_simu",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if other._nb_simu != self._nb_simu:
-            diff_list.append(name + ".nb_simu")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._nb_simu)
+                    + ", other="
+                    + str(other._nb_simu)
+                    + ")"
+                )
+                diff_list.append(name + ".nb_simu" + val_str)
+            else:
+                diff_list.append(name + ".nb_simu")
         if other._is_reuse_femm_file != self._is_reuse_femm_file:
-            diff_list.append(name + ".is_reuse_femm_file")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_reuse_femm_file)
+                    + ", other="
+                    + str(other._is_reuse_femm_file)
+                    + ")"
+                )
+                diff_list.append(name + ".is_reuse_femm_file" + val_str)
+            else:
+                diff_list.append(name + ".is_reuse_femm_file")
         if (other.postproc_list is None and self.postproc_list is not None) or (
             other.postproc_list is not None and self.postproc_list is None
         ):
@@ -403,6 +467,8 @@ class VarSimu(FrozenClass):
                     self.postproc_list[ii].compare(
                         other.postproc_list[ii],
                         name=name + ".postproc_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (
@@ -423,6 +489,8 @@ class VarSimu(FrozenClass):
                     self.pre_keeper_postproc_list[ii].compare(
                         other.pre_keeper_postproc_list[ii],
                         name=name + ".pre_keeper_postproc_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (
@@ -445,8 +513,22 @@ class VarSimu(FrozenClass):
                     self.post_keeper_postproc_list[ii].compare(
                         other.post_keeper_postproc_list[ii],
                         name=name + ".post_keeper_postproc_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
+        if other._is_reuse_LUT != self._is_reuse_LUT:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_reuse_LUT)
+                    + ", other="
+                    + str(other._is_reuse_LUT)
+                    + ")"
+                )
+                diff_list.append(name + ".is_reuse_LUT" + val_str)
+            else:
+                diff_list.append(name + ".is_reuse_LUT")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -474,6 +556,7 @@ class VarSimu(FrozenClass):
         if self.post_keeper_postproc_list is not None:
             for value in self.post_keeper_postproc_list:
                 S += getsizeof(value)
+        S += getsizeof(self.is_reuse_LUT)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -562,10 +645,67 @@ class VarSimu(FrozenClass):
                     )
                 else:
                     VarSimu_dict["post_keeper_postproc_list"].append(None)
+        VarSimu_dict["is_reuse_LUT"] = self.is_reuse_LUT
         # The class name is added to the dict for deserialisation purpose
         VarSimu_dict["__class__"] = "VarSimu"
         return VarSimu_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        name_val = self.name
+        desc_val = self.desc
+        if self.datakeeper_list is None:
+            datakeeper_list_val = None
+        else:
+            datakeeper_list_val = list()
+            for obj in self.datakeeper_list:
+                datakeeper_list_val.append(obj.copy())
+        is_keep_all_output_val = self.is_keep_all_output
+        stop_if_error_val = self.stop_if_error
+        if self.var_simu is None:
+            var_simu_val = None
+        else:
+            var_simu_val = self.var_simu.copy()
+        nb_simu_val = self.nb_simu
+        is_reuse_femm_file_val = self.is_reuse_femm_file
+        if self.postproc_list is None:
+            postproc_list_val = None
+        else:
+            postproc_list_val = list()
+            for obj in self.postproc_list:
+                postproc_list_val.append(obj.copy())
+        if self.pre_keeper_postproc_list is None:
+            pre_keeper_postproc_list_val = None
+        else:
+            pre_keeper_postproc_list_val = list()
+            for obj in self.pre_keeper_postproc_list:
+                pre_keeper_postproc_list_val.append(obj.copy())
+        if self.post_keeper_postproc_list is None:
+            post_keeper_postproc_list_val = None
+        else:
+            post_keeper_postproc_list_val = list()
+            for obj in self.post_keeper_postproc_list:
+                post_keeper_postproc_list_val.append(obj.copy())
+        is_reuse_LUT_val = self.is_reuse_LUT
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            name=name_val,
+            desc=desc_val,
+            datakeeper_list=datakeeper_list_val,
+            is_keep_all_output=is_keep_all_output_val,
+            stop_if_error=stop_if_error_val,
+            var_simu=var_simu_val,
+            nb_simu=nb_simu_val,
+            is_reuse_femm_file=is_reuse_femm_file_val,
+            postproc_list=postproc_list_val,
+            pre_keeper_postproc_list=pre_keeper_postproc_list_val,
+            post_keeper_postproc_list=post_keeper_postproc_list_val,
+            is_reuse_LUT=is_reuse_LUT_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -581,6 +721,7 @@ class VarSimu(FrozenClass):
         self.postproc_list = None
         self.pre_keeper_postproc_list = None
         self.post_keeper_postproc_list = None
+        self.is_reuse_LUT = None
 
     def _get_name(self):
         """getter of name"""
@@ -630,6 +771,15 @@ class VarSimu(FrozenClass):
         """setter of datakeeper_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "datakeeper_list"
@@ -694,13 +844,20 @@ class VarSimu(FrozenClass):
     def _set_var_simu(self, value):
         """setter of var_simu"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "var_simu"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            VarSimu = import_class("pyleecan.Classes", "VarSimu", "var_simu")
             value = VarSimu()
         check_var("var_simu", value, "VarSimu")
         self._var_simu = value
@@ -765,6 +922,15 @@ class VarSimu(FrozenClass):
         """setter of postproc_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "postproc_list"
@@ -798,6 +964,15 @@ class VarSimu(FrozenClass):
         """setter of pre_keeper_postproc_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes",
@@ -833,6 +1008,15 @@ class VarSimu(FrozenClass):
         """setter of post_keeper_postproc_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes",
@@ -855,3 +1039,21 @@ class VarSimu(FrozenClass):
         :Type: [Post]
         """,
     )
+
+    def _get_is_reuse_LUT(self):
+        """getter of is_reuse_LUT"""
+        return self._is_reuse_LUT
+
+    def _set_is_reuse_LUT(self, value):
+        """setter of is_reuse_LUT"""
+        check_var("is_reuse_LUT", value, "bool")
+        self._is_reuse_LUT = value
+
+    is_reuse_LUT = property(
+        fget=_get_is_reuse_LUT,
+        fset=_set_is_reuse_LUT,
+        doc=u"""True to reuse the look up table
+
+        :Type: bool
+        """,
+    )
