@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Hole import Hole
 
 # Import all class method
@@ -55,8 +55,8 @@ except ImportError as error:
     plot_schematics = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Material import Material
 
 
 class VentilationCirc(Hole):
@@ -144,9 +144,8 @@ class VentilationCirc(Hole):
         )
     else:
         plot_schematics = plot_schematics
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -226,7 +225,7 @@ class VentilationCirc(Hole):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -236,11 +235,37 @@ class VentilationCirc(Hole):
         diff_list = list()
 
         # Check the properties inherited from Hole
-        diff_list.extend(super(VentilationCirc, self).compare(other, name=name))
-        if other._D0 != self._D0:
-            diff_list.append(name + ".D0")
-        if other._H0 != self._H0:
-            diff_list.append(name + ".H0")
+        diff_list.extend(
+            super(VentilationCirc, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._D0 is not None
+            and self._D0 is not None
+            and isnan(other._D0)
+            and isnan(self._D0)
+        ):
+            pass
+        elif other._D0 != self._D0:
+            if is_add_value:
+                val_str = " (self=" + str(self._D0) + ", other=" + str(other._D0) + ")"
+                diff_list.append(name + ".D0" + val_str)
+            else:
+                diff_list.append(name + ".D0")
+        if (
+            other._H0 is not None
+            and self._H0 is not None
+            and isnan(other._H0)
+            and isnan(self._H0)
+        ):
+            pass
+        elif other._H0 != self._H0:
+            if is_add_value:
+                val_str = " (self=" + str(self._H0) + ", other=" + str(other._H0) + ")"
+                diff_list.append(name + ".H0" + val_str)
+            else:
+                diff_list.append(name + ".H0")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -280,6 +305,33 @@ class VentilationCirc(Hole):
         VentilationCirc_dict["__class__"] = "VentilationCirc"
         return VentilationCirc_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        D0_val = self.D0
+        H0_val = self.H0
+        Zh_val = self.Zh
+        if self.mat_void is None:
+            mat_void_val = None
+        else:
+            mat_void_val = self.mat_void.copy()
+        if self.magnetization_dict_offset is None:
+            magnetization_dict_offset_val = None
+        else:
+            magnetization_dict_offset_val = self.magnetization_dict_offset.copy()
+        Alpha0_val = self.Alpha0
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            D0=D0_val,
+            H0=H0_val,
+            Zh=Zh_val,
+            mat_void=mat_void_val,
+            magnetization_dict_offset=magnetization_dict_offset_val,
+            Alpha0=Alpha0_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
