@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -79,9 +79,8 @@ except ImportError as error:
 
 
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Conductor import Conductor
-from .EndWinding import EndWinding
 
 
 class Winding(FrozenClass):
@@ -223,9 +222,8 @@ class Winding(FrozenClass):
         )
     else:
         clean = clean
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -414,7 +412,7 @@ class Winding(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -423,53 +421,200 @@ class Winding(FrozenClass):
             return ["type(" + name + ")"]
         diff_list = list()
         if other._is_reverse_wind != self._is_reverse_wind:
-            diff_list.append(name + ".is_reverse_wind")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_reverse_wind)
+                    + ", other="
+                    + str(other._is_reverse_wind)
+                    + ")"
+                )
+                diff_list.append(name + ".is_reverse_wind" + val_str)
+            else:
+                diff_list.append(name + ".is_reverse_wind")
         if other._Nslot_shift_wind != self._Nslot_shift_wind:
-            diff_list.append(name + ".Nslot_shift_wind")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Nslot_shift_wind)
+                    + ", other="
+                    + str(other._Nslot_shift_wind)
+                    + ")"
+                )
+                diff_list.append(name + ".Nslot_shift_wind" + val_str)
+            else:
+                diff_list.append(name + ".Nslot_shift_wind")
         if other._qs != self._qs:
-            diff_list.append(name + ".qs")
+            if is_add_value:
+                val_str = " (self=" + str(self._qs) + ", other=" + str(other._qs) + ")"
+                diff_list.append(name + ".qs" + val_str)
+            else:
+                diff_list.append(name + ".qs")
         if other._Ntcoil != self._Ntcoil:
-            diff_list.append(name + ".Ntcoil")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Ntcoil)
+                    + ", other="
+                    + str(other._Ntcoil)
+                    + ")"
+                )
+                diff_list.append(name + ".Ntcoil" + val_str)
+            else:
+                diff_list.append(name + ".Ntcoil")
         if other._Npcp != self._Npcp:
-            diff_list.append(name + ".Npcp")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Npcp) + ", other=" + str(other._Npcp) + ")"
+                )
+                diff_list.append(name + ".Npcp" + val_str)
+            else:
+                diff_list.append(name + ".Npcp")
         if other._type_connection != self._type_connection:
-            diff_list.append(name + ".type_connection")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_connection)
+                    + ", other="
+                    + str(other._type_connection)
+                    + ")"
+                )
+                diff_list.append(name + ".type_connection" + val_str)
+            else:
+                diff_list.append(name + ".type_connection")
         if other._p != self._p:
-            diff_list.append(name + ".p")
-        if other._Lewout != self._Lewout:
-            diff_list.append(name + ".Lewout")
+            if is_add_value:
+                val_str = " (self=" + str(self._p) + ", other=" + str(other._p) + ")"
+                diff_list.append(name + ".p" + val_str)
+            else:
+                diff_list.append(name + ".p")
+        if (
+            other._Lewout is not None
+            and self._Lewout is not None
+            and isnan(other._Lewout)
+            and isnan(self._Lewout)
+        ):
+            pass
+        elif other._Lewout != self._Lewout:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Lewout)
+                    + ", other="
+                    + str(other._Lewout)
+                    + ")"
+                )
+                diff_list.append(name + ".Lewout" + val_str)
+            else:
+                diff_list.append(name + ".Lewout")
         if (other.conductor is None and self.conductor is not None) or (
             other.conductor is not None and self.conductor is None
         ):
             diff_list.append(name + ".conductor None mismatch")
         elif self.conductor is not None:
             diff_list.extend(
-                self.conductor.compare(other.conductor, name=name + ".conductor")
+                self.conductor.compare(
+                    other.conductor,
+                    name=name + ".conductor",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if other._coil_pitch != self._coil_pitch:
-            diff_list.append(name + ".coil_pitch")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._coil_pitch)
+                    + ", other="
+                    + str(other._coil_pitch)
+                    + ")"
+                )
+                diff_list.append(name + ".coil_pitch" + val_str)
+            else:
+                diff_list.append(name + ".coil_pitch")
         if not array_equal(other.wind_mat, self.wind_mat):
             diff_list.append(name + ".wind_mat")
         if other._Nlayer != self._Nlayer:
-            diff_list.append(name + ".Nlayer")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._Nlayer)
+                    + ", other="
+                    + str(other._Nlayer)
+                    + ")"
+                )
+                diff_list.append(name + ".Nlayer" + val_str)
+            else:
+                diff_list.append(name + ".Nlayer")
         if other._per_a != self._per_a:
-            diff_list.append(name + ".per_a")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._per_a) + ", other=" + str(other._per_a) + ")"
+                )
+                diff_list.append(name + ".per_a" + val_str)
+            else:
+                diff_list.append(name + ".per_a")
         if other._is_aper_a != self._is_aper_a:
-            diff_list.append(name + ".is_aper_a")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_aper_a)
+                    + ", other="
+                    + str(other._is_aper_a)
+                    + ")"
+                )
+                diff_list.append(name + ".is_aper_a" + val_str)
+            else:
+                diff_list.append(name + ".is_aper_a")
         if (other.end_winding is None and self.end_winding is not None) or (
             other.end_winding is not None and self.end_winding is None
         ):
             diff_list.append(name + ".end_winding None mismatch")
         elif self.end_winding is not None:
             diff_list.extend(
-                self.end_winding.compare(other.end_winding, name=name + ".end_winding")
+                self.end_winding.compare(
+                    other.end_winding,
+                    name=name + ".end_winding",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if other._is_reverse_layer != self._is_reverse_layer:
-            diff_list.append(name + ".is_reverse_layer")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_reverse_layer)
+                    + ", other="
+                    + str(other._is_reverse_layer)
+                    + ")"
+                )
+                diff_list.append(name + ".is_reverse_layer" + val_str)
+            else:
+                diff_list.append(name + ".is_reverse_layer")
         if other._is_change_layer != self._is_change_layer:
-            diff_list.append(name + ".is_change_layer")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_change_layer)
+                    + ", other="
+                    + str(other._is_change_layer)
+                    + ")"
+                )
+                diff_list.append(name + ".is_change_layer" + val_str)
+            else:
+                diff_list.append(name + ".is_change_layer")
         if other._is_permute_B_C != self._is_permute_B_C:
-            diff_list.append(name + ".is_permute_B_C")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_permute_B_C)
+                    + ", other="
+                    + str(other._is_permute_B_C)
+                    + ")"
+                )
+                diff_list.append(name + ".is_permute_B_C" + val_str)
+            else:
+                diff_list.append(name + ".is_permute_B_C")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -558,6 +703,60 @@ class Winding(FrozenClass):
         Winding_dict["__class__"] = "Winding"
         return Winding_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        is_reverse_wind_val = self.is_reverse_wind
+        Nslot_shift_wind_val = self.Nslot_shift_wind
+        qs_val = self.qs
+        Ntcoil_val = self.Ntcoil
+        Npcp_val = self.Npcp
+        type_connection_val = self.type_connection
+        p_val = self.p
+        Lewout_val = self.Lewout
+        if self.conductor is None:
+            conductor_val = None
+        else:
+            conductor_val = self.conductor.copy()
+        coil_pitch_val = self.coil_pitch
+        if self.wind_mat is None:
+            wind_mat_val = None
+        else:
+            wind_mat_val = self.wind_mat.copy()
+        Nlayer_val = self.Nlayer
+        per_a_val = self.per_a
+        is_aper_a_val = self.is_aper_a
+        if self.end_winding is None:
+            end_winding_val = None
+        else:
+            end_winding_val = self.end_winding.copy()
+        is_reverse_layer_val = self.is_reverse_layer
+        is_change_layer_val = self.is_change_layer
+        is_permute_B_C_val = self.is_permute_B_C
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            is_reverse_wind=is_reverse_wind_val,
+            Nslot_shift_wind=Nslot_shift_wind_val,
+            qs=qs_val,
+            Ntcoil=Ntcoil_val,
+            Npcp=Npcp_val,
+            type_connection=type_connection_val,
+            p=p_val,
+            Lewout=Lewout_val,
+            conductor=conductor_val,
+            coil_pitch=coil_pitch_val,
+            wind_mat=wind_mat_val,
+            Nlayer=Nlayer_val,
+            per_a=per_a_val,
+            is_aper_a=is_aper_a_val,
+            end_winding=end_winding_val,
+            is_reverse_layer=is_reverse_layer_val,
+            is_change_layer=is_change_layer_val,
+            is_permute_B_C=is_permute_B_C_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -740,13 +939,20 @@ class Winding(FrozenClass):
     def _set_conductor(self, value):
         """setter of conductor"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "conductor"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Conductor = import_class("pyleecan.Classes", "Conductor", "conductor")
             value = Conductor()
         check_var("conductor", value, "Conductor")
         self._conductor = value
@@ -869,13 +1075,20 @@ class Winding(FrozenClass):
     def _set_end_winding(self, value):
         """setter of end_winding"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "end_winding"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            EndWinding = import_class("pyleecan.Classes", "EndWinding", "end_winding")
             value = EndWinding()
         check_var("end_winding", value, "EndWinding")
         self._end_winding = value
