@@ -1,9 +1,10 @@
-import win32com.client
 import os
-from six import string_types
-import pythoncom
 from math import exp
 
+import pythoncom
+import win32com.client
+from six import string_types
+
 
 class _FEMMHandler(object):
     """
@@ -27,7 +28,10 @@ class _FEMMHandler(object):
         _FEMMHandler_dict["HandleToFEMM"] = None
         return _FEMMHandler_dict
 
-    def compare(self, other, name="self"):
+    def copy(self):
+        return _FEMMHandler(HandleToFEMM=None)
+
+    def compare(self, other, ignore_list=list(), name="self", is_add_value=False):
         """Compare two objects and return list of differences"""
         return list()
 
