@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
-from ...Classes.Output import Output
 
 
 def update(indiv):
     """Update the individual output after the mutation
-    
+
     Parameters
     ----------
         indiv : Individual
 
     """
 
-    indiv.output = Output(simu=indiv.output.simu.as_dict())
+    indiv.output = type(indiv.output)(simu=indiv.output.simu.as_dict())
 
     for k, setter in enumerate(indiv.setter_list):
         setter(indiv.output.simu, indiv[k])
