@@ -9,7 +9,7 @@ from PySide2.QtCore import *
 from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
-from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
+from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelectV import WMatSelectV
 from ......GUI.Dialog.DMachineSetup.SBar.WBarOut.WBarOut import WBarOut
 
 
@@ -18,17 +18,18 @@ class Ui_PCondType22(object):
         if not PCondType22.objectName():
             PCondType22.setObjectName(u"PCondType22")
         PCondType22.resize(460, 124)
-        self.horizontalLayout = QHBoxLayout(PCondType22)
-        self.horizontalLayout.setObjectName(u"horizontalLayout")
-        self.w_mat = WMatSelect(PCondType22)
+        self.verticalLayout = QVBoxLayout(PCondType22)
+        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.w_mat = WMatSelectV(PCondType22)
         self.w_mat.setObjectName(u"w_mat")
+        self.w_mat.setMinimumSize(QSize(100, 0))
 
-        self.horizontalLayout.addWidget(self.w_mat)
+        self.verticalLayout.addWidget(self.w_mat)
 
         self.w_out = WBarOut(PCondType22)
         self.w_out.setObjectName(u"w_out")
 
-        self.horizontalLayout.addWidget(self.w_out)
+        self.verticalLayout.addWidget(self.w_out)
 
         self.retranslateUi(PCondType22)
 
