@@ -1,28 +1,25 @@
-# -*- coding: utf-8 -*-
-
 from logging import getLogger
 from os.path import join
 
-import matplotlib.pyplot as plt
 from PySide2.QtWidgets import QFileDialog, QTableWidgetItem, QWidget, QMessageBox
 
 from ......Classes._FEMMHandler import _FEMMHandler
 from ......Classes.Output import Output
+from ......Classes.InputCurrent import InputCurrent
 from ......Classes.Simu1 import Simu1
 from ......Classes.OPdq import OPdq
 from ......Classes.OPslip import OPslip
+from ......Classes.InputCurrent import InputCurrent
 from ......definitions import config_dict
 from ......loggers import GUI_LOG_NAME
+from ......Functions.GUI.log_error import log_error
 from ......Functions.FEMM.update_FEMM_simulation import update_FEMM_simulation
 from ......Functions.FEMM.draw_FEMM import draw_FEMM
 from ......Functions.Plot.set_plot_gui_icon import set_plot_gui_icon
 from ......GUI.Dialog.DMachineSetup.SPreview.WMachineTable.Ui_WMachineTable import (
     Ui_WMachineTable,
 )
-from SciDataTool import DataLinspace
-from ......Methods.Simulation.MagElmer import (
-    MagElmer_BP_dict,
-)
+from ......Methods.Simulation.MagElmer import MagElmer_BP_dict
 
 try:
     from ......Functions.GMSH.draw_GMSH import draw_GMSH
@@ -102,9 +99,13 @@ class WMachineTable(Ui_WMachineTable, QWidget):
 
     def plot_mmf(self):
         """Plot the unit mmf of the stator"""
-        if self.machine is not None:
-            self.machine.stator.plot_mmf_unit(is_show_fig=True)
-        set_plot_gui_icon()
+        try:
+            if self.machine is not None:
+                self.machine.stator.plot_mmf_unit()
+                set_plot_gui_icon()
+        except Exception as e:
+            err_msg = "Error while plotting Stator mmf unit:\n" + str(e)
+            log_error(self, err_msg)
 
     def plot_machine(self):
         """Plot the machine"""
@@ -120,38 +121,51 @@ class WMachineTable(Ui_WMachineTable, QWidget):
         if save_file_path is [None, ""]:
             return
 
-        femm = _FEMMHandler()
-        output = Output(simu=Simu1(machine=self.machine))
-        # Periodicity
-        sym, is_antiper, _, _ = self.machine.comp_periodicity()
-        if is_antiper:
-            sym *= 2
-        # Set Current (constant J in a layer)
-        S_slot = self.machine.stator.slot.comp_surface_active()
-        (Nrad, Ntan) = self.machine.stator.winding.get_dim_wind()
-        Ntcoil = self.machine.stator.winding.Ntcoil
-        Sphase = S_slot / (Nrad * Ntan)
-        J = 5e6
-        if self.machine.is_synchronous():
-            output.elec.OP = OPdq(felec=60)
-        else:
-            output.elec.OP = OPslip(felec=60)
-        output.elec.OP.set_Id_Iq(Id=J * Sphase / Ntcoil, Iq=0)
-        output.elec.Time = DataLinspace(
-            name="time",
-            unit="s",
-            initial=0,
-            final=60,
-            number=20,
-            include_endpoint=False,
-        )
-        time = output.elec.Time.get_values(
-            is_oneperiod=False,
-            is_antiperiod=False,
-        )
-        Is = output.elec.comp_I_mag(time, is_stator=True)
-        alpha = output.get_angle_rotor_initial()
         try:
+            femm = _FEMMHandler()
+
+            # Periodicity
+            sym, is_antiper = self.machine.comp_periodicity_spatial()
+            if is_antiper:
+                sym *= 2
+            # Set Current (constant J in a layer)
+            S_slot = self.machine.stator.slot.comp_surface_active()
+            (Nrad, Ntan) = self.machine.stator.winding.get_dim_wind()
+            Ntcoil = self.machine.stator.winding.Ntcoil
+            Sphase = S_slot / (Nrad * Ntan)
+            J = 5e6
+            if self.machine.is_synchronous():
+                OP = OPdq(felec=60)
+                OP.set_Id_Iq(Id=0, Iq=J * Sphase / Ntcoil)
+            else:
+                OP = OPslip(felec=60)
+                OP.set_Id_Iq(Id=J * Sphase / Ntcoil, Iq=0)
+
+            output = Output(
+                simu=Simu1(
+                    machine=self.machine,
+                    input=InputCurrent(OP=OP, Nt_tot=20, Na_tot=200),
+                )
+            )
+
+            # Generate time and phase vectors in OutElec
+            output.simu.input.gen_input()
+
+            # Get current values for given OP
+            Is = output.elec.get_Is().values
+
+            # Divide phase current by the number of parallel circuit per phase of winding
+            stator = self.machine.stator
+            if hasattr(stator.winding, "Npcp") and stator.winding.Npcp is not None:
+                Npcp = stator.winding.Npcp
+            else:
+                Npcp = 1
+            Is /= Npcp
+
+            # Get rotor angular position in degress
+            angle_rotor = output.elec.axes_dict["time"].get_values(
+                normalization="angle_rotor"
+            )
             # Draw the machine
             FEMM_dict = draw_FEMM(
                 femm,
@@ -163,14 +177,15 @@ class WMachineTable(Ui_WMachineTable, QWidget):
                 type_calc_leakage=0,
                 path_save=None,
                 is_sliding_band=True,
+                is_fast_draw=True,
             )
             # Set the current
             update_FEMM_simulation(
                 femm=femm,
-                circuits=FEMM_dict["circuits"],
+                FEMM_dict=FEMM_dict,
                 is_sliding_band=True,
                 is_internal_rotor=self.machine.rotor.is_internal,
-                angle_rotor=[alpha],
+                angle_rotor=angle_rotor,
                 Is=Is,
                 Ir=None,
                 ii=0,
@@ -183,12 +198,7 @@ class WMachineTable(Ui_WMachineTable, QWidget):
                 + " in FEMM:\n"
                 + str(e)
             )
-            getLogger(GUI_LOG_NAME).error(err_msg)
-            QMessageBox().critical(
-                self,
-                self.tr("Error"),
-                self.tr(err_msg),
-            )
+            log_error(self, err_msg)
         femm.closefemm()
 
     def draw_GMSH(self):
@@ -197,12 +207,12 @@ class WMachineTable(Ui_WMachineTable, QWidget):
         if save_file_path is [None, ""]:
             return
         # Create the Simulation
-        mySimu = Simu1(name="test_gmsh_ipm", machine=self.machine)
-        myResults = Output(simu=mySimu)
-        sym, is_antiper, _, _ = self.machine.comp_periodicity()
-        if is_antiper:
-            sym *= 2
         try:
+            mySimu = Simu1(name="test_gmsh_ipm", machine=self.machine)
+            myResults = Output(simu=mySimu)
+            sym, is_antiper = self.machine.comp_periodicity_spatial()
+            if is_antiper:
+                sym *= 2
             draw_GMSH(
                 output=myResults,
                 sym=sym,
@@ -221,12 +231,7 @@ class WMachineTable(Ui_WMachineTable, QWidget):
                 + " in GMSH:\n"
                 + str(e)
             )
-            getLogger(GUI_LOG_NAME).error(err_msg)
-            QMessageBox().critical(
-                self,
-                self.tr("Error"),
-                self.tr(err_msg),
-            )
+            log_error(self, err_msg)
 
     def draw_GMSH_3D(self):
         save_file_path = self.get_save_path(ext="_stator.msh", file_type="GMSH (*.msh)")
@@ -248,12 +253,7 @@ class WMachineTable(Ui_WMachineTable, QWidget):
                 + " in GMSH:\n"
                 + str(e)
             )
-            getLogger(GUI_LOG_NAME).error(err_msg)
-            QMessageBox().critical(
-                self,
-                self.tr("Error"),
-                self.tr(err_msg),
-            )
+            log_error(self, err_msg)
 
     def get_save_path(self, ext=".fem", file_type="FEMM (*.fem)"):
         machine_path = config_dict["MAIN"]["MACHINE_DIR"]
