@@ -11,6 +11,7 @@ from PySide2.QtWidgets import *
 
 from ......GUI.Tools.FloatEdit import FloatEdit
 from ......GUI.Dialog.DMachineSetup.SWSlot.WWSlotOut.WWSlotOut import WWSlotOut
+from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelectV import WMatSelectV
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -35,7 +36,7 @@ class Ui_PWSlot26(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW26.png")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW26_wind.png")
         )
         self.img_slot.setScaledContents(False)
         self.img_slot.setAlignment(Qt.AlignCenter)
@@ -51,7 +52,7 @@ class Ui_PWSlot26(object):
             self.txt_constraint.sizePolicy().hasHeightForWidth()
         )
         self.txt_constraint.setSizePolicy(sizePolicy1)
-        self.txt_constraint.setMaximumSize(QSize(16777215, 70))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 50))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -69,8 +70,8 @@ class Ui_PWSlot26(object):
         self.scrollAreaWidgetContents = QWidget()
         self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
         self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 446))
-        self.verticalLayout = QVBoxLayout(self.scrollAreaWidgetContents)
-        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.verticalLayout_3 = QVBoxLayout(self.scrollAreaWidgetContents)
+        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
         self.in_W0 = QLabel(self.scrollAreaWidgetContents)
@@ -148,18 +149,32 @@ class Ui_PWSlot26(object):
 
         self.gridLayout.addWidget(self.unit_R2, 4, 2, 1, 1)
 
-        self.verticalLayout.addLayout(self.gridLayout)
+        self.verticalLayout_3.addLayout(self.gridLayout)
+
+        self.g_wedge = QGroupBox(self.scrollAreaWidgetContents)
+        self.g_wedge.setObjectName(u"g_wedge")
+        self.g_wedge.setCheckable(True)
+        self.g_wedge.setChecked(False)
+        self.verticalLayout = QVBoxLayout(self.g_wedge)
+        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.w_wedge_mat = WMatSelectV(self.g_wedge)
+        self.w_wedge_mat.setObjectName(u"w_wedge_mat")
+        self.w_wedge_mat.setMinimumSize(QSize(100, 0))
+
+        self.verticalLayout.addWidget(self.w_wedge_mat)
+
+        self.verticalLayout_3.addWidget(self.g_wedge)
 
         self.verticalSpacer = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout.addItem(self.verticalSpacer)
+        self.verticalLayout_3.addItem(self.verticalSpacer)
 
         self.w_out = WWSlotOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
-        self.verticalLayout.addWidget(self.w_out)
+        self.verticalLayout_3.addWidget(self.w_out)
 
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
 
@@ -185,9 +200,9 @@ class Ui_PWSlot26(object):
                 u'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "http://www.w3.org/TR/REC-html40/strict.dtd">\n'
                 '<html><head><meta name="qrichtext" content="1" /><style type="text/css">\n'
                 "p, li { white-space: pre-wrap; }\n"
-                "</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">W0 &lt; 2*R1</span></p></body></html>',
+                "</style></head><body style=\" font-family:'DejaVu Sans'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt;">W0 &lt; 2 \u00d7 R1</span></p></body></html>',
                 None,
             )
         )
@@ -202,5 +217,6 @@ class Ui_PWSlot26(object):
         self.in_R2.setText(QCoreApplication.translate("PWSlot26", u"R2", None))
         self.lf_R2.setText("")
         self.unit_R2.setText(QCoreApplication.translate("PWSlot26", u"m", None))
+        self.g_wedge.setTitle(QCoreApplication.translate("PWSlot26", u"Wedge", None))
 
     # retranslateUi
