@@ -19,7 +19,7 @@ from ....Classes.SlotM10 import SlotM10
 from ....Classes.Winding import Winding
 from ....Classes.WindingSC import WindingSC
 from ....GUI.Dialog.DMachineSetup.SBar.SBar import SBar
-from ....GUI.Dialog.DMachineSetup.SLamParam.SLamParam import SLamParam
+from ....GUI.Dialog.DMachineSetup.SLamShape.SLamShape import SLamShape
 from ....GUI.Dialog.DMachineSetup.SMachineDimension.SMachineDimension import (
     SMachineDimension,
 )
@@ -34,19 +34,19 @@ from ....GUI.Dialog.DMachineSetup.SSkew.SSkew import SSkew
 from ....GUI.Resources import pixmap_dict
 
 # Steps needed to setup a LamSlotWind
-LSW_step = [SLamParam, SWSlot, SWinding, SWindCond]
+LSW_step = [SWSlot, SWinding, SWindCond, SLamShape]
 # Steps needed to setup a LamSlotWind for the rotor of a WRSM
-LP_step = [SLamParam, SWPole, SWinding, SWindCond, SSkew]
+LP_step = [SWPole, SWinding, SWindCond, SLamShape, SSkew]
 # Steps needed to setup a LamSquirrelCage
-LSC_step = [SLamParam, SWSlot, SBar, SSkew]
+LSC_step = [SWSlot, SBar, SLamShape, SSkew]
 # Steps needed to setup a LamSquirrelCageMag
-LSCM_step = [SLamParam, SWSlot, SBar, SMHoleMag, SSkew]
+LSCM_step = [SWSlot, SBar, SMHoleMag, SLamShape, SSkew]
 # Steps needed to setup a LamHole
-LH_step = [SLamParam, SMHoleMag, SSkew]
+LH_step = [SMHoleMag, SLamShape, SSkew]
 # Steps needed to setup a LamSlot
-LS_step = [SLamParam, SWSlot, SSkew]
+LS_step = [SWSlot, SLamShape, SSkew]
 # Steps needed to setup a LamSlotMag
-LSM_step = [SLamParam, SMSlot, SSkew]
+LSM_step = [SMSlot, SLamShape, SSkew]
 # Steps to start the design of a machine with 2 laminations
 S_step = [SMachineType, SMachineDimension]
 
