@@ -10,7 +10,7 @@ from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
 from .....GUI.Tools.FloatEdit import FloatEdit
-from .....GUI.Tools.WImport.WImport import WImport
+from .....GUI.Tools.WTableData.DTableData import DTableData
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -19,7 +19,7 @@ class Ui_DMatSetup(object):
     def setupUi(self, DMatSetup):
         if not DMatSetup.objectName():
             DMatSetup.setObjectName(u"DMatSetup")
-        DMatSetup.resize(642, 451)
+        DMatSetup.resize(958, 657)
         icon = QIcon()
         icon.addFile(
             u":/images/images/icon/pyleecan_64.png", QSize(), QIcon.Normal, QIcon.Off
@@ -39,36 +39,52 @@ class Ui_DMatSetup(object):
 
         self.horizontalLayout.addWidget(self.le_name)
 
+        self.horizontalSpacer = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.horizontalLayout.addItem(self.horizontalSpacer)
+
+        self.horizontalSpacer_4 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.horizontalLayout.addItem(self.horizontalSpacer_4)
+
+        self.horizontalSpacer_3 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.horizontalLayout.addItem(self.horizontalSpacer_3)
+
         self.verticalLayout.addLayout(self.horizontalLayout)
 
-        self.is_isotropic = QCheckBox(DMatSetup)
-        self.is_isotropic.setObjectName(u"is_isotropic")
-
-        self.verticalLayout.addWidget(self.is_isotropic)
-
         self.nav_phy = QTabWidget(DMatSetup)
         self.nav_phy.setObjectName(u"nav_phy")
         self.nav_phy.setMinimumSize(QSize(370, 0))
         self.tab_elec = QWidget()
         self.tab_elec.setObjectName(u"tab_elec")
-        self.gridLayout_2 = QGridLayout(self.tab_elec)
+        self.verticalLayout_5 = QVBoxLayout(self.tab_elec)
+        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
+        self.gridLayout_2 = QGridLayout()
         self.gridLayout_2.setObjectName(u"gridLayout_2")
+        self.in_rho_elec = QLabel(self.tab_elec)
+        self.in_rho_elec.setObjectName(u"in_rho_elec")
+        font = QFont()
+        font.setPointSize(8)
+        font.setBold(False)
+        font.setWeight(50)
+        self.in_rho_elec.setFont(font)
+
+        self.gridLayout_2.addWidget(self.in_rho_elec, 0, 0, 1, 1)
+
         self.lf_rho_elec = FloatEdit(self.tab_elec)
         self.lf_rho_elec.setObjectName(u"lf_rho_elec")
 
         self.gridLayout_2.addWidget(self.lf_rho_elec, 0, 1, 1, 1)
 
-        self.lf_epsr = FloatEdit(self.tab_elec)
-        self.lf_epsr.setObjectName(u"lf_epsr")
-
-        self.gridLayout_2.addWidget(self.lf_epsr, 1, 1, 1, 1)
-
         self.unit_rho_elec = QLabel(self.tab_elec)
         self.unit_rho_elec.setObjectName(u"unit_rho_elec")
-        font = QFont()
-        font.setPointSize(8)
-        font.setBold(False)
-        font.setWeight(50)
         self.unit_rho_elec.setFont(font)
 
         self.gridLayout_2.addWidget(self.unit_rho_elec, 0, 2, 1, 1)
@@ -79,99 +95,212 @@ class Ui_DMatSetup(object):
 
         self.gridLayout_2.addWidget(self.in_epsr, 1, 0, 1, 1)
 
-        self.in_rho_elec = QLabel(self.tab_elec)
-        self.in_rho_elec.setObjectName(u"in_rho_elec")
-        self.in_rho_elec.setFont(font)
+        self.lf_epsr = FloatEdit(self.tab_elec)
+        self.lf_epsr.setObjectName(u"lf_epsr")
 
-        self.gridLayout_2.addWidget(self.in_rho_elec, 0, 0, 1, 1)
+        self.gridLayout_2.addWidget(self.lf_epsr, 1, 1, 1, 1)
+
+        self.unit_epsr = QLabel(self.tab_elec)
+        self.unit_epsr.setObjectName(u"unit_epsr")
+
+        self.gridLayout_2.addWidget(self.unit_epsr, 1, 2, 1, 1)
+
+        self.verticalLayout_5.addLayout(self.gridLayout_2)
 
         self.verticalSpacer_2 = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.gridLayout_2.addItem(self.verticalSpacer_2, 2, 1, 1, 1)
+        self.verticalLayout_5.addItem(self.verticalSpacer_2)
 
         self.nav_phy.addTab(self.tab_elec, "")
         self.tab_mag = QWidget()
         self.tab_mag.setObjectName(u"tab_mag")
-        self.verticalLayout_3 = QVBoxLayout(self.tab_mag)
-        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
+        self.mag_layout = QVBoxLayout(self.tab_mag)
+        self.mag_layout.setObjectName(u"mag_layout")
+        self.horizontalLayout_8 = QHBoxLayout()
+        self.horizontalLayout_8.setObjectName(u"horizontalLayout_8")
+        self.c_type_material = QComboBox(self.tab_mag)
+        self.c_type_material.addItem("")
+        self.c_type_material.addItem("")
+        self.c_type_material.addItem("")
+        self.c_type_material.setObjectName(u"c_type_material")
+        self.c_type_material.setMinimumSize(QSize(200, 0))
+
+        self.horizontalLayout_8.addWidget(self.c_type_material)
+
+        self.horizontalSpacer_2 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.horizontalLayout_8.addItem(self.horizontalSpacer_2)
+
+        self.mag_layout.addLayout(self.horizontalLayout_8)
+
+        self.nav_mag = QStackedWidget(self.tab_mag)
+        self.nav_mag.setObjectName(u"nav_mag")
+        self.page = QWidget()
+        self.page.setObjectName(u"page")
+        self.verticalLayout_9 = QVBoxLayout(self.page)
+        self.verticalLayout_9.setObjectName(u"verticalLayout_9")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_mur_lin = QLabel(self.tab_mag)
-        self.in_mur_lin.setObjectName(u"in_mur_lin")
-        self.in_mur_lin.setFont(font)
+        self.gridLayout.setSizeConstraint(QLayout.SetDefaultConstraint)
+        self.lf_alpha_Br = FloatEdit(self.page)
+        self.lf_alpha_Br.setObjectName(u"lf_alpha_Br")
 
-        self.gridLayout.addWidget(self.in_mur_lin, 0, 0, 1, 1)
+        self.gridLayout.addWidget(self.lf_alpha_Br, 2, 1, 1, 1)
 
-        self.lf_mur_lin = FloatEdit(self.tab_mag)
-        self.lf_mur_lin.setObjectName(u"lf_mur_lin")
+        self.unit_alpha_Br = QLabel(self.page)
+        self.unit_alpha_Br.setObjectName(u"unit_alpha_Br")
 
-        self.gridLayout.addWidget(self.lf_mur_lin, 0, 1, 1, 1)
+        self.gridLayout.addWidget(self.unit_alpha_Br, 2, 2, 1, 1)
 
-        self.in_Brm20 = QLabel(self.tab_mag)
-        self.in_Brm20.setObjectName(u"in_Brm20")
-        self.in_Brm20.setFont(font)
+        self.unit_mur_lin = QLabel(self.page)
+        self.unit_mur_lin.setObjectName(u"unit_mur_lin")
 
-        self.gridLayout.addWidget(self.in_Brm20, 1, 0, 1, 1)
+        self.gridLayout.addWidget(self.unit_mur_lin, 0, 2, 1, 1)
 
-        self.lf_Brm20 = FloatEdit(self.tab_mag)
-        self.lf_Brm20.setObjectName(u"lf_Brm20")
-
-        self.gridLayout.addWidget(self.lf_Brm20, 1, 1, 1, 1)
-
-        self.unit_Brm20 = QLabel(self.tab_mag)
-        self.unit_Brm20.setObjectName(u"unit_Brm20")
-        self.unit_Brm20.setFont(font)
-
-        self.gridLayout.addWidget(self.unit_Brm20, 1, 2, 1, 1)
-
-        self.in_alpha_Br = QLabel(self.tab_mag)
+        self.in_alpha_Br = QLabel(self.page)
         self.in_alpha_Br.setObjectName(u"in_alpha_Br")
         self.in_alpha_Br.setFont(font)
 
         self.gridLayout.addWidget(self.in_alpha_Br, 2, 0, 1, 1)
 
-        self.lf_alpha_Br = FloatEdit(self.tab_mag)
-        self.lf_alpha_Br.setObjectName(u"lf_alpha_Br")
+        self.in_mur_lin = QLabel(self.page)
+        self.in_mur_lin.setObjectName(u"in_mur_lin")
+        self.in_mur_lin.setFont(font)
 
-        self.gridLayout.addWidget(self.lf_alpha_Br, 2, 1, 1, 1)
+        self.gridLayout.addWidget(self.in_mur_lin, 0, 0, 1, 1)
 
-        self.in_Wlam = QLabel(self.tab_mag)
-        self.in_Wlam.setObjectName(u"in_Wlam")
-        self.in_Wlam.setFont(font)
+        self.horizontalSpacer_6 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
 
-        self.gridLayout.addWidget(self.in_Wlam, 3, 0, 1, 1)
+        self.gridLayout.addItem(self.horizontalSpacer_6, 0, 3, 1, 1)
 
-        self.lf_Wlam = FloatEdit(self.tab_mag)
+        self.horizontalSpacer_7 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.gridLayout.addItem(self.horizontalSpacer_7, 1, 3, 1, 1)
+
+        self.horizontalSpacer_8 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.gridLayout.addItem(self.horizontalSpacer_8, 2, 3, 1, 1)
+
+        self.in_Brm20 = QLabel(self.page)
+        self.in_Brm20.setObjectName(u"in_Brm20")
+        self.in_Brm20.setFont(font)
+
+        self.gridLayout.addWidget(self.in_Brm20, 1, 0, 1, 1)
+
+        self.lf_mur_lin = FloatEdit(self.page)
+        self.lf_mur_lin.setObjectName(u"lf_mur_lin")
+
+        self.gridLayout.addWidget(self.lf_mur_lin, 0, 1, 1, 1)
+
+        self.lf_Brm20 = FloatEdit(self.page)
+        self.lf_Brm20.setObjectName(u"lf_Brm20")
+
+        self.gridLayout.addWidget(self.lf_Brm20, 1, 1, 1, 1)
+
+        self.unit_Brm20 = QLabel(self.page)
+        self.unit_Brm20.setObjectName(u"unit_Brm20")
+        self.unit_Brm20.setFont(font)
+
+        self.gridLayout.addWidget(self.unit_Brm20, 1, 2, 1, 1)
+
+        self.verticalLayout_9.addLayout(self.gridLayout)
+
+        self.verticalSpacer_7 = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout_9.addItem(self.verticalSpacer_7)
+
+        self.nav_mag.addWidget(self.page)
+        self.page_2 = QWidget()
+        self.page_2.setObjectName(u"page_2")
+        self.verticalLayout_3 = QVBoxLayout(self.page_2)
+        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
+        self.g_BH_import = QGroupBox(self.page_2)
+        self.g_BH_import.setObjectName(u"g_BH_import")
+        self.g_BH_import.setCheckable(True)
+        self.verticalLayout_8 = QVBoxLayout(self.g_BH_import)
+        self.verticalLayout_8.setObjectName(u"verticalLayout_8")
+        self.tab_values = DTableData(self.g_BH_import)
+        self.tab_values.setObjectName(u"tab_values")
+
+        self.verticalLayout_8.addWidget(self.tab_values)
+
+        self.verticalLayout_3.addWidget(self.g_BH_import)
+
+        self.gridLayout_5 = QGridLayout()
+        self.gridLayout_5.setObjectName(u"gridLayout_5")
+        self.lf_Wlam = FloatEdit(self.page_2)
         self.lf_Wlam.setObjectName(u"lf_Wlam")
 
-        self.gridLayout.addWidget(self.lf_Wlam, 3, 1, 1, 1)
+        self.gridLayout_5.addWidget(self.lf_Wlam, 0, 1, 1, 1)
 
-        self.unit_Wlam = QLabel(self.tab_mag)
+        self.in_Wlam = QLabel(self.page_2)
+        self.in_Wlam.setObjectName(u"in_Wlam")
+
+        self.gridLayout_5.addWidget(self.in_Wlam, 0, 0, 1, 1)
+
+        self.unit_Wlam = QLabel(self.page_2)
         self.unit_Wlam.setObjectName(u"unit_Wlam")
-        self.unit_Wlam.setFont(font)
 
-        self.gridLayout.addWidget(self.unit_Wlam, 3, 2, 1, 1)
+        self.gridLayout_5.addWidget(self.unit_Wlam, 0, 2, 1, 1)
 
-        self.verticalLayout_3.addLayout(self.gridLayout)
+        self.horizontalSpacer_10 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
 
-        self.w_BH_import = WImport(self.tab_mag)
-        self.w_BH_import.setObjectName(u"w_BH_import")
+        self.gridLayout_5.addItem(self.horizontalSpacer_10, 0, 3, 1, 1)
 
-        self.verticalLayout_3.addWidget(self.w_BH_import)
+        self.verticalLayout_3.addLayout(self.gridLayout_5)
+
+        self.nav_mag.addWidget(self.page_2)
+
+        self.mag_layout.addWidget(self.nav_mag)
 
         self.verticalSpacer = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout_3.addItem(self.verticalSpacer)
+        self.mag_layout.addItem(self.verticalSpacer)
 
         self.nav_phy.addTab(self.tab_mag, "")
         self.tab_mec = QWidget()
         self.tab_mec.setObjectName(u"tab_mec")
         self.verticalLayout_12 = QVBoxLayout(self.tab_mec)
         self.verticalLayout_12.setObjectName(u"verticalLayout_12")
+        self.horizontalLayout_10 = QHBoxLayout()
+        self.horizontalLayout_10.setObjectName(u"horizontalLayout_10")
+        self.in_material_type = QLabel(self.tab_mec)
+        self.in_material_type.setObjectName(u"in_material_type")
+
+        self.horizontalLayout_10.addWidget(self.in_material_type)
+
+        self.cb_material_type = QComboBox(self.tab_mec)
+        self.cb_material_type.addItem("")
+        self.cb_material_type.addItem("")
+        self.cb_material_type.setObjectName(u"cb_material_type")
+        self.cb_material_type.setMinimumSize(QSize(150, 0))
+
+        self.horizontalLayout_10.addWidget(self.cb_material_type)
+
+        self.horizontalSpacer_9 = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
+        )
+
+        self.horizontalLayout_10.addItem(self.horizontalSpacer_9)
+
+        self.verticalLayout_12.addLayout(self.horizontalLayout_10)
+
         self.horizontalLayout_41 = QHBoxLayout()
         self.horizontalLayout_41.setObjectName(u"horizontalLayout_41")
         self.in_rho_meca = QLabel(self.tab_mec)
@@ -325,56 +454,65 @@ class Ui_DMatSetup(object):
         self.nav_meca.addWidget(self.page_niso_mec)
         self.page_iso_mec = QWidget()
         self.page_iso_mec.setObjectName(u"page_iso_mec")
-        self.gridLayout_6 = QGridLayout(self.page_iso_mec)
-        self.gridLayout_6.setObjectName(u"gridLayout_6")
+        self.verticalLayout_7 = QVBoxLayout(self.page_iso_mec)
+        self.verticalLayout_7.setObjectName(u"verticalLayout_7")
+        self.gridLayout_4 = QGridLayout()
+        self.gridLayout_4.setObjectName(u"gridLayout_4")
         self.in_E = QLabel(self.page_iso_mec)
         self.in_E.setObjectName(u"in_E")
         self.in_E.setFont(font)
 
-        self.gridLayout_6.addWidget(self.in_E, 0, 0, 1, 1)
-
-        self.lf_G = FloatEdit(self.page_iso_mec)
-        self.lf_G.setObjectName(u"lf_G")
-
-        self.gridLayout_6.addWidget(self.lf_G, 2, 2, 1, 2)
-
-        self.verticalSpacer_6 = QSpacerItem(
-            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
-        )
-
-        self.gridLayout_6.addItem(self.verticalSpacer_6, 4, 3, 1, 1)
-
-        self.unit_G = QLabel(self.page_iso_mec)
-        self.unit_G.setObjectName(u"unit_G")
-
-        self.gridLayout_6.addWidget(self.unit_G, 2, 4, 1, 1)
+        self.gridLayout_4.addWidget(self.in_E, 0, 0, 1, 1)
 
         self.lf_E = FloatEdit(self.page_iso_mec)
         self.lf_E.setObjectName(u"lf_E")
 
-        self.gridLayout_6.addWidget(self.lf_E, 0, 1, 1, 3)
+        self.gridLayout_4.addWidget(self.lf_E, 0, 1, 1, 1)
 
-        self.in_G = QLabel(self.page_iso_mec)
-        self.in_G.setObjectName(u"in_G")
-        self.in_G.setFont(font)
+        self.unit_E = QLabel(self.page_iso_mec)
+        self.unit_E.setObjectName(u"unit_E")
 
-        self.gridLayout_6.addWidget(self.in_G, 2, 0, 1, 2)
+        self.gridLayout_4.addWidget(self.unit_E, 0, 2, 1, 1)
 
         self.in_nu = QLabel(self.page_iso_mec)
         self.in_nu.setObjectName(u"in_nu")
         self.in_nu.setFont(font)
 
-        self.gridLayout_6.addWidget(self.in_nu, 1, 0, 1, 3)
+        self.gridLayout_4.addWidget(self.in_nu, 1, 0, 1, 1)
 
         self.lf_nu = FloatEdit(self.page_iso_mec)
         self.lf_nu.setObjectName(u"lf_nu")
 
-        self.gridLayout_6.addWidget(self.lf_nu, 1, 3, 1, 1)
+        self.gridLayout_4.addWidget(self.lf_nu, 1, 1, 1, 1)
 
-        self.unit_E = QLabel(self.page_iso_mec)
-        self.unit_E.setObjectName(u"unit_E")
+        self.in_G = QLabel(self.page_iso_mec)
+        self.in_G.setObjectName(u"in_G")
+        self.in_G.setFont(font)
 
-        self.gridLayout_6.addWidget(self.unit_E, 0, 4, 1, 1)
+        self.gridLayout_4.addWidget(self.in_G, 2, 0, 1, 1)
+
+        self.lf_G = FloatEdit(self.page_iso_mec)
+        self.lf_G.setObjectName(u"lf_G")
+
+        self.gridLayout_4.addWidget(self.lf_G, 2, 1, 1, 1)
+
+        self.unit_G = QLabel(self.page_iso_mec)
+        self.unit_G.setObjectName(u"unit_G")
+
+        self.gridLayout_4.addWidget(self.unit_G, 2, 2, 1, 1)
+
+        self.unit_nu = QLabel(self.page_iso_mec)
+        self.unit_nu.setObjectName(u"unit_nu")
+
+        self.gridLayout_4.addWidget(self.unit_nu, 1, 2, 1, 1)
+
+        self.verticalLayout_7.addLayout(self.gridLayout_4)
+
+        self.verticalSpacer_6 = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout_7.addItem(self.verticalSpacer_6)
 
         self.nav_meca.addWidget(self.page_iso_mec)
 
@@ -387,11 +525,13 @@ class Ui_DMatSetup(object):
         self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.g_lambda = QGroupBox(self.tab_ther)
         self.g_lambda.setObjectName(u"g_lambda")
+        self.g_lambda.setMinimumSize(QSize(0, 90))
         self.g_lambda.setMaximumSize(QSize(16777215, 80))
         self.verticalLayout_11 = QVBoxLayout(self.g_lambda)
         self.verticalLayout_11.setObjectName(u"verticalLayout_11")
         self.nav_ther = QStackedWidget(self.g_lambda)
         self.nav_ther.setObjectName(u"nav_ther")
+        self.nav_ther.setMinimumSize(QSize(0, 50))
         self.page_niso_ther = QWidget()
         self.page_niso_ther.setObjectName(u"page_niso_ther")
         self.horizontalLayout_5 = QHBoxLayout(self.page_niso_ther)
@@ -486,6 +626,11 @@ class Ui_DMatSetup(object):
 
         self.gridLayout_3.addWidget(self.lf_Cp, 0, 1, 1, 1)
 
+        self.unit_alpha = QLabel(self.tab_ther)
+        self.unit_alpha.setObjectName(u"unit_alpha")
+
+        self.gridLayout_3.addWidget(self.unit_alpha, 1, 2, 1, 1)
+
         self.verticalLayout_2.addLayout(self.gridLayout_3)
 
         self.verticalSpacer_3 = QSpacerItem(
@@ -529,38 +674,37 @@ class Ui_DMatSetup(object):
 
         self.verticalLayout.addWidget(self.nav_phy)
 
-        self.horizontalGroupBox = QGroupBox(DMatSetup)
-        self.horizontalGroupBox.setObjectName(u"horizontalGroupBox")
-        self.horizontalLayout_9 = QHBoxLayout(self.horizontalGroupBox)
+        self.horizontalLayout_9 = QHBoxLayout()
         self.horizontalLayout_9.setObjectName(u"horizontalLayout_9")
-        self.horizontalSpacer_2 = QSpacerItem(
+        self.horizontalSpacer_5 = QSpacerItem(
             40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
         )
 
-        self.horizontalLayout_9.addItem(self.horizontalSpacer_2)
+        self.horizontalLayout_9.addItem(self.horizontalSpacer_5)
 
-        self.b_add_matlib = QPushButton(self.horizontalGroupBox)
-        self.b_add_matlib.setObjectName(u"b_add_matlib")
+        self.b_delete = QPushButton(DMatSetup)
+        self.b_delete.setObjectName(u"b_delete")
 
-        self.horizontalLayout_9.addWidget(self.b_add_matlib)
+        self.horizontalLayout_9.addWidget(self.b_delete)
 
-        self.b_save = QPushButton(self.horizontalGroupBox)
+        self.b_save = QPushButton(DMatSetup)
         self.b_save.setObjectName(u"b_save")
 
         self.horizontalLayout_9.addWidget(self.b_save)
 
-        self.b_cancel = QPushButton(self.horizontalGroupBox)
+        self.b_cancel = QPushButton(DMatSetup)
         self.b_cancel.setObjectName(u"b_cancel")
 
         self.horizontalLayout_9.addWidget(self.b_cancel)
 
-        self.verticalLayout.addWidget(self.horizontalGroupBox)
+        self.verticalLayout.addLayout(self.horizontalLayout_9)
 
         self.retranslateUi(DMatSetup)
 
-        self.nav_phy.setCurrentIndex(1)
-        self.nav_meca.setCurrentIndex(1)
-        self.nav_ther.setCurrentIndex(1)
+        self.nav_phy.setCurrentIndex(2)
+        self.nav_mag.setCurrentIndex(0)
+        self.nav_meca.setCurrentIndex(0)
+        self.nav_ther.setCurrentIndex(0)
 
         QMetaObject.connectSlotsByName(DMatSetup)
 
@@ -570,41 +714,68 @@ class Ui_DMatSetup(object):
         DMatSetup.setWindowTitle(
             QCoreApplication.translate("DMatSetup", u"Edit Material", None)
         )
-        self.in_name.setText(QCoreApplication.translate("DMatSetup", u"name", None))
-        self.le_name.setText("")
-        self.is_isotropic.setText(
-            QCoreApplication.translate("DMatSetup", u"is_isotropic", None)
+        self.in_name.setText(
+            QCoreApplication.translate("DMatSetup", u"Material name", None)
         )
+        self.le_name.setText("")
+        self.in_rho_elec.setText(QCoreApplication.translate("DMatSetup", u"rho", None))
         self.unit_rho_elec.setText(
-            QCoreApplication.translate("DMatSetup", u"ohm.m", None)
+            QCoreApplication.translate("DMatSetup", u"[ohm.m]", None)
         )
         self.in_epsr.setText(QCoreApplication.translate("DMatSetup", u"epsr", None))
-        self.in_rho_elec.setText(QCoreApplication.translate("DMatSetup", u"rho", None))
+        self.unit_epsr.setText(QCoreApplication.translate("DMatSetup", u"[ ]", None))
         self.nav_phy.setTabText(
             self.nav_phy.indexOf(self.tab_elec),
             QCoreApplication.translate("DMatSetup", u"Electrical", None),
         )
+        self.c_type_material.setItemText(
+            0, QCoreApplication.translate("DMatSetup", u"Linear material", None)
+        )
+        self.c_type_material.setItemText(
+            1, QCoreApplication.translate("DMatSetup", u"Magnet material", None)
+        )
+        self.c_type_material.setItemText(
+            2, QCoreApplication.translate("DMatSetup", u"Lamination material", None)
+        )
+
+        self.unit_alpha_Br.setText(
+            QCoreApplication.translate("DMatSetup", u"[ ]", None)
+        )
+        self.unit_mur_lin.setText(QCoreApplication.translate("DMatSetup", u"[ ]", None))
+        self.in_alpha_Br.setText(
+            QCoreApplication.translate("DMatSetup", u"alphaBr", None)
+        )
         self.in_mur_lin.setText(
             QCoreApplication.translate("DMatSetup", u"mur_lin", None)
         )
         self.in_Brm20.setText(QCoreApplication.translate("DMatSetup", u"Brm20", None))
-        self.unit_Brm20.setText(QCoreApplication.translate("DMatSetup", u"T", None))
-        self.in_alpha_Br.setText(
-            QCoreApplication.translate("DMatSetup", u"alphaBr", None)
+        self.unit_Brm20.setText(QCoreApplication.translate("DMatSetup", u"[T]", None))
+        self.g_BH_import.setTitle(
+            QCoreApplication.translate("DMatSetup", u"B(H) curve definition", None)
         )
         self.in_Wlam.setText(QCoreApplication.translate("DMatSetup", u"Wlam", None))
-        self.unit_Wlam.setText(QCoreApplication.translate("DMatSetup", u"m", None))
+        self.unit_Wlam.setText(QCoreApplication.translate("DMatSetup", u"[mm]", None))
         self.nav_phy.setTabText(
             self.nav_phy.indexOf(self.tab_mag),
             QCoreApplication.translate("DMatSetup", u"Magnetics", None),
         )
+        self.in_material_type.setText(
+            QCoreApplication.translate("DMatSetup", u"Material Type :", None)
+        )
+        self.cb_material_type.setItemText(
+            0, QCoreApplication.translate("DMatSetup", u"Orthotropic", None)
+        )
+        self.cb_material_type.setItemText(
+            1, QCoreApplication.translate("DMatSetup", u"Isotropic", None)
+        )
+
         self.in_rho_meca.setText(QCoreApplication.translate("DMatSetup", u"rho", None))
         self.unit_rho_meca.setText(
-            QCoreApplication.translate("DMatSetup", u"kg/m^3", None)
+            QCoreApplication.translate("DMatSetup", u"[kg/m^3]", None)
         )
         self.g_young.setTitle(
             QCoreApplication.translate(
-                "DMatSetup", u"Equivalent Yong Modulus [Pa]", None
+                "DMatSetup", u"Equivalent Yong Modulus [GPa]", None
             )
         )
         self.in_Ex.setText(QCoreApplication.translate("DMatSetup", u"Ex", None))
@@ -619,16 +790,17 @@ class Ui_DMatSetup(object):
         self.in_nu_xz.setText(QCoreApplication.translate("DMatSetup", u"nu_xz", None))
         self.in_nu_yz.setText(QCoreApplication.translate("DMatSetup", u"nu_yz", None))
         self.g_shear.setTitle(
-            QCoreApplication.translate("DMatSetup", u"Shear modulus [Pa]", None)
+            QCoreApplication.translate("DMatSetup", u"Shear modulus [GPa]", None)
         )
         self.in_Gxy.setText(QCoreApplication.translate("DMatSetup", u"Gxy", None))
         self.in_Gxz.setText(QCoreApplication.translate("DMatSetup", u"Gxz", None))
         self.in_Gyz.setText(QCoreApplication.translate("DMatSetup", u"Gyz", None))
         self.in_E.setText(QCoreApplication.translate("DMatSetup", u"E", None))
-        self.unit_G.setText(QCoreApplication.translate("DMatSetup", u"Pa", None))
-        self.in_G.setText(QCoreApplication.translate("DMatSetup", u"G", None))
+        self.unit_E.setText(QCoreApplication.translate("DMatSetup", u"[GPa]", None))
         self.in_nu.setText(QCoreApplication.translate("DMatSetup", u"nu", None))
-        self.unit_E.setText(QCoreApplication.translate("DMatSetup", u"Pa", None))
+        self.in_G.setText(QCoreApplication.translate("DMatSetup", u"G", None))
+        self.unit_G.setText(QCoreApplication.translate("DMatSetup", u"[GPa]", None))
+        self.unit_nu.setText(QCoreApplication.translate("DMatSetup", u"[ ]", None))
         self.nav_phy.setTabText(
             self.nav_phy.indexOf(self.tab_mec),
             QCoreApplication.translate("DMatSetup", u"Mechanics", None),
@@ -640,29 +812,28 @@ class Ui_DMatSetup(object):
         self.in_Ly.setText(QCoreApplication.translate("DMatSetup", u"Y", None))
         self.in_Lz.setText(QCoreApplication.translate("DMatSetup", u"Z", None))
         self.in_L.setText(QCoreApplication.translate("DMatSetup", u"Lambda", None))
-        self.unit_L.setText(QCoreApplication.translate("DMatSetup", u"W / K", None))
+        self.unit_L.setText(QCoreApplication.translate("DMatSetup", u"[W / K]", None))
         self.in_alpha.setText(QCoreApplication.translate("DMatSetup", u"alpha", None))
         self.in_Cp.setText(QCoreApplication.translate("DMatSetup", u"Cp", None))
         self.unit_Cp.setText(
-            QCoreApplication.translate("DMatSetup", u"W / kg / K", None)
+            QCoreApplication.translate("DMatSetup", u"[W / kg / K]", None)
         )
+        self.unit_alpha.setText(QCoreApplication.translate("DMatSetup", u"[ ]", None))
         self.nav_phy.setTabText(
             self.nav_phy.indexOf(self.tab_ther),
-            QCoreApplication.translate("DMatSetup", u"Thermics", None),
+            QCoreApplication.translate("DMatSetup", u"Heat Transfer", None),
         )
         self.in_cost_unit.setText(
             QCoreApplication.translate("DMatSetup", u"cost_unit", None)
         )
         self.unit_cost_unit.setText(
-            QCoreApplication.translate("DMatSetup", u"\u20ac / kg", None)
+            QCoreApplication.translate("DMatSetup", u"[\u20ac / kg]", None)
         )
         self.nav_phy.setTabText(
             self.nav_phy.indexOf(self.tab_eco),
             QCoreApplication.translate("DMatSetup", u"Economical", None),
         )
-        self.b_add_matlib.setText(
-            QCoreApplication.translate("DMatSetup", u"Add to MatLib", None)
-        )
+        self.b_delete.setText(QCoreApplication.translate("DMatSetup", u"Delete", None))
         self.b_save.setText(QCoreApplication.translate("DMatSetup", u"Save", None))
         self.b_cancel.setText(QCoreApplication.translate("DMatSetup", u"Cancel", None))
 
