@@ -8,15 +8,17 @@ from matplotlib.backends.backend_qt5agg import (
 )
 from ezdxf import readfile
 from numpy import angle as np_angle
-from numpy import argmin, array
-from PySide2.QtCore import QUrl
-from PySide2.QtGui import QDesktopServices, QIcon
-from PySide2.QtWidgets import QDialog, QFileDialog, QMessageBox
+from numpy import argmin, array, exp, angle
+from PySide2.QtCore import QSize, Qt, QUrl
+from PySide2.QtGui import QIcon, QPixmap, QFont, QDesktopServices
+from PySide2.QtWidgets import QComboBox, QDialog, QFileDialog, QMessageBox, QPushButton
 
 
 from ...Classes.LamSlot import LamSlot
 from ...Classes.SlotUD import SlotUD
+from ...Classes.Segment import Segment
 from ...definitions import config_dict
+from ...Functions.Plot.set_plot_gui_icon import set_plot_gui_icon
 from ...GUI.Dxf.dxf_to_pyleecan import dxf_to_pyleecan_list, convert_dxf_with_FEMM
 from ...GUI.Resources import pixmap_dict
 from ...GUI.Tools.MPLCanvas import MPLCanvas
@@ -29,6 +31,8 @@ TYPE_COL = 0
 DEL_COL = 1
 HL_COL = 2
 WIND_COLOR = config_dict["PLOT"]["COLOR_DICT"]["BAR_COLOR"]
+FONT_SIZE = 12
+FONT_NAME = config_dict["PLOT"]["FONT_NAME"]
 Z_TOL = 1e-4  # Point comparison tolerance
 
 
@@ -37,7 +41,7 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
 
     convert_dxf_with_FEMM = convert_dxf_with_FEMM
 
-    def __init__(self, dxf_path=None, Zs=None, lam=None):
+    def __init__(self, dxf_path=None, Zs=None, lam=None, is_notch=False):
         """Initialize the Dialog
 
         Parameters
@@ -46,6 +50,12 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
             a DXF_Slot object
         dxf_path : str
             Path to a dxf file to read
+        Zs : int
+            Number of slot/notch
+        lam : Lamination
+            Lamination to add the slot to
+        is_notch : bool
+            True if the DXF is meant for a notch
         """
         # Widget setup
         QDialog.__init__(self)
@@ -55,12 +65,19 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
         self.line_list = list()  # List of line from DXF
         self.selected_list = list()  # List of currently selected lines
         self.lam = lam
+        self.is_notch = is_notch
         self.Zcenter = 0  # For offset
 
         # Tutorial video link
         self.url = "https://pyleecan.org/videos.html#feature-tutorials"
         self.b_tuto.setEnabled(True)
 
+        # Adapt GUI for notches
+        if self.is_notch:
+            self.g_active.hide()
+            self.in_Zs.setText("Number of notches")
+            self.setWindowTitle("Define Notch from DXF")
+
         # Initialize the graph
         self.init_graph()
 
@@ -91,6 +108,12 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
         if self.dxf_path is not None and isfile(self.dxf_path):
             self.open_document()
 
+        # Set font
+        font = QFont()
+        font.setFamily(FONT_NAME)
+        font.setPointSize(FONT_SIZE)
+        self.textBrowser.setFont(font)
+
         # Connect signals to slot
         self.w_path_selector.pathChanged.connect(self.open_document)
         self.b_save.pressed.connect(self.save)
@@ -354,12 +377,12 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
             User defined slot according to selected lines
         """
 
-        if self.lf_scaling.value() == 0:  # Avoid error
+        if self.lf_scaling.value() in [0, None]:  # Avoid error
             self.lf_scaling.setValue(1)
 
-        # Get all the selected lines
+        # Get all the selected lines at proper scale
         line_list = list()
-        point_list = list()
+        point_list = list()  # List of all begin, end of all the lines
         for ii, line in enumerate(self.line_list):
             if self.selected_list[ii]:
                 line_list.append(line.copy())
@@ -369,6 +392,8 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
 
         # Find begin point
         single_list = list()
+        # In point list all point should be present twice
+        # except first and last point
         for p1 in point_list:
             count = 0
             for p2 in point_list:
@@ -376,9 +401,13 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
                     count += 1
             if count == 1:
                 single_list.append(p1)
-        assert len(single_list) == 2
+        assert (
+            len(single_list) == 2
+        ), "Unable to detect first and last point of the slot"
+        # Lines must be returned in trigo order center on Ox
+        # Begin selection can be wrong, corrected if needed after rotate
         Zbegin = single_list[argmin(np_angle(array(single_list)))]
-        # Get begin line
+        # Get First line
         id_list = list()
         id_list.extend(
             [
@@ -388,7 +417,7 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
                 or abs(line.get_end() - Zbegin) < Z_TOL
             ]
         )
-        # Sort the lines (begin = end)
+        # Sort the lines (find line with current.end == line.begin)
         curve_list = list()
         curve_list.append(line_list.pop(id_list[0]))
         if abs(curve_list[0].get_end() - Zbegin) < Z_TOL:
@@ -404,27 +433,41 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
                     break
             curve_list.append(line_list.pop(ii))
 
-        # Create the Slot object
-        slot = SlotUD(line_list=curve_list)
-        slot.type_line_wind = self.c_type_line.currentIndex()
-        begin_id = self.si_wind_begin_index.value()
-        end_id = self.si_wind_end_index.value()
-        if (
-            begin_id < len(curve_list)
-            and end_id < len(curve_list)
-            and begin_id < end_id
-        ):
-            slot.wind_begin_index = begin_id
-            slot.wind_end_index = end_id
-        else:
-            slot.wind_begin_index = None
-            slot.wind_end_index = None
-
         # Translate
         if self.Zcenter != 0:
             for line in curve_list:
                 line.translate(-self.Zcenter * self.lf_scaling.value())
 
+        # Check the first and last point are matching Rint
+        Rbo = self.lam.get_Rbo()
+        Zbegin = curve_list[0].get_begin()
+        Zend = curve_list[-1].get_end()
+        if abs(abs(Zbegin) - Rbo) > Z_TOL:
+            QMessageBox().critical(
+                self,
+                self.tr("Error"),
+                self.tr(
+                    "First point of the slot is not on the bore radius:\nBore radius="
+                    + format(Rbo, ".6g")
+                    + ", abs(First point)="
+                    + format(abs(Zbegin), ".6g")
+                ),
+            )
+
+            return None
+        if abs(abs(Zend) - Rbo) > Z_TOL:
+            QMessageBox().critical(
+                self,
+                self.tr("Error"),
+                self.tr(
+                    "Last point of the slot is not on the bore radius:\nBore radius="
+                    + format(Rbo, ".6g")
+                    + ", abs(Last point)="
+                    + format(abs(Zend), ".6g")
+                ),
+            )
+            return None
+
         # Rotation
         Z1 = curve_list[0].get_begin()
         Z2 = curve_list[-1].get_end()
@@ -432,13 +475,50 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
         for line in curve_list:
             line.rotate(-1 * alpha)
 
-        # Set metadata
+        # Enforce perfect match with Bore radius by adding Segments in needed
+        Zbegin = curve_list[0].get_begin()
+        Zb2 = Rbo * exp(1j * angle(Zbegin))
+        if abs(Zb2 - Zbegin) > 1e-9:
+            curve_list.insert(0, Segment(begin=Zb2, end=Zbegin))
+
+        Zend = curve_list[-1].get_end()
+        Ze2 = Rbo * exp(1j * angle(Zend))
+        if abs(Ze2 - Zend) > 1e-9:
+            curve_list.append(Segment(begin=Zend, end=Ze2))
+
+        # Check that the lines are in trigo order (can be reversed for inner slot)
+        if angle(curve_list[0].get_begin()) > angle(curve_list[-1].get_end()):
+            curve_list = curve_list[::-1]
+            for line in curve_list:
+                line.reverse()
+
+        # Create the Slot object
+        slot = SlotUD(line_list=curve_list)
+        slot.type_line_wind = self.c_type_line.currentIndex()
+        begin_id = self.si_wind_begin_index.value()
+        end_id = self.si_wind_end_index.value()
+        if begin_id == 0 and end_id == 0:  # Not defined yet
+            slot.wind_begin_index = None
+            slot.wind_end_index = None
+        elif (
+            begin_id < len(curve_list)
+            and end_id < len(curve_list)
+            # and begin_id < end_id
+        ):
+            slot.wind_begin_index = begin_id
+            slot.wind_end_index = end_id
+        else:  # Wrong definition
+            slot.wind_begin_index = None
+            slot.wind_end_index = None
+        if self.is_notch:
+            slot.wind_begin_index = None
+            slot.wind_end_index = None
         slot.Zs = self.si_Zs.value()
 
         return slot
 
     def plot(self):
-        """Plot the current state of the hole
+        """Plot the current state of the slot
 
         Parameters
         ----------
@@ -446,7 +526,19 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
             a DXF_Slot object
         """
         if self.check_selection():
-            slot = self.get_slot()
+            try:
+                slot = self.get_slot()
+            except Exception as e:
+                err_msg = "Error in DXF slot definition:\n" + str(e)
+                QMessageBox().critical(
+                    self,
+                    self.tr("Error"),
+                    err_msg,
+                )
+                return
+
+            if slot is None:
+                return  # Uncorrect slot
             # Lamination definition
             if self.lam is None:
                 lam = LamSlot(slot=slot)
@@ -454,24 +546,36 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
             else:
                 lam = self.lam.copy()
                 lam.slot = slot
-            fig, (ax1, ax2) = plt.subplots(1, 2)
-            slot.plot(fig=fig, ax=ax1)
-            # Add the winding if defined
-            if slot.wind_begin_index is not None:
-                surf_wind = slot.get_surface_active()
-                surf_wind.plot(fig=fig, ax=ax1, color=WIND_COLOR, is_show_fig=False)
-            # Add point index
-            index = 0
-            for line in slot.line_list:
-                Zb = line.get_begin()
-                ax1.plot(Zb.real, Zb.imag, "rx", zorder=0)
-                ax1.text(Zb.real, Zb.imag, str(index))
-                index += 1
-            Ze = slot.line_list[-1].get_end()
-            ax1.plot(Ze.real, Ze.imag, "rx", zorder=0)
-            ax1.text(Ze.real, Ze.imag, str(index))
-            # Lamination point
-            lam.plot(fig=fig, ax=ax2)
+            try:
+                # Left single slot with point index, Right Lamination with slot
+                fig, (ax1, ax2) = plt.subplots(1, 2)
+                slot.plot(fig=fig, ax=ax1)
+                # Add the winding to slot if defined
+                if not self.is_notch and slot.wind_begin_index is not None:
+                    surf_wind = slot.get_surface_active()
+                    surf_wind.plot(fig=fig, ax=ax1, color=WIND_COLOR, is_show_fig=False)
+                if not self.is_notch:
+                    # Add point index for winding definition
+                    index = 0
+                    for line in slot.line_list:
+                        Zb = line.get_begin()
+                        ax1.plot(Zb.real, Zb.imag, "rx", zorder=0)
+                        ax1.text(Zb.real, Zb.imag, str(index))
+                        index += 1
+                    Ze = slot.line_list[-1].get_end()
+                    ax1.plot(Ze.real, Ze.imag, "rx", zorder=0)
+                    ax1.text(Ze.real, Ze.imag, str(index))
+                # Plot lamination with slot and winding (if needed)
+                lam.plot(fig=fig, ax=ax2, is_lam_only=self.is_notch)
+                set_plot_gui_icon()
+            except Exception as e:
+                err_msg = "Error while plotting DXF imported slot:\n" + str(e)
+                QMessageBox().critical(
+                    self,
+                    self.tr("Error"),
+                    err_msg,
+                )
+                return
 
     def save(self):
         """Save the SlotUD object in a json file
@@ -483,8 +587,31 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
         """
 
         if self.check_selection():
-            slot = self.get_slot()
-
+            try:
+                slot = self.get_slot()
+            except Exception as e:
+                err_msg = "Error in DXF slot definition:\n" + str(e)
+                QMessageBox().critical(
+                    self,
+                    self.tr("Error"),
+                    err_msg,
+                )
+                return
+            if slot is None:
+                return  # Uncorrect slot
+            if (
+                self.si_wind_begin_index.value() == 0
+                and self.si_wind_end_index.value() == 0
+                and not self.is_notch  # No winding for notch
+            ):
+                QMessageBox().warning(
+                    self,
+                    self.tr("Warning"),
+                    self.tr(
+                        "The winding was not defined. Please use plot to see the points indices"
+                    ),
+                )
+                return
             save_file_path = QFileDialog.getSaveFileName(
                 self, self.tr("Save file"), dirname(self.dxf_path), "Json (*.json)"
             )[0]
@@ -495,11 +622,13 @@ class DXF_Slot(Ui_DXF_Slot, QDialog):
                     slot.save(save_file_path)
                     self.accept()
                 except Exception as e:
+                    err_msg = "Error while saving DXF slot json file:\n" + str(e)
                     QMessageBox().critical(
                         self,
                         self.tr("Error"),
-                        self.tr("Error while saving slot json file:\n" + str(e)),
+                        err_msg,
                     )
+                return
 
     def open_tuto(self):
         """Open the tutorial video in a web browser"""
