@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from matplotlib.pyplot import axis, legend
 from numpy import real, imag
 
 from ....Functions.init_fig import init_fig
 
 
-def plot_lines(self, fig=None, is_show_fig=True):
+def plot_lines(self, fig=None, ax=None, is_show_fig=True):
     """Plot the SurfLine-Contour in a matplotlib fig
     (For plotting unclosed contour, for Polygon use plot method from Surface object)
 
@@ -14,20 +11,24 @@ def plot_lines(self, fig=None, is_show_fig=True):
     ----------
     self : SurfLine
         A SurfLine object
-    fig :
-        if None, open a new fig and plot, else add to the
-        current one (Default value = None)
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
     is_show_fig : bool
         To call show at the end of the method
 
     Returns
     -------
-    None
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
 
-    (fig, axes, patch_leg, label_leg) = init_fig(fig)
-    axes.set_xlabel("(m)")
-    axes.set_ylabel("(m)")
+    (fig, ax, patch_leg, label_leg) = init_fig(fig, ax)
+    ax.set_xlabel("(m)")
+    ax.set_ylabel("(m)")
 
     points = self.discretize(10)
 
@@ -38,10 +39,11 @@ def plot_lines(self, fig=None, is_show_fig=True):
         y1 = imag(z1)
         x2 = real(z2)
         y2 = imag(z2)
-        axes.plot([x1, x2], [y1, y2], "k")
+        ax.plot([x1, x2], [y1, y2], "k")
 
     # Axis Setup
-    axis("equal")
+    ax.axis("equal")
 
     if is_show_fig:
         fig.show()
+    return fig, ax
