@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 from matplotlib.patches import Patch
-from matplotlib.pyplot import axis, legend
 import matplotlib.pyplot as plt
 
 from ....Functions.labels import decode_label, WIND_LAB, BAR_LAB, LAM_LAB
@@ -27,6 +24,8 @@ def plot(
     alpha=0,
     delta=0,
     is_edge_only=False,
+    edgecolor=None,
+    is_add_arrow=False,
     is_display=True,
     is_add_sign=False,
     is_show_fig=True,
@@ -53,14 +52,21 @@ def plot(
         Complex value for translation
     is_edge_only: bool
         To plot transparent Patches
+    edgecolor:
+        Color of the edges if is_edge_only=True
     is_display : bool
         False to return the patches
     is_show_fig : bool
         To call show at the end of the method
+
     Returns
     -------
     patches : list
         List of Patches
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
 
     if self.is_stator:
@@ -68,7 +74,7 @@ def plot(
     else:
         lam_color = ROTOR_COLOR
 
-    (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
+    (fig, ax, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
 
     # getting the number of phases and winding connection matrix
     if self.winding is not None:
@@ -92,7 +98,11 @@ def plot(
     for surf in surf_list:
         label_dict = decode_label(surf.label)
         if LAM_LAB in label_dict["surf_type"]:
-            patches.extend(surf.get_patches(color=lam_color, is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(
+                    color=lam_color, is_edge_only=is_edge_only, edgecolor=edgecolor
+                )
+            )
         elif WIND_LAB in label_dict["surf_type"] or BAR_LAB in label_dict["surf_type"]:
             if not is_lam_only:
                 color, sign = find_wind_phase_color(wind_mat=wind_mat, label=surf.label)
@@ -104,22 +114,27 @@ def plot(
                     hatch = None
                 patches.extend(
                     surf.get_patches(
-                        color=color, is_edge_only=is_edge_only, hatch=hatch
+                        color=color,
+                        is_edge_only=is_edge_only,
+                        hatch=hatch,
+                        edgecolor=edgecolor,
                     )
                 )
         else:
-            patches.extend(surf.get_patches(is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(is_edge_only=is_edge_only, edgecolor=edgecolor)
+            )
 
     # Display the result
     if is_display:
-        (fig, axes, patch_leg, label_leg) = init_fig(fig)
-        axes.set_xlabel("(m)")
-        axes.set_ylabel("(m)")
+        (fig, ax, patch_leg, label_leg) = init_fig(fig)
+        ax.set_xlabel("(m)")
+        ax.set_ylabel("(m)")
         for patch in patches:
-            axes.add_patch(patch)
+            ax.add_patch(patch)
 
         # Axis Setup
-        axes.axis("equal")
+        ax.axis("equal")
 
         # Window title
         if self.is_stator:
@@ -140,19 +155,19 @@ def plot(
 
         # The Lamination is centered in the figure
         Lim = self.Rext * 1.5
-        axes.set_xlim(-Lim, Lim)
-        axes.set_ylim(-Lim, Lim)
+        ax.set_xlim(-Lim, Lim)
+        ax.set_ylim(-Lim, Lim)
 
         # Add the legend
         if not is_edge_only:
             if self.is_stator and "Stator" not in label_leg:
                 patch_leg.append(Patch(color=STATOR_COLOR))
                 label_leg.append("Stator")
-                axes.set_title("Stator with empty slot")
+                ax.set_title("Stator with empty slot")
             elif not self.is_stator and "Rotor" not in label_leg:
                 patch_leg.append(Patch(color=ROTOR_COLOR))
                 label_leg.append("Rotor")
-                axes.set_title("Rotor with Winding")
+                ax.set_title("Rotor with Winding")
             # Add the winding legend only if needed
             if not is_lam_only:
                 if isinstance(self.winding, WindingSC):
@@ -180,12 +195,13 @@ def plot(
                                 Patch(color=PHASE_COLORS[index], hatch=MINUS_HATCH)
                             )
                             label_leg.append(phase_name[ii] + " -")
-            legend(patch_leg, label_leg)
+            ax.legend(patch_leg, label_leg)
 
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
         if is_show_fig:
             fig.show()
+        return fig, ax
     else:
         return patches
