@@ -1,9 +1,17 @@
-from pyleecan.Classes.Winding import Winding
-from pyleecan.Classes.Conductor import Conductor
-
-
 def comp_fill_factor(self):
-    """Compute the fill factor of the winding"""
+    """Compute the fill factor of the winding
+
+    Parameters
+    ----------
+    self : LamSlotWind
+        a LamSlotWind object
+
+    Returns
+    -------
+    Kfill : float
+        fill factor of the winding
+    """
+
     if self.winding is None or self.winding.qs == 0 or self.winding.conductor is None:
         return 0
     else:
