@@ -1,20 +1,19 @@
-# -*- coding: utf-8 -*-
-
 from matplotlib.patches import Patch
-from matplotlib.pyplot import axis, legend
 import matplotlib.pyplot as plt
 
-from ....Functions.labels import decode_label, WIND_LAB, BAR_LAB, LAM_LAB
+from ....Functions.labels import decode_label, WIND_LAB, BAR_LAB, LAM_LAB, WEDGE_LAB
 from ....Functions.Winding.find_wind_phase_color import find_wind_phase_color
 from ....Functions.Winding.gen_phase_list import gen_name
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
 from ....Classes.WindingSC import WindingSC
-from ....Classes.Winding import Winding
 
 PHASE_COLORS = config_dict["PLOT"]["COLOR_DICT"]["PHASE_COLORS"]
 ROTOR_COLOR = config_dict["PLOT"]["COLOR_DICT"]["ROTOR_COLOR"]
 STATOR_COLOR = config_dict["PLOT"]["COLOR_DICT"]["STATOR_COLOR"]
+if "WEDGE_COLOR" not in config_dict["PLOT"]["COLOR_DICT"]:
+    config_dict["PLOT"]["COLOR_DICT"]["WEDGE_COLOR"] = "y"
+WEDGE_COLOR = config_dict["PLOT"]["COLOR_DICT"]["WEDGE_COLOR"]
 PLUS_HATCH = "++"
 MINUS_HATCH = ".."
 
@@ -28,11 +27,15 @@ def plot(
     alpha=0,
     delta=0,
     is_edge_only=False,
+    edgecolor=None,
+    is_add_arrow=False,
     is_display=True,
     is_add_sign=True,
     is_show_fig=True,
     save_path=None,
     win_title=None,
+    is_legend=True,
+    is_clean_plot=False,
 ):
     """Plot the Lamination in a matplotlib fig
 
@@ -54,6 +57,8 @@ def plot(
         Complex value for translation
     is_edge_only: bool
         To plot transparent Patches
+    edgecolor:
+        Color of the edges if is_edge_only=True
     is_display : bool
         False to return the patches
     is_add_sign : bool
@@ -64,10 +69,19 @@ def plot(
         full path including folder, name and extension of the file to save if save_path is not None
     win_title : str
         Title for the window
+    is_legend : bool
+        True to add the legend
+    is_clean_plot : bool
+        True to remove title, legend, axis (only machine on plot with white background)
+
     Returns
     -------
     patches : list
         List of Patches
+    fig : Matplotlib.figure.Figure
+        Figure containing the plot
+    ax : Matplotlib.axes.Axes object
+        Axis containing the plot
     """
     if self.is_stator:
         color_lam = STATOR_COLOR
@@ -97,7 +111,11 @@ def plot(
     for surf in surf_list:
         label_dict = decode_label(surf.label)
         if LAM_LAB in label_dict["surf_type"]:
-            patches.extend(surf.get_patches(color_lam, is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(
+                    color_lam, is_edge_only=is_edge_only, edgecolor=edgecolor
+                )
+            )
         elif WIND_LAB in label_dict["surf_type"] or BAR_LAB in label_dict["surf_type"]:
             if not is_lam_only:
                 color, sign = find_wind_phase_color(wind_mat=wind_mat, label=surf.label)
@@ -109,21 +127,30 @@ def plot(
                     hatch = None
                 patches.extend(
                     surf.get_patches(
-                        color=color, is_edge_only=is_edge_only, hatch=hatch
+                        color=color,
+                        is_edge_only=is_edge_only,
+                        hatch=hatch,
+                        edgecolor=edgecolor,
                     )
                 )
+        elif WEDGE_LAB in label_dict["surf_type"] and not is_lam_only:
+            patches.extend(surf.get_patches(WEDGE_COLOR, is_edge_only=is_edge_only))
         else:
-            patches.extend(surf.get_patches(is_edge_only=is_edge_only))
+            patches.extend(
+                surf.get_patches(is_edge_only=is_edge_only, edgecolor=edgecolor)
+            )
 
     if is_display:
+
         # Display the result
-        (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
-        axes.set_xlabel("(m)")
-        axes.set_ylabel("(m)")
+        (fig, ax, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
+
+        ax.set_xlabel("(m)")
+        ax.set_ylabel("(m)")
         for patch in patches:
-            axes.add_patch(patch)
+            ax.add_patch(patch)
         # Axis Setup
-        axes.axis("equal")
+        ax.axis("equal")
 
         # Window title
         if self.is_stator:
@@ -144,19 +171,30 @@ def plot(
 
         # The Lamination is centered in the figure
         Lim = self.Rext * 1.5
-        axes.set_xlim(-Lim, Lim)
-        axes.set_ylim(-Lim, Lim)
+        ax.set_xlim(-Lim, Lim)
+        ax.set_ylim(-Lim, Lim)
+
+        title = None
 
         # Add the legend
         if not is_edge_only:
             if self.is_stator and "Stator" not in label_leg:
                 patch_leg.append(Patch(color=STATOR_COLOR))
                 label_leg.append("Stator")
-                axes.set_title("Stator with Winding")
+                title = "Stator with winding"
             elif not self.is_stator and "Rotor" not in label_leg:
                 patch_leg.append(Patch(color=ROTOR_COLOR))
                 label_leg.append("Rotor")
-                axes.set_title("Rotor with Winding")
+                title = "Rotor with winding"
+            ax.set_title(title)
+            # Add the wedges legend only if needed
+            if (
+                self.slot is not None
+                and self.slot.wedge_mat is not None
+                and not is_lam_only
+            ):
+                patch_leg.append(Patch(color=WEDGE_COLOR))
+                label_leg.append("Wedge")
             # Add the winding legend only if needed
             if not is_lam_only:
                 if isinstance(self.winding, WindingSC):
@@ -184,11 +222,23 @@ def plot(
                                 Patch(color=PHASE_COLORS[index], hatch=MINUS_HATCH)
                             )
                             label_leg.append(phase_name[ii] + " -")
-            legend(patch_leg, label_leg)
+
+            if is_legend:
+                ax.legend(patch_leg, label_leg)
+
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
+        # Clean figure
+        if is_clean_plot:
+            ax.set_axis_off()
+            ax.axis("equal")
+            if ax.get_legend() is not None:
+                ax.get_legend().remove()
+            ax.set_title("")
+
         if is_show_fig:
             fig.show()
+        return fig, ax
     else:
         return patches
