@@ -110,9 +110,9 @@ def comp_connection_mat(self, Zs=None, p=None):
     if self.Npcp is None:
         self.Npcp = Npcp_list[0]
     elif self.Npcp > 2 * p:
-        self.Npcp = 2 * p
+        # self.Npcp = 2 * p
         self.get_logger().warning(
-            "Number of parallel circuits per phase must be < 2*p, assign it to: "
+            "Number of parallel circuits per phase should be < 2*p, current value is: "
             + str(self.Npcp)
         )
     # if self.Npcp not in Npcp_list:
