@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from numpy import angle, exp, linspace, pi, sum, zeros
+from ....Methods.Machine.Winding import WindingError
 
 
 def comp_phasor_angle(self, Zs=None):
@@ -37,7 +38,7 @@ def comp_phasor_angle(self, Zs=None):
     assert Zs > 0, "Zs must be >0"
     assert Zs % 1 == 0, "Zs must be an integer"
 
-    wind_mat = self.comp_connection_mat(Zs)
+    wind_mat = self.get_connection_mat(Zs)
     p = self.p
     qs = self.qs  # number of phases
 
