@@ -17,6 +17,16 @@ def get_felec(self, p=None):
         Electrical Frequency [Hz]
     """
 
+    if self.slip_ref is None:
+        raise InputError("OPslip object can't have felec and slip_ref both None")
+
+    if p is None and (self.felec is None or self.N0 is None):
+        machine = self.get_machine_from_parent()
+        if machine is None:
+            raise InputError("OPslip object can't find machine parent to compute felec")
+
+        p = machine.get_pole_pair_number()
+
     if self.felec is not None:
         return self.felec
 
@@ -24,13 +34,11 @@ def get_felec(self, p=None):
     if self.N0 is None:
         raise InputError("OPslip object can't have felec and N0 both None")
 
-    if p is None:
-        machine = self.get_machine_from_parent()
-        if machine is None:
-            raise InputError("OPslip object can't find machine parent to compute felec")
-
-        p = machine.get_pole_pair_number()
-
-    self.felec = self.N0 * p / (60 * (1 - self.slip_ref))
+    if self.slip_ref != 1:
+        self.felec = self.N0 * p / (60 * (1 - self.slip_ref))
+    else:
+        raise InputError(
+            "Cannot calculate felec if slip_ref=1, felec must be enforced and N0 set to None or 0s"
+        )
 
     return self.felec
