@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from ....Methods.Slot.Slot import SlotCheckError
 from numpy import pi
 from ....Methods.Slot.HoleM51 import *
 
