@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from numpy import arcsin, pi
-
-from pyleecan.Methods.Slot.Slot import SlotCheckError
 from ....Methods.Slot.HoleM57 import *
 
 
