@@ -33,6 +33,8 @@ def plot_schematics(
     type_add_active=True,
     save_path=None,
     is_show_fig=True,
+    fig=None,
+    ax=None,
 ):
     """Plot the schematics of the slot
 
@@ -54,6 +56,17 @@ def plot_schematics(
         full path including folder, name and extension of the file to save if save_path is not None
     is_show_fig : bool
         To call show at the end of the method
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
+
+    Returns
+    -------
+    fig : Matplotlib.figure.Figure
+        Figure containing the schematics
+    ax : Matplotlib.axes.Axes object
+        Axis containing the schematics
     """
 
     # Use some default parameter
@@ -62,7 +75,7 @@ def plot_schematics(
         lam = LamSlot(
             Rint=80e-3, Rext=240e-3, is_internal=True, is_stator=False, slot=slot
         )
-        slot.plot_schematics(
+        return slot.plot_schematics(
             is_default=False,
             is_add_point_label=is_add_point_label,
             is_add_schematics=is_add_schematics,
@@ -70,15 +83,17 @@ def plot_schematics(
             type_add_active=type_add_active,
             save_path=save_path,
             is_show_fig=is_show_fig,
+            fig=fig,
+            ax=ax,
         )
     else:
         # Getting the main plot
         if self.parent is None:
             raise ParentMissingError("Error: The slot is not inside a Lamination")
         lam = self.parent
-        lam.plot(alpha=pi / self.Zs, is_show_fig=False)  # center slot on Ox axis
-        fig = plt.gcf()
-        ax = plt.gca()
+        fig, ax = lam.plot(
+            alpha=pi / self.Zs, is_show_fig=False, fig=fig, ax=ax
+        )  # center slot on Ox axis
         point_dict = self._comp_point_coordinate()
         if self.is_outwards():
             sign = +1
@@ -182,7 +197,7 @@ def plot_schematics(
         W = self.W1 / 2 * 1.3
         Rint, Rext = self.comp_radius()
 
-        plt.axis("equal")
+        ax.axis("equal")
         ax.set_xlim(Rint, Rext)
         ax.set_ylim(-W, W)
         manager = plt.get_current_fig_manager()
@@ -195,7 +210,8 @@ def plot_schematics(
         # Save / Show
         if save_path is not None:
             fig.savefig(save_path)
-            plt.close()
+            plt.close(fig=fig)
 
         if is_show_fig:
             fig.show()
+        return fig, ax
