@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
-
 from numpy import linspace, zeros
 
 from ....Classes.Segment import Segment
 from ....Classes.SurfLine import SurfLine
-from ....Functions.labels import WIND_LAB
+from ....Functions.labels import WIND_LAB, DRAW_PROP_LAB
 
 
-def build_geometry_active(self, Nrad, Ntan, is_simplified=False, alpha=0, delta=0):
+def build_geometry_active(self, Nrad, Ntan, alpha=0, delta=0):
     """Split the slot winding area in several zone
 
     Parameters
@@ -18,8 +16,6 @@ def build_geometry_active(self, Nrad, Ntan, is_simplified=False, alpha=0, delta=
         Number of radial layer
     Ntan : int
         Number of tangentiel layer
-    is_simplified : bool
-        boolean to specify if coincident lines are considered as one or different lines (Default value = False)
     alpha : float
         float number for rotation (Default value = 0) [rad]
     delta : complex
@@ -62,46 +58,42 @@ def build_geometry_active(self, Nrad, Ntan, is_simplified=False, alpha=0, delta=
             Z4 = Z[ii + 1][jj]
             point_ref = (Z1 + Z2 + Z3 + Z4) / 4
             # With one zone the order would be [Z7,Z4,Z5,Z6]
-            if is_simplified:
-                curve_list = list()
-                if ii == 0:
-                    curve_list.append(Segment(Z1, Z2))
-                if jj != Ntan - 1:
-                    curve_list.append(Segment(Z2, Z3))
-                if ii != Nrad - 1:
-                    curve_list.append(Segment(Z3, Z4))
-                surface = SurfLine(
-                    line_list=curve_list,
-                    label=lam_label
-                    + "_"
-                    + WIND_LAB
-                    + "_R"
-                    + str(ii)
-                    + "-T"
-                    + str(jj)
-                    + "-S0",
-                    point_ref=point_ref,
+            curve_list = list()
+            curve_list.append(Segment(Z1, Z2))
+            curve_list.append(
+                Segment(
+                    Z2,
+                    Z3,
+                    prop_dict={DRAW_PROP_LAB: False},
                 )
-                surf_list.append(surface)
-            else:
-                curve_list = list()
-                curve_list.append(Segment(Z1, Z2))
-                curve_list.append(Segment(Z2, Z3))
-                curve_list.append(Segment(Z3, Z4))
-                curve_list.append(Segment(Z4, Z1))
-                surface = SurfLine(
-                    line_list=curve_list,
-                    label=lam_label
-                    + "_"
-                    + WIND_LAB
-                    + "_R"
-                    + str(ii)
-                    + "-T"
-                    + str(jj)
-                    + "-S0",
-                    point_ref=point_ref,
+            )
+            curve_list.append(
+                Segment(
+                    Z3,
+                    Z4,
+                    prop_dict={DRAW_PROP_LAB: False},
                 )
-                surf_list.append(surface)
+            )
+            curve_list.append(
+                Segment(
+                    Z4,
+                    Z1,
+                    prop_dict={DRAW_PROP_LAB: jj != 0},
+                )
+            )
+            surface = SurfLine(
+                line_list=curve_list,
+                label=lam_label
+                + "_"
+                + WIND_LAB
+                + "_R"
+                + str(ii)
+                + "-T"
+                + str(jj)
+                + "-S0",
+                point_ref=point_ref,
+            )
+            surf_list.append(surface)
 
     for surf in surf_list:
         surf.rotate(alpha)
